@@ -15,6 +15,7 @@ use File::Basename qw(dirname);
 use File::Copy;
 use Storable qw(dclone);
 
+use pgBackRestDoc::Common::DocConfig;
 use pgBackRestDoc::Common::DocManifest;
 use pgBackRestDoc::Common::Log;
 use pgBackRestDoc::Common::String;
@@ -77,6 +78,66 @@ sub process
         $strMarkdown .= ' <br/> ' . $oPage->paramGet('subtitle') . '';
     }
 
+    # my $oHtmlBuilder = new pgBackRestDoc::Html::DocHtmlBuilder("{[project]} - Reliable PostgreSQL Backup",
+    #                                                          $strTitle . (defined($strSubTitle) ? " - ${strSubTitle}" : ''),
+    #                                                          $self->{bPretty});
+    #
+    # # Generate header
+    # my $oPageHeader = $oHtmlBuilder->bodyGet()->addNew(HTML_DIV, 'page-header');
+    #
+    # $oPageHeader->
+    #     addNew(HTML_DIV, 'page-header-title',
+    #            {strContent => $strTitle});
+    #
+    # if (defined($strSubTitle))
+    # {
+    #     $oPageHeader->
+    #         addNew(HTML_DIV, 'page-header-subtitle',
+    #                {strContent => $strSubTitle});
+    # }
+    #
+    # # Generate menu
+    # my $oMenuBody = $oHtmlBuilder->bodyGet()->addNew(HTML_DIV, 'page-menu')->addNew(HTML_DIV, 'menu-body');
+    #
+    # if ($self->{strRenderOutKey} ne 'index')
+    # {
+    #     my $oRenderOut = $self->{oManifest}->renderOutGet(RENDER_TYPE_HTML, 'index');
+    #
+    #     $oMenuBody->
+    #         addNew(HTML_DIV, 'menu')->
+    #             addNew(HTML_A, 'menu-link', {strContent => $$oRenderOut{menu}, strRef => '{[project-url-root]}'});
+    # }
+    #
+    # foreach my $strRenderOutKey ($self->{oManifest}->renderOutList(RENDER_TYPE_HTML))
+    # {
+    #     if ($strRenderOutKey ne $self->{strRenderOutKey} && $strRenderOutKey ne 'index')
+    #     {
+    #         my $oRenderOut = $self->{oManifest}->renderOutGet(RENDER_TYPE_HTML, $strRenderOutKey);
+    #
+    #         $oMenuBody->
+    #             addNew(HTML_DIV, 'menu')->
+    #                 addNew(HTML_A, 'menu-link', {strContent => $$oRenderOut{menu}, strRef => "${strRenderOutKey}.html"});
+    #     }
+    # }
+    #
+    # # Generate table of contents
+    # my $oPageTocBody;
+    #
+    # if (!defined($oPage->paramGet('toc', false)) || $oPage->paramGet('toc') eq 'y')
+    # {
+    #     my $oPageToc = $oHtmlBuilder->bodyGet()->addNew(HTML_DIV, 'page-toc');
+    #
+    #     $oPageToc->
+    #         addNew(HTML_DIV, 'page-toc-title',
+    #                {strContent => "Table of Contents"});
+    #
+    #     $oPageTocBody = $oPageToc->
+    #         addNew(HTML_DIV, 'page-toc-body');
+    # }
+    #
+    # # Generate body
+    # my $oPageBody = $oHtmlBuilder->bodyGet()->addNew(HTML_DIV, 'page-body');
+
     # Render sections
     foreach my $oSection ($oPage->nodeList('section'))
     {
@@ -243,6 +304,41 @@ sub sectionProcess
 
             $strMarkdown .= "\n" . $self->processText($oChild->textGet());
         }
+        # Add option descriptive text
+        elsif ($oChild->nameGet() eq 'option-description')
+        {
+            # my $strOption = $oChild->paramGet("key");
+            # my $oDescription = ${$self->{oReference}->{oConfigHash}}{&CONFIG_HELP_OPTION}{$strOption}{&CONFIG_HELP_DESCRIPTION};
+            #
+            # if (!defined($oDescription))
+            # {
+            #     confess &log(ERROR, "unable to find ${strOption} option in sections - try adding command?");
+            # }
+            #
+            # $oSectionBodyElement->
+            #     addNew(HTML_DIV, 'section-body-text',
+            #            {strContent => $self->processText($oDescription)});
+        }
+        # Add/remove backrest config options
+        elsif ($oChild->nameGet() eq 'backrest-config')
+        {
+            # my $oConfigElement = $self->backrestConfigProcess($oSection, $oChild, $iDepth + 3);
+            #
+            # if (defined($oConfigElement))
+            # {
+            #     $oSectionBodyElement->add($oConfigElement);
+            # }
+        }
+        # Add/remove postgres config options
+        elsif ($oChild->nameGet() eq 'postgres-config')
+        {
+            # my $oConfigElement = $self->postgresConfigProcess($oSection, $oChild, $iDepth + 3);
+            #
+            # if (defined($oConfigElement))
+            # {
+            #     $oSectionBodyElement->add($oConfigElement);
+            # }
+        }
         # Add a list
         elsif ($oChild->nameGet() eq 'list')
         {
@@ -352,4 +448,121 @@ sub sectionProcess
     );
 }
 
+####################################################################################################################################
+# backrestConfigProcess
+####################################################################################################################################
+sub backrestConfigProcess
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $oSection,
+        $oConfig,
+        $iDepth
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->backrestConfigProcess', \@_,
+            {name => 'oSection'},
+            {name => 'oConfig'},
+            {name => 'iDepth'}
+        );
+
+    # # Generate the config
+    # my $oConfigElement;
+    # my ($strFile, $strConfig, $bShow) = $self->backrestConfig($oSection, $oConfig, $iDepth);
+    #
+    # if ($bShow)
+    # {
+    #     my $strHostName = $self->{oManifest}->variableReplace($oConfig->paramGet('host'));
+    #
+    #     # Render the config
+    #     $oConfigElement = new pgBackRestDoc::Html::DocHtmlElement(HTML_DIV, "config");
+    #
+    #     $oConfigElement->
+    #         addNew(HTML_DIV, "config-title",
+    #                {strContent => "<span class=\"host\">${strHostName}</span>:<span class=\"file\">${strFile}</span>" .
+    #                               " <b>&#x21d2;</b> " . $self->processText($oConfig->nodeGet('title')->textGet())});
+    #
+    #     my $oConfigBodyElement = $oConfigElement->addNew(HTML_DIV, "config-body");
+    #     #
+    #     # $oConfigBodyElement->
+    #     #     addNew(HTML_DIV, "config-body-title",
+    #     #            {strContent => "${strFile}:"});
+    #
+    #     $oConfigBodyElement->
+    #         addNew(HTML_DIV, "config-body-output",
+    #                {strContent => $strConfig});
+    # }
+    #
+    # # Return from function and log return values if any
+    # return logDebugReturn
+    # (
+    #     $strOperation,
+    #     {name => 'oConfigElement', value => $oConfigElement, trace => true}
+    # );
+}
+
+####################################################################################################################################
+# postgresConfigProcess
+####################################################################################################################################
+sub postgresConfigProcess
+{
+    my $self = shift;
+
+    # # Assign function parameters, defaults, and log debug info
+    # my
+    # (
+    #     $strOperation,
+    #     $oSection,
+    #     $oConfig,
+    #     $iDepth
+    # ) =
+    #     logDebugParam
+    #     (
+    #         __PACKAGE__ . '->postgresConfigProcess', \@_,
+    #         {name => 'oSection'},
+    #         {name => 'oConfig'},
+    #         {name => 'iDepth'}
+    #     );
+    #
+    # # Generate the config
+    # my $oConfigElement;
+    # my ($strFile, $strConfig, $bShow) = $self->postgresConfig($oSection, $oConfig, $iDepth);
+    #
+    # if ($bShow)
+    # {
+    #     # Render the config
+    #     my $strHostName = $self->{oManifest}->variableReplace($oConfig->paramGet('host'));
+    #     $oConfigElement = new pgBackRestDoc::Html::DocHtmlElement(HTML_DIV, "config");
+    #
+    #     $oConfigElement->
+    #         addNew(HTML_DIV, "config-title",
+    #                {strContent => "<span class=\"host\">${strHostName}</span>:<span class=\"file\">${strFile}</span>" .
+    #                               " <b>&#x21d2;</b> " . $self->processText($oConfig->nodeGet('title')->textGet())});
+    #
+    #     my $oConfigBodyElement = $oConfigElement->addNew(HTML_DIV, "config-body");
+    #
+    #     # $oConfigBodyElement->
+    #     #     addNew(HTML_DIV, "config-body-title",
+    #     #            {strContent => "append to ${strFile}:"});
+    #
+    #     $oConfigBodyElement->
+    #         addNew(HTML_DIV, "config-body-output",
+    #                {strContent => defined($strConfig) ? $strConfig : '<No PgBackRest Settings>'});
+    #
+    #     $oConfig->fieldSet('actual-config', $strConfig);
+    # }
+    #
+    # # Return from function and log return values if any
+    # return logDebugReturn
+    # (
+    #     $strOperation,
+    #     {name => 'oConfigElement', value => $oConfigElement, trace => true}
+    # );
+}
+
 1;
