@@ -225,7 +225,7 @@ eval
 
             # Generate coverage summary
             &log(INFO, "Generate Coverage Summary");
-            executeTest("${strTestExe} --vm=f33 --no-valgrind --clean --coverage-summary", {bShowOutputAsync => true});
+            executeTest("${strTestExe} --vm=u22 --no-valgrind --clean --coverage-summary", {bShowOutputAsync => true});
         }
 
         # Remove permanent cache file
@@ -311,8 +311,8 @@ eval
         }
 
         # Update permissions
-        executeTest("find ${strDeployPath} -type d -exec chmod 750 {} +");
-        executeTest("find ${strDeployPath} -type f -exec chmod 640 {} +");
+        executeTest("find ${strDeployPath} -path .git -prune -type d -exec chmod 750 {} +");
+        executeTest("find ${strDeployPath} -path .git -prune -type f -exec chmod 640 {} +");
     }
 
     # Exit with success
