@@ -12,13 +12,13 @@ Check Command Common
 Functions
 ***********************************************************************************************************************************/
 // Check the database path and version are configured correctly
-void checkDbConfig(const unsigned int pgVersion, const unsigned int pgIdx, const Db *dbObject, bool isStandby);
+FN_EXTERN void checkDbConfig(const unsigned int pgVersion, const unsigned int pgIdx, const Db *dbObject, bool isStandby);
 
 // Validate the archive and backup info files
-void checkStanzaInfo(const InfoPgData *archiveInfo, const InfoPgData *backupInfo);
+FN_EXTERN void checkStanzaInfo(const InfoPgData *archiveInfo, const InfoPgData *backupInfo);
 
 // Load and validate the database data of the info files against each other and the current database
-void checkStanzaInfoPg(
+FN_EXTERN void checkStanzaInfoPg(
     const Storage *storage, const unsigned int pgVersion, const uint64_t pgSystemId, CipherType cipherType,
     const String *cipherPass);
 
