@@ -7,6 +7,6 @@ Start Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdStart(void);
+FN_EXTERN void cmdStart(void);
 
 #endif
