@@ -8,6 +8,7 @@ Remote Command
 #include "command/backup/blockIncr.h"
 #include "command/backup/pageChecksum.h"
 #include "command/control/common.h"
+#include "command/restore/blockChecksum.h"
 #include "common/crypto/cipherBlock.h"
 #include "common/crypto/hash.h"
 #include "common/debug.h"
@@ -36,6 +37,7 @@ Filter handlers
 ***********************************************************************************************************************************/
 static const StorageRemoteFilterHandler storageRemoteFilterHandlerList[] =
 {
+    {.type = BLOCK_CHECKSUM_FILTER_TYPE, .handlerParam = blockChecksumNewPack},
     {.type = BLOCK_INCR_FILTER_TYPE, .handlerParam = blockIncrNewPack},
     {.type = CIPHER_BLOCK_FILTER_TYPE, .handlerParam = cipherBlockNewPack},
     {.type = CRYPTO_HASH_FILTER_TYPE, .handlerParam = cryptoHashNewPack},
