@@ -34,9 +34,10 @@ typedef struct RestoreFile
     uint64_t offset;                                                // Offset into repo file where pg file is located
     const Variant *limit;                                           // Limit for read in the repo file
     uint64_t blockIncrMapSize;                                      // Block incremental map size (0 if not incremental)
-    uint64_t blockIncrSize;                                         // Block incremental size (when map size > 0)
+    size_t blockIncrSize;                                           // Block incremental size (when map size > 0)
+    size_t blockIncrChecksumSize;                                   // Checksum size (when map size > 0)
     const String *manifestFile;                                     // Manifest file
-    const Buffer *deltaMap;                                         // Delta for block incremental restore, set in restoreFile()
+    const Buffer *blockChecksum;                                    // Checksums for block incremental restore, set in restoreFile()
 } RestoreFile;
 
 typedef struct RestoreFileResult
@@ -47,6 +48,6 @@ typedef struct RestoreFileResult
 
 FN_EXTERN List *restoreFile(
     const String *repoFile, unsigned int repoIdx, CompressType repoFileCompressType, time_t copyTimeBegin, bool delta,
-    bool deltaForce, const String *cipherPass, const StringList *referenceList, List *fileList);
+    bool deltaForce, bool bundleRaw, const String *cipherPass, const StringList *referenceList, List *fileList);
 
 #endif
