@@ -10,6 +10,12 @@ Compression Helper Internal
 Functions
 ***********************************************************************************************************************************/
 // Default compression level for a compression type, used while loading the configuration
-int compressLevelDefault(CompressType type);
+FN_EXTERN int compressLevelDefault(CompressType type);
+
+// Minimum compression level for a compression type, used while loading the configuration
+FN_EXTERN int compressLevelMin(CompressType type);
+
+// Maximum compression level for a compression type, used while loading the configuration
+FN_EXTERN int compressLevelMax(CompressType type);
 
 #endif
