@@ -11,7 +11,7 @@ LZ4 Common
 #include "common/debug.h"
 
 /**********************************************************************************************************************************/
-LZ4F_errorCode_t
+FN_EXTERN LZ4F_errorCode_t
 lz4Error(LZ4F_errorCode_t error)
 {
     FUNCTION_TEST_BEGIN();
