@@ -58,10 +58,10 @@ fdReadyRetry(int pollResult, int errNo, bool first, TimeMSec *timeout, TimeMSec
         }
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(BOOL, result);
 }
 
-bool
+FN_EXTERN bool
 fdReady(int fd, bool read, bool write, TimeMSec timeout)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
