@@ -12,10 +12,10 @@ Read from a file descriptor using the IoRead interface.
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoRead *ioFdReadNew(const String *name, int fd, TimeMSec timeout);
+FN_EXTERN IoRead *ioFdReadNew(const String *name, int fd, TimeMSec timeout);
 
 // Construct and open read fd
-__attribute__((always_inline)) static inline IoRead *
+FN_INLINE_ALWAYS IoRead *
 ioFdReadNewOpen(const String *const name, const int fd, const TimeMSec timeout)
 {
     IoRead *const result = ioFdReadNew(name, fd, timeout);
