@@ -17,6 +17,6 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *ioSinkNew(void);
+FN_EXTERN IoFilter *ioSinkNew(void);
 
 #endif
