@@ -17,6 +17,6 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *ioSizeNew(void);
+FN_EXTERN IoFilter *ioSizeNew(void);
 
 #endif
