@@ -14,10 +14,12 @@ Convert the time using the format specified in https://tools.ietf.org/html/rfc72
 only version we support).
 ***********************************************************************************************************************************/
 static const char *const httpCommonMonthList[] =
-    {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
+{
+    "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
+};
 static const char *const httpCommonDayList[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
 
-time_t
+FN_EXTERN time_t
 httpDateToTime(const String *const lastModified)
 {
     FUNCTION_TEST_BEGIN();
@@ -46,7 +48,7 @@ httpDateToTime(const String *const lastModified)
             cvtZSubNToInt(strZ(lastModified), 23, 2), 0));
 }
 
-String *
+FN_EXTERN String *
 httpDateFromTime(const time_t time)
 {
     FUNCTION_TEST_BEGIN();
@@ -65,7 +67,7 @@ httpDateFromTime(const time_t time)
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 httpUriDecode(const String *const uri)
 {
     FUNCTION_TEST_BEGIN();
@@ -106,7 +108,7 @@ httpUriDecode(const String *const uri)
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 httpUriEncode(const String *uri, bool path)
 {
     FUNCTION_TEST_BEGIN();
