@@ -17,41 +17,41 @@ typedef struct HttpHeader HttpHeader;
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-HttpHeader *httpHeaderNew(const StringList *redactList);
-HttpHeader *httpHeaderDup(const HttpHeader *header, const StringList *redactList);
+FN_EXTERN HttpHeader *httpHeaderNew(const StringList *redactList);
+FN_EXTERN HttpHeader *httpHeaderDup(const HttpHeader *header, const StringList *redactList);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Add a header
-HttpHeader *httpHeaderAdd(HttpHeader *this, const String *key, const String *value);
+FN_EXTERN HttpHeader *httpHeaderAdd(HttpHeader *this, const String *key, const String *value);
 
 // Get a value using the key
-const String *httpHeaderGet(const HttpHeader *this, const String *key);
+FN_EXTERN const String *httpHeaderGet(const HttpHeader *this, const String *key);
 
 // Get list of keys
-StringList *httpHeaderList(const HttpHeader *this);
+FN_EXTERN StringList *httpHeaderList(const HttpHeader *this);
 
 // Move to a new parent mem context
-__attribute__((always_inline)) static inline HttpHeader *
+FN_INLINE_ALWAYS HttpHeader *
 httpHeaderMove(HttpHeader *const this, MemContext *const parentNew)
 {
     return objMove(this, parentNew);
 }
 
 // Put a header
-HttpHeader *httpHeaderPut(HttpHeader *this, const String *header, const String *value);
+FN_EXTERN HttpHeader *httpHeaderPut(HttpHeader *this, const String *header, const String *value);
 
 // Put range header when needed
-HttpHeader *httpHeaderPutRange(HttpHeader *this, uint64_t offset, const Variant *limit);
+FN_EXTERN HttpHeader *httpHeaderPutRange(HttpHeader *this, uint64_t offset, const Variant *limit);
 
 // Should the header be redacted when logging?
-bool httpHeaderRedact(const HttpHeader *this, const String *key);
+FN_EXTERN bool httpHeaderRedact(const HttpHeader *this, const String *key);
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 httpHeaderFree(HttpHeader *const this)
 {
     objFree(this);
@@ -60,11 +60,11 @@ httpHeaderFree(HttpHeader *const this)
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *httpHeaderToLog(const HttpHeader *this);
+FN_EXTERN void httpHeaderToLog(const HttpHeader *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_HTTP_HEADER_TYPE                                                                                              \
     HttpHeader *
 #define FUNCTION_LOG_HTTP_HEADER_FORMAT(value, buffer, bufferSize)                                                                 \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, httpHeaderToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, httpHeaderToLog, buffer, bufferSize)
 
 #endif
