@@ -26,10 +26,10 @@ typedef struct HttpQueryNewParam
 #define httpQueryNewP(...)                                                                                                         \
     httpQueryNew((HttpQueryNewParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-HttpQuery *httpQueryNew(HttpQueryNewParam param);
+FN_EXTERN HttpQuery *httpQueryNew(HttpQueryNewParam param);
 
 // New from encoded query string
-HttpQuery *httpQueryNewStr(const String *query);
+FN_EXTERN HttpQuery *httpQueryNewStr(const String *query);
 
 // Duplicate
 typedef struct HttpQueryDupParam
@@ -41,35 +41,35 @@ typedef struct HttpQueryDupParam
 #define httpQueryDupP(query, ...)                                                                                                  \
     httpQueryDup(query, (HttpQueryDupParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-HttpQuery *httpQueryDup(const HttpQuery *query, HttpQueryDupParam param);
+FN_EXTERN HttpQuery *httpQueryDup(const HttpQuery *query, HttpQueryDupParam param);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Add a query item
-HttpQuery *httpQueryAdd(HttpQuery *this, const String *key, const String *value);
+FN_EXTERN HttpQuery *httpQueryAdd(HttpQuery *this, const String *key, const String *value);
 
 // Get a value using the key
-const String *httpQueryGet(const HttpQuery *this, const String *key);
+FN_EXTERN const String *httpQueryGet(const HttpQuery *this, const String *key);
 
 // Get list of keys
-StringList *httpQueryList(const HttpQuery *this);
+FN_EXTERN StringList *httpQueryList(const HttpQuery *this);
 
 // Merge the contents of another query into this one
-HttpQuery *httpQueryMerge(HttpQuery *this, const HttpQuery *query);
+FN_EXTERN HttpQuery *httpQueryMerge(HttpQuery *this, const HttpQuery *query);
 
 // Move to a new parent mem context
-__attribute__((always_inline)) static inline HttpQuery *
+FN_INLINE_ALWAYS HttpQuery *
 httpQueryMove(HttpQuery *const this, MemContext *const parentNew)
 {
     return objMove(this, parentNew);
 }
 
 // Put a query item
-HttpQuery *httpQueryPut(HttpQuery *this, const String *header, const String *value);
+FN_EXTERN HttpQuery *httpQueryPut(HttpQuery *this, const String *header, const String *value);
 
 // Should the query key be redacted when logging?
-bool httpQueryRedact(const HttpQuery *this, const String *key);
+FN_EXTERN bool httpQueryRedact(const HttpQuery *this, const String *key);
 
 // Render the query for inclusion in an HTTP request
 typedef struct HttpQueryRenderParam
@@ -81,12 +81,12 @@ typedef struct HttpQueryRenderParam
 #define httpQueryRenderP(this, ...)                                                                                                \
     httpQueryRender(this, (HttpQueryRenderParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-String *httpQueryRender(const HttpQuery *this, HttpQueryRenderParam param);
+FN_EXTERN String *httpQueryRender(const HttpQuery *this, HttpQueryRenderParam param);
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 httpQueryFree(HttpQuery *const this)
 {
     objFree(this);
@@ -95,11 +95,11 @@ httpQueryFree(HttpQuery *const this)
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *httpQueryToLog(const HttpQuery *this);
+FN_EXTERN void httpQueryToLog(const HttpQuery *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_HTTP_QUERY_TYPE                                                                                               \
     HttpQuery *
 #define FUNCTION_LOG_HTTP_QUERY_FORMAT(value, buffer, bufferSize)                                                                  \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, httpQueryToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, httpQueryToLog, buffer, bufferSize)
 
 #endif
