@@ -23,14 +23,14 @@ typedef struct IoRead IoRead;
 Getters/Setters
 ***********************************************************************************************************************************/
 // Do reads block when more bytes are requested than are available to read?
-__attribute__((always_inline)) static inline bool
+FN_INLINE_ALWAYS bool
 ioReadBlock(const IoRead *const this)
 {
     return THIS_PUB(IoRead)->interface.block;
 }
 
 // Is IO at EOF? All driver reads are complete and all data has been flushed from the filters (if any).
-__attribute__((always_inline)) static inline bool
+FN_INLINE_ALWAYS bool
 ioReadEof(const IoRead *const this)
 {
     ASSERT_INLINE(THIS_PUB(IoRead)->opened && !THIS_PUB(IoRead)->closed);
@@ -38,37 +38,40 @@ ioReadEof(const IoRead *const this)
 }
 
 // Get filter group if filters need to be added
-__attribute__((always_inline)) static inline IoFilterGroup *
+FN_INLINE_ALWAYS IoFilterGroup *
 ioReadFilterGroup(IoRead *const this)
 {
     return THIS_PUB(IoRead)->filterGroup;
 }
 
 // File descriptor for the read object. Not all read objects have a file descriptor and -1 will be returned in that case.
-int ioReadFd(const IoRead *this);
+FN_EXTERN int ioReadFd(const IoRead *this);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Open the IO
-bool ioReadOpen(IoRead *this);
+FN_EXTERN bool ioReadOpen(IoRead *this);
 
 // Read data from IO and process filters
-size_t ioRead(IoRead *this, Buffer *buffer);
+FN_EXTERN size_t ioRead(IoRead *this, Buffer *buffer);
 
 // Same as ioRead() but optimized for small reads (intended for making repetitive reads that are smaller than ioBufferSize())
-size_t ioReadSmall(IoRead *this, Buffer *buffer);
+FN_EXTERN size_t ioReadSmall(IoRead *this, Buffer *buffer);
 
 // Read linefeed-terminated string and optionally error on eof
-String *ioReadLineParam(IoRead *this, bool allowEof);
+FN_EXTERN String *ioReadLineParam(IoRead *this, bool allowEof);
 
 // Read linefeed-terminated string
-__attribute__((always_inline)) static inline String *
+FN_INLINE_ALWAYS String *
 ioReadLine(IoRead *const this)
 {
     return ioReadLineParam(this, false);
 }
 
+// Read varint-128 encoding
+FN_EXTERN uint64_t ioReadVarIntU64(IoRead *this);
+
 // Are there bytes ready to read immediately? There are no guarantees on how much data is available to read but it must be at least
 // one byte.
 typedef struct IoReadReadyParam
@@ -80,15 +83,15 @@ typedef struct IoReadReadyParam
 #define ioReadReadyP(this, ...)                                                                                                    \
     ioReadReady(this, (IoReadReadyParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-bool ioReadReady(IoRead *this, IoReadReadyParam param);
+FN_EXTERN bool ioReadReady(IoRead *this, IoReadReadyParam param);
 
 // Close the IO
-void ioReadClose(IoRead *this);
+FN_EXTERN void ioReadClose(IoRead *this);
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 ioReadFree(IoRead *const this)
 {
     objFreeContext(this);
@@ -100,6 +103,6 @@ Macros for function logging
 #define FUNCTION_LOG_IO_READ_TYPE                                                                                                  \
     IoRead *
 #define FUNCTION_LOG_IO_READ_FORMAT(value, buffer, bufferSize)                                                                     \
-    objToLog(value, "IoRead", buffer, bufferSize)
+    objNameToLog(value, "IoRead", buffer, bufferSize)
 
 #endif
