@@ -41,24 +41,33 @@ typedef struct IoSessionPub
 } IoSessionPub;
 
 // Is the session authenticated? The exact meaning of "authenticated" will vary by driver type.
-__attribute__((always_inline)) static inline bool
+FN_INLINE_ALWAYS bool
 ioSessionAuthenticated(const IoSession *const this)
 {
     return THIS_PUB(IoSession)->authenticated;
 }
 
 // Session file descriptor, -1 if none
-int ioSessionFd(IoSession *this);
+FN_EXTERN int ioSessionFd(IoSession *this);
 
 // Read interface
-__attribute__((always_inline)) static inline IoRead *
-ioSessionIoRead(IoSession *const this)
+typedef struct IoSessionIoReadParam
 {
-    return THIS_PUB(IoSession)->interface->ioRead(THIS_PUB(IoSession)->driver);
+    VAR_PARAM_HEADER;
+    bool ignoreUnexpectedEof;                                       // Allow unexpected EOF, e.g. TLS session improperly terminated
+} IoSessionIoReadParam;
+
+#define ioSessionIoReadP(this, ...)                                                                                                \
+    ioSessionIoRead(this, (IoSessionIoReadParam){VAR_PARAM_INIT, __VA_ARGS__})
+
+FN_INLINE_ALWAYS IoRead *
+ioSessionIoRead(IoSession *const this, const IoSessionIoReadParam param)
+{
+    return THIS_PUB(IoSession)->interface->ioRead(THIS_PUB(IoSession)->driver, param.ignoreUnexpectedEof);
 }
 
 // Write interface
-__attribute__((always_inline)) static inline IoWrite *
+FN_INLINE_ALWAYS IoWrite *
 ioSessionIoWrite(IoSession *const this)
 {
     return THIS_PUB(IoSession)->interface->ioWrite(THIS_PUB(IoSession)->driver);
@@ -66,14 +75,14 @@ ioSessionIoWrite(IoSession *const this)
 
 // The peer name, if any. The exact meaning will vary by driver type, for example the peer name will be the client CN for the
 // TlsSession driver.
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 ioSessionPeerName(const IoSession *const this)
 {
     return THIS_PUB(IoSession)->peerName;
 }
 
 // Session role
-__attribute__((always_inline)) static inline IoSessionRole
+FN_INLINE_ALWAYS IoSessionRole
 ioSessionRole(const IoSession *const this)
 {
     return THIS_PUB(IoSession)->interface->role(THIS_PUB(IoSession)->driver);
@@ -83,14 +92,14 @@ ioSessionRole(const IoSession *const this)
 Functions
 ***********************************************************************************************************************************/
 // Close the session
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 ioSessionClose(IoSession *const this)
 {
     return THIS_PUB(IoSession)->interface->close(THIS_PUB(IoSession)->driver);
 }
 
 // Move to a new parent mem context
-__attribute__((always_inline)) static inline IoSession *
+FN_INLINE_ALWAYS IoSession *
 ioSessionMove(IoSession *const this, MemContext *const parentNew)
 {
     return objMoveContext(this, parentNew);
@@ -99,7 +108,7 @@ ioSessionMove(IoSession *const this, MemContext *const parentNew)
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 ioSessionFree(IoSession *const this)
 {
     objFreeContext(this);
@@ -108,11 +117,11 @@ ioSessionFree(IoSession *const this)
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *ioSessionToLog(const IoSession *this);
+FN_EXTERN void ioSessionToLog(const IoSession *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_IO_SESSION_TYPE                                                                                               \
     IoSession *
 #define FUNCTION_LOG_IO_SESSION_FORMAT(value, buffer, bufferSize)                                                                  \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, ioSessionToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, ioSessionToLog, buffer, bufferSize)
 
 #endif
