@@ -18,8 +18,8 @@ header by doing some pointer arithmetic. This is much faster than searching thro
 ***********************************************************************************************************************************/
 typedef struct MemContextAlloc
 {
-    unsigned int allocIdx:32;                                       // Index in the allocation list
-    unsigned int size:32;                                           // Allocation size (4GB max)
+    unsigned int allocIdx : 32;                                     // Index in the allocation list
+    unsigned int size : 32;                                         // Allocation size (4GB max)
 } MemContextAlloc;
 
 // Get the allocation buffer pointer given the allocation header pointer
@@ -52,15 +52,16 @@ struct MemContext
 {
 #ifdef DEBUG
     const char *name;                                               // Indicates what the context is being used for
-    bool active:1;                                                  // Is the context currently active?
+    uint64_t sequenceNew;                                           // Sequence when this context was created (used for audit)
+    bool active : 1;                                                // Is the context currently active?
 #endif
-    MemQty childQty:2;                                              // How many child contexts can this context have?
-    bool childInitialized:1;                                        // Has the child context list been initialized?
-    MemQty allocQty:2;                                              // How many allocations can this context have?
-    bool allocInitialized:1;                                        // Has the allocation list been initialized?
-    MemQty callbackQty:2;                                           // How many callbacks can this context have?
-    bool callbackInitialized:1;                                     // Has the callback been initialized?
-    size_t allocExtra:16;                                           // Size of extra allocation (1kB max)
+    MemQty childQty : 2;                                            // How many child contexts can this context have?
+    bool childInitialized : 1;                                      // Has the child context list been initialized?
+    MemQty allocQty : 2;                                            // How many allocations can this context have?
+    bool allocInitialized : 1;                                      // Has the allocation list been initialized?
+    MemQty callbackQty : 2;                                         // How many callbacks can this context have?
+    bool callbackInitialized : 1;                                   // Has the callback been initialized?
+    size_t allocExtra : 16;                                         // Size of extra allocation (1kB max)
 
     unsigned int contextParentIdx;                                  // Index in the parent context list
     MemContext *contextParent;                                      // All contexts have a parent except top
@@ -102,8 +103,9 @@ typedef struct MemContextCallbackOne
 } MemContextCallbackOne;
 
 /***********************************************************************************************************************************
-Possible sizes for the manifest based on options. Formatting has been compressed to save space.
+Possible sizes for the manifest based on options
 ***********************************************************************************************************************************/
+// {uncrustify_off - formatting compressed to save space}
 static const uint8_t memContextSizePossible[memQtyMany + 1][memQtyMany + 1][memQtyOne + 1] =
 {
     // child none
@@ -136,6 +138,7 @@ static const uint8_t memContextSizePossible[memQtyMany + 1][memQtyMany + 1][memQ
      {/* callback none */ sizeof(MemContextChildMany) + sizeof(MemContextAllocMany),
       /* callback one */ sizeof(MemContextChildMany) + sizeof(MemContextAllocMany) + sizeof(MemContextCallbackOne)}},
 };
+// {uncrustify_on}
 
 /***********************************************************************************************************************************
 Get pointers to optional parts of the manifest
@@ -176,8 +179,9 @@ static MemContextCallbackOne *
 memContextCallbackOne(MemContext *const memContext)
 {
     return
-        (MemContextCallbackOne *)((unsigned char *)(memContext + 1) +
-            memContextSizePossible[memContext->childQty][memContext->allocQty][0] + memContext->allocExtra);
+        (MemContextCallbackOne *)
+        ((unsigned char *)(memContext + 1) +
+         memContextSizePossible[memContext->childQty][memContext->allocQty][0] + memContext->allocExtra);
 }
 
 /***********************************************************************************************************************************
@@ -228,6 +232,165 @@ static struct MemContextStack
 static unsigned int memContextCurrentStackIdx = 0;
 static unsigned int memContextMaxStackIdx = 0;
 
+/***********************************************************************************************************************************
+***********************************************************************************************************************************/
+#ifdef DEBUG
+
+static uint64_t memContextSequence = 0;
+
+FN_EXTERN void
+memContextAuditBegin(MemContextAuditState *const state)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, state);
+    FUNCTION_TEST_END();
+
+    ASSERT(state != NULL);
+    ASSERT(state->memContext != NULL);
+    ASSERT(state->memContext == memContextTop() || state->memContext->sequenceNew != 0);
+
+    if (state->memContext->childInitialized)
+    {
+        ASSERT(state->memContext->childQty != memQtyNone);
+
+        if (state->memContext->childQty == memQtyOne)
+        {
+            MemContextChildOne *const memContextChild = memContextChildOne(state->memContext);
+
+            if (memContextChild->context != NULL)
+                state->sequenceContextNew = memContextChild->context->sequenceNew;
+        }
+        else
+        {
+            ASSERT(state->memContext->childQty == memQtyMany);
+            MemContextChildMany *const memContextChild = memContextChildMany(state->memContext);
+
+            for (unsigned int contextIdx = 0; contextIdx < memContextChild->listSize; contextIdx++)
+            {
+                if (memContextChild->list[contextIdx] != NULL &&
+                    memContextChild->list[contextIdx]->sequenceNew > state->sequenceContextNew)
+                {
+                    state->sequenceContextNew = memContextChild->list[contextIdx]->sequenceNew;
+                }
+            }
+        }
+    }
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+static bool
+memContextAuditNameMatch(const char *const actual, const char *const expected)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, actual);
+        FUNCTION_TEST_PARAM(STRINGZ, expected);
+    FUNCTION_TEST_END();
+
+    ASSERT(actual != NULL);
+    ASSERT(expected != NULL);
+
+    unsigned int actualIdx = 0;
+
+    while (actual[actualIdx] != '\0' && actual[actualIdx] == expected[actualIdx])
+        actualIdx++;
+
+    FUNCTION_TEST_RETURN(
+        BOOL,
+        (actual[actualIdx] == '\0' || strncmp(actual + actualIdx, "::", 2) == 0) &&
+        (expected[actualIdx] == '\0' || strcmp(expected + actualIdx, " *") == 0));
+}
+
+FN_EXTERN void
+memContextAuditEnd(const MemContextAuditState *const state, const char *const returnType)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, state);
+        FUNCTION_TEST_PARAM(STRINGZ, returnType);
+    FUNCTION_TEST_END();
+
+    if (state->returnTypeAny)
+        FUNCTION_TEST_RETURN_VOID();
+
+    if (state->memContext->childInitialized)
+    {
+        ASSERT(state->memContext->childQty != memQtyNone);
+
+        const char *returnTypeInvalid = NULL;
+        const char *returnTypeFound = NULL;
+
+        if (state->memContext->childQty == memQtyOne)
+        {
+            MemContextChildOne *const memContextChild = memContextChildOne(state->memContext);
+
+            if (memContextChild->context != NULL && memContextChild->context->sequenceNew > state->sequenceContextNew &&
+                !memContextAuditNameMatch(memContextChild->context->name, returnType))
+            {
+                returnTypeInvalid = memContextChild->context->name;
+            }
+        }
+        else
+        {
+            ASSERT(state->memContext->childQty == memQtyMany);
+            MemContextChildMany *const memContextChild = memContextChildMany(state->memContext);
+
+            for (unsigned int contextIdx = 0; contextIdx < memContextChild->listSize; contextIdx++)
+            {
+                if (memContextChild->list[contextIdx] != NULL &&
+                    memContextChild->list[contextIdx]->sequenceNew > state->sequenceContextNew)
+                {
+                    if (memContextAuditNameMatch(memContextChild->list[contextIdx]->name, returnType))
+                    {
+                        if (returnTypeFound != NULL)
+                        {
+                            returnTypeInvalid = memContextChild->list[contextIdx]->name;
+                            break;
+                        }
+
+                        returnTypeFound = memContextChild->list[contextIdx]->name;
+                    }
+                    else
+                    {
+                        returnTypeInvalid = memContextChild->list[contextIdx]->name;
+                        break;
+                    }
+                }
+            }
+        }
+
+        if (returnTypeInvalid != NULL)
+        {
+            if (returnTypeFound != NULL)
+            {
+                THROW_FMT(
+                    AssertError, "expected return type '%s' already found but also found '%s'", returnTypeFound, returnTypeInvalid);
+            }
+            else
+            {
+                THROW_FMT(
+                    AssertError, "expected return type '%s' but found '%s'", returnType, returnTypeInvalid);
+            }
+        }
+    }
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+FN_EXTERN void *
+memContextAuditAllocExtraName(void *const allocExtra, const char *const name)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, allocExtra);
+        FUNCTION_TEST_PARAM(STRINGZ, name);
+    FUNCTION_TEST_END();
+
+    memContextFromAllocExtra(allocExtra)->name = name;
+
+    FUNCTION_TEST_RETURN_P(VOID, allocExtra);
+}
+
+#endif
+
 /***********************************************************************************************************************************
 Wrapper around malloc() with error handling
 ***********************************************************************************************************************************/
@@ -386,7 +549,7 @@ memContextNewIndex(MemContext *const memContext, MemContextChildMany *const memC
 }
 
 /**********************************************************************************************************************************/
-MemContext *
+FN_EXTERN MemContext *
 memContextNew(
 #ifdef DEBUG
     const char *const name,
@@ -432,6 +595,9 @@ memContextNew(
         // Set the context name
         .name = name,
 
+        // Set audit sequence
+        .sequenceNew = ++memContextSequence,
+
         // Set new context active
         .active = true,
 #endif
@@ -482,7 +648,7 @@ memContextNew(
 }
 
 /**********************************************************************************************************************************/
-void *
+FN_EXTERN void *
 memContextAllocExtra(MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
@@ -496,7 +662,7 @@ memContextAllocExtra(MemContext *const this)
 }
 
 /**********************************************************************************************************************************/
-MemContext *
+FN_EXTERN MemContext *
 memContextFromAllocExtra(void *const allocExtra)
 {
     FUNCTION_TEST_BEGIN();
@@ -509,21 +675,8 @@ memContextFromAllocExtra(void *const allocExtra)
     FUNCTION_TEST_RETURN(MEM_CONTEXT, (MemContext *)allocExtra - 1);
 }
 
-const MemContext *
-memContextConstFromAllocExtra(const void *const allocExtra)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM_P(VOID, allocExtra);
-    FUNCTION_TEST_END();
-
-    ASSERT(allocExtra != NULL);
-    ASSERT(((MemContext *)allocExtra - 1)->allocExtra != 0);
-
-    FUNCTION_TEST_RETURN(MEM_CONTEXT, (MemContext *)allocExtra - 1);
-}
-
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *callbackArgument)
 {
     FUNCTION_TEST_BEGIN();
@@ -552,7 +705,7 @@ memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextCallbackClear(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -686,7 +839,7 @@ memContextAllocResize(MemContextAlloc *alloc, size_t size)
 }
 
 /**********************************************************************************************************************************/
-void *
+FN_EXTERN void *
 memNew(size_t size)
 {
     FUNCTION_TEST_BEGIN();
@@ -699,7 +852,7 @@ memNew(size_t size)
 }
 
 /**********************************************************************************************************************************/
-void *
+FN_EXTERN void *
 memNewPtrArray(size_t size)
 {
     FUNCTION_TEST_BEGIN();
@@ -717,7 +870,7 @@ memNewPtrArray(size_t size)
 }
 
 /**********************************************************************************************************************************/
-void *
+FN_EXTERN void *
 memResize(const void *buffer, size_t size)
 {
     FUNCTION_TEST_BEGIN();
@@ -729,7 +882,7 @@ memResize(const void *buffer, size_t size)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memFree(void *const buffer)
 {
     FUNCTION_TEST_BEGIN();
@@ -770,7 +923,7 @@ memFree(void *const buffer)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextMove(MemContext *this, MemContext *parentNew)
 {
     FUNCTION_TEST_BEGIN();
@@ -831,7 +984,7 @@ memContextMove(MemContext *this, MemContext *parentNew)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextSwitch(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -857,7 +1010,7 @@ memContextSwitch(MemContext *this)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextSwitchBack(void)
 {
     FUNCTION_TEST_VOID();
@@ -888,7 +1041,7 @@ memContextSwitchBack(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextKeep(void)
 {
     FUNCTION_TEST_VOID();
@@ -909,7 +1062,7 @@ memContextKeep(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 memContextDiscard(void)
 {
     FUNCTION_TEST_VOID();
@@ -931,7 +1084,7 @@ memContextDiscard(void)
 }
 
 /**********************************************************************************************************************************/
-MemContext *
+FN_EXTERN MemContext *
 memContextTop(void)
 {
     FUNCTION_TEST_VOID();
@@ -939,7 +1092,7 @@ memContextTop(void)
 }
 
 /**********************************************************************************************************************************/
-MemContext *
+FN_EXTERN MemContext *
 memContextCurrent(void)
 {
     FUNCTION_TEST_VOID();
@@ -947,7 +1100,7 @@ memContextCurrent(void)
 }
 
 /**********************************************************************************************************************************/
-MemContext *
+FN_EXTERN MemContext *
 memContextPrior(void)
 {
     FUNCTION_TEST_VOID();
@@ -963,7 +1116,9 @@ memContextPrior(void)
 }
 
 /**********************************************************************************************************************************/
-size_t
+#ifdef DEBUG
+
+FN_EXTERN size_t
 memContextSize(const MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1046,12 +1201,15 @@ memContextSize(const MemContext *const this)
     FUNCTION_TEST_RETURN(SIZE, (size_t)(offset - (unsigned char *)this) + total);
 }
 
+#endif // DEBUG
+
 /**********************************************************************************************************************************/
-void
-memContextClean(unsigned int tryDepth)
+FN_EXTERN void
+memContextClean(const unsigned int tryDepth, const bool fatal)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(UINT, tryDepth);
+        FUNCTION_TEST_PARAM(BOOL, false);
     FUNCTION_TEST_END();
 
     ASSERT(tryDepth > 0);
@@ -1059,10 +1217,12 @@ memContextClean(unsigned int tryDepth)
     // Iterate through everything pushed to the stack since the last try
     while (memContextStack[memContextMaxStackIdx].tryDepth >= tryDepth)
     {
-        // Free memory contexts that were not kept
+        // Free memory contexts that were not kept. Skip this for fatal errors to avoid calling destructors that could error and
+        // mask the original error.
         if (memContextStack[memContextMaxStackIdx].type == memContextStackTypeNew)
         {
-            memContextFree(memContextStack[memContextMaxStackIdx].memContext);
+            if (!fatal)
+                memContextFree(memContextStack[memContextMaxStackIdx].memContext);
         }
         // Else find the prior context and make it the current context
         else
@@ -1234,7 +1394,7 @@ memContextFreeRecurse(MemContext *const this)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-void
+FN_EXTERN void
 memContextFree(MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
