@@ -22,32 +22,32 @@ Constants describing number of sub-units in an interval
 Functions
 ***********************************************************************************************************************************/
 // Sleep for specified milliseconds
-void sleepMSec(TimeMSec sleepMSec);
+FN_EXTERN void sleepMSec(TimeMSec sleepMSec);
 
 // Epoch time in milliseconds
-TimeMSec timeMSec(void);
+FN_EXTERN TimeMSec timeMSec(void);
 
 // Are the date parts valid? (year >= 1970, month 1-12, day 1-31)
-void datePartsValid(int year, int month, int day);
+FN_EXTERN void datePartsValid(int year, int month, int day);
 
 // Are the time parts valid?
-void timePartsValid(int hour, int minute, int second);
+FN_EXTERN void timePartsValid(int hour, int minute, int second);
 
 // Are the timezone offset parts valid?
-void tzPartsValid(int tzHour, int tzMinute);
+FN_EXTERN void tzPartsValid(int tzHour, int tzMinute);
 
 // Given the hours, minutes and sign of a time zone (e.g. -0700 => -7, 0) return the signed number or seconds (e.g. -25200)
-int tzOffsetSeconds(int tzHour, int tzMinute);
+FN_EXTERN int tzOffsetSeconds(int tzHour, int tzMinute);
 
 // Is the year a leap year?
-bool yearIsLeap(int year);
+FN_EXTERN bool yearIsLeap(int year);
 
 // Get days since the beginning of the year (year >= 1970, month 1-12, day 1-31), returns 1-366
-int dayOfYear(int year, int month, int day);
+FN_EXTERN int dayOfYear(int year, int month, int day);
 
 // Return epoch time from date/time parts (year >= 1970, month 1-12, day 1-31, hour 0-23, minute 0-59, second 0-59, tzOffsetSecond
 // is the number of seconds plus or minus (+/-) the provided time - if 0, then the datetime is assumed to be UTC)
-time_t epochFromParts(int year, int month, int day, int hour, int minute, int second, int tzOffsetSecond);
+FN_EXTERN time_t epochFromParts(int year, int month, int day, int hour, int minute, int second, int tzOffsetSecond);
 
 /***********************************************************************************************************************************
 Macros for function logging
