@@ -12,6 +12,7 @@ Convert C Types
 #include <time.h>
 
 #include "common/debug.h"
+#include "common/macro.h"
 #include "common/type/convert.h"
 
 /***********************************************************************************************************************************
@@ -62,7 +63,7 @@ cvtZToInt64Internal(const char *value, const char *type, int base)
     // Validate the result
     cvtZToIntValid(errno, base, value, endPtr, type);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(INT64, result);
 }
 
 /***********************************************************************************************************************************
@@ -87,11 +88,11 @@ cvtZToUInt64Internal(const char *value, const char *type, int base)
     // Validate the result
     cvtZToIntValid(errno, base, value, endPtr, type);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtBoolToZ(bool value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -107,37 +108,17 @@ cvtBoolToZ(bool value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-const char *
+FN_EXTERN const char *
 cvtBoolToConstZ(bool value)
 {
     return value ? TRUE_Z : FALSE_Z;
 }
 
 /**********************************************************************************************************************************/
-size_t
-cvtCharToZ(char value, char *buffer, size_t bufferSize)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(BOOL, value);
-        FUNCTION_TEST_PARAM_P(CHARDATA, buffer);
-        FUNCTION_TEST_PARAM(SIZE, bufferSize);
-    FUNCTION_TEST_END();
-
-    ASSERT(buffer != NULL);
-
-    size_t result = (size_t)snprintf(buffer, bufferSize, "%c", value);
-
-    if (result >= bufferSize)
-        THROW(AssertError, "buffer overflow");
-
-    FUNCTION_TEST_RETURN(result);
-}
-
-/**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtDoubleToZ(double value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -177,10 +158,10 @@ cvtDoubleToZ(double value, char *buffer, size_t bufferSize)
     end[1] = 0;
 
     // Return string length
-    FUNCTION_TEST_RETURN((size_t)(end - buffer + 1));
+    FUNCTION_TEST_RETURN(SIZE, (size_t)(end - buffer + 1));
 }
 
-double
+FN_EXTERN double
 cvtZToDouble(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -195,11 +176,11 @@ cvtZToDouble(const char *value)
     if (result == 0 && strcmp(value, "0") != 0)
         THROW_FMT(FormatError, "unable to convert string '%s' to double", value);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(DOUBLE, result);
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtIntToZ(int value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -215,10 +196,10 @@ cvtIntToZ(int value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-int
+FN_EXTERN int
 cvtZToIntBase(const char *value, int base)
 {
     FUNCTION_TEST_BEGIN();
@@ -232,10 +213,10 @@ cvtZToIntBase(const char *value, int base)
     if (result > INT_MAX || result < INT_MIN)
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to int", base, value);
 
-    FUNCTION_TEST_RETURN((int)result);
+    FUNCTION_TEST_RETURN(INT, (int)result);
 }
 
-int
+FN_EXTERN int
 cvtZToInt(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -244,11 +225,31 @@ cvtZToInt(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToIntBase(value, 10));
+    FUNCTION_TEST_RETURN(INT, cvtZToIntBase(value, 10));
+}
+
+FN_EXTERN int
+cvtZSubNToIntBase(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    memcpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(INT, cvtZToIntBase(buffer, base));
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtInt64ToZ(int64_t value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -264,10 +265,10 @@ cvtInt64ToZ(int64_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-int64_t
+FN_EXTERN int64_t
 cvtZToInt64Base(const char *value, int base)
 {
     FUNCTION_TEST_BEGIN();
@@ -276,10 +277,10 @@ cvtZToInt64Base(const char *value, int base)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToInt64Internal(value, "int64", base));
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Internal(value, "int64", base));
 }
 
-int64_t
+FN_EXTERN int64_t
 cvtZToInt64(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -288,11 +289,31 @@ cvtZToInt64(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToInt64Base(value, 10));
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Base(value, 10));
+}
+
+FN_EXTERN int64_t
+cvtZSubNToInt64Base(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    memcpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Base(buffer, base));
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtModeToZ(mode_t value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -308,10 +329,10 @@ cvtModeToZ(mode_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-mode_t
+FN_EXTERN mode_t
 cvtZToMode(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -320,11 +341,11 @@ cvtZToMode(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN((mode_t)cvtZToUIntBase(value, 8));
+    FUNCTION_TEST_RETURN(MODE, (mode_t)cvtZToUIntBase(value, 8));
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtSizeToZ(size_t value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -340,30 +361,11 @@ cvtSizeToZ(size_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
-}
-
-size_t
-cvtSSizeToZ(ssize_t value, char *buffer, size_t bufferSize)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(SSIZE, value);
-        FUNCTION_TEST_PARAM_P(CHARDATA, buffer);
-        FUNCTION_TEST_PARAM(SIZE, bufferSize);
-    FUNCTION_TEST_END();
-
-    ASSERT(buffer != NULL);
-
-    size_t result = (size_t)snprintf(buffer, bufferSize, "%zd", value);
-
-    if (result >= bufferSize)
-        THROW(AssertError, "buffer overflow");
-
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtTimeToZ(time_t value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -380,11 +382,11 @@ cvtTimeToZ(time_t value, char *buffer, size_t bufferSize)
     if (result == 0)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtUIntToZ(unsigned int value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -400,10 +402,10 @@ cvtUIntToZ(unsigned int value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-unsigned int
+FN_EXTERN unsigned int
 cvtZToUIntBase(const char *value, int base)
 {
     FUNCTION_TEST_BEGIN();
@@ -418,10 +420,10 @@ cvtZToUIntBase(const char *value, int base)
     if (*value == '-' || result > UINT_MAX)
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to unsigned int", base, value);
 
-    FUNCTION_TEST_RETURN((unsigned int)result);
+    FUNCTION_TEST_RETURN(UINT, (unsigned int)result);
 }
 
-unsigned int
+FN_EXTERN unsigned int
 cvtZToUInt(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -430,11 +432,31 @@ cvtZToUInt(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToUIntBase(value, 10));
+    FUNCTION_TEST_RETURN(UINT, cvtZToUIntBase(value, 10));
+}
+
+FN_EXTERN unsigned int
+cvtZSubNToUIntBase(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    memcpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(UINT, cvtZToUIntBase(buffer, base));
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 cvtUInt64ToZ(uint64_t value, char *buffer, size_t bufferSize)
 {
     FUNCTION_TEST_BEGIN();
@@ -450,10 +472,10 @@ cvtUInt64ToZ(uint64_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
-uint64_t
+FN_EXTERN uint64_t
 cvtZToUInt64Base(const char *value, int base)
 {
     FUNCTION_TEST_BEGIN();
@@ -468,10 +490,10 @@ cvtZToUInt64Base(const char *value, int base)
     if (*value == '-')
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to uint64", base, value);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
 
-uint64_t
+FN_EXTERN uint64_t
 cvtZToUInt64(const char *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -480,5 +502,107 @@ cvtZToUInt64(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToUInt64Base(value, 10));
+    FUNCTION_TEST_RETURN(UINT64, cvtZToUInt64Base(value, 10));
+}
+
+FN_EXTERN uint64_t
+cvtZSubNToUInt64Base(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    memcpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(UINT64, cvtZToUInt64Base(buffer, base));
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN void
+cvtUInt64ToVarInt128(uint64_t value, uint8_t *const buffer, size_t *const bufferPos, const size_t bufferSize)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT64, value);
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
+        FUNCTION_TEST_PARAM(UINT64, bufferSize);
+    FUNCTION_TEST_END();
+
+    ASSERT(buffer != NULL);
+    ASSERT(bufferPos != NULL);
+    ASSERT(bufferSize > *bufferPos);
+
+    // Keep encoding bytes while the remaining value is greater than 7 bits
+    while (value >= 0x80)
+    {
+        // Encode the lower order 7 bits, adding the continuation bit to indicate there is more data
+        buffer[*bufferPos] = (unsigned char)value | 0x80;
+
+        // Shift the value to remove bits that have been encoded
+        value >>= 7;
+
+        // Keep track of size so we know how many bytes to write out
+        (*bufferPos)++;
+
+        // Make sure the buffer won't overflow
+        if (*bufferPos >= bufferSize)
+            THROW(AssertError, "buffer overflow");
+    }
+
+    // Encode the last 7 bits of value
+    buffer[*bufferPos] = (unsigned char)value;
+    (*bufferPos)++;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+FN_EXTERN uint64_t
+cvtUInt64FromVarInt128(const uint8_t *const buffer, size_t *const bufferPos, const size_t bufferSize)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
+        FUNCTION_TEST_PARAM_P(SIZE, bufferPos);
+        FUNCTION_TEST_PARAM(SIZE, bufferSize);
+    FUNCTION_TEST_END();
+
+    ASSERT(buffer != NULL);
+    ASSERT(bufferPos != NULL);
+
+    // Decode all bytes
+    uint64_t result = 0;
+    uint8_t byte;
+
+    for (unsigned int bufferIdx = 0; bufferIdx < CVT_VARINT128_BUFFER_SIZE; bufferIdx++)
+    {
+        // Error if the buffer position is beyond the buffer size
+        if (*bufferPos >= bufferSize)
+            THROW(FormatError, "buffer position is beyond buffer size");
+
+        // Get the next encoded byte
+        byte = buffer[*bufferPos];
+
+        // Shift the lower order 7 encoded bits into the uint64 in reverse order
+        result |= (uint64_t)(byte & 0x7f) << (7 * bufferIdx);
+
+        // Increment buffer position to indicate that the byte has been processed
+        (*bufferPos)++;
+
+        // Done if the high order bit is not set to indicate more data
+        if (byte < 0x80)
+            break;
+    }
+
+    // By this point all bytes should have been read so error if this is not the case. This could be due to a coding error or
+    // corruption in the data stream.
+    if (byte >= 0x80)
+        THROW(FormatError, "unterminated varint-128 integer");
+
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
