@@ -32,72 +32,72 @@ typedef struct JsonWrite JsonWrite;
 /***********************************************************************************************************************************
 Read Constructors
 ***********************************************************************************************************************************/
-JsonRead *jsonReadNew(const String *string);
+FN_EXTERN JsonRead *jsonReadNew(const String *string);
 
 /***********************************************************************************************************************************
 Read Functions
 ***********************************************************************************************************************************/
 // Read next JSON type. This is based on an examination of the first character so there may be an error when the type is read, but
 // the type will not change.
-JsonType jsonReadTypeNext(JsonRead *this);
+FN_EXTERN JsonType jsonReadTypeNext(JsonRead *this);
 
 // Read array begin/end
-void jsonReadArrayBegin(JsonRead *this);
-void jsonReadArrayEnd(JsonRead *this);
+FN_EXTERN void jsonReadArrayBegin(JsonRead *this);
+FN_EXTERN void jsonReadArrayEnd(JsonRead *this);
 
 // Read boolean
-bool jsonReadBool(JsonRead *this);
+FN_EXTERN bool jsonReadBool(JsonRead *this);
 
 // Read integer
-int jsonReadInt(JsonRead *this);
-int64_t jsonReadInt64(JsonRead *this);
-unsigned int jsonReadUInt(JsonRead *this);
-uint64_t jsonReadUInt64(JsonRead *this);
+FN_EXTERN int jsonReadInt(JsonRead *this);
+FN_EXTERN int64_t jsonReadInt64(JsonRead *this);
+FN_EXTERN unsigned int jsonReadUInt(JsonRead *this);
+FN_EXTERN uint64_t jsonReadUInt64(JsonRead *this);
 
 // Read key
-String *jsonReadKey(JsonRead *this);
+FN_EXTERN String *jsonReadKey(JsonRead *this);
 
 // Read an expected key
-bool jsonReadKeyExpect(JsonRead *this, const String *key);
-bool jsonReadKeyExpectStrId(JsonRead *this, StringId key);
-bool jsonReadKeyExpectZ(JsonRead *this, const char *key);
+FN_EXTERN bool jsonReadKeyExpect(JsonRead *this, const String *key);
+FN_EXTERN bool jsonReadKeyExpectStrId(JsonRead *this, StringId key);
+FN_EXTERN bool jsonReadKeyExpectZ(JsonRead *this, const char *key);
 
 // Read an required key
-JsonRead *jsonReadKeyRequire(JsonRead *this, const String *key);
-JsonRead *jsonReadKeyRequireStrId(JsonRead *this, StringId key);
-JsonRead *jsonReadKeyRequireZ(JsonRead *this, const char *key);
+FN_EXTERN JsonRead *jsonReadKeyRequire(JsonRead *this, const String *key);
+FN_EXTERN JsonRead *jsonReadKeyRequireStrId(JsonRead *this, StringId key);
+FN_EXTERN JsonRead *jsonReadKeyRequireZ(JsonRead *this, const char *key);
 
 // Read null
-void jsonReadNull(JsonRead *this);
+FN_EXTERN void jsonReadNull(JsonRead *this);
 
 // Read object begin/end
-void jsonReadObjectBegin(JsonRead *this);
-void jsonReadObjectEnd(JsonRead *this);
+FN_EXTERN void jsonReadObjectBegin(JsonRead *this);
+FN_EXTERN void jsonReadObjectEnd(JsonRead *this);
 
 // Skip value
-void jsonReadSkip(JsonRead *this);
+FN_EXTERN void jsonReadSkip(JsonRead *this);
 
 // Read string
-String *jsonReadStr(JsonRead *this);
-StringId jsonReadStrId(JsonRead *this);
-StringList *jsonReadStrLst(JsonRead *this);
+FN_EXTERN String *jsonReadStr(JsonRead *this);
+FN_EXTERN StringId jsonReadStrId(JsonRead *this);
+FN_EXTERN StringList *jsonReadStrLst(JsonRead *this);
 
 // Read variant
-Variant *jsonReadVar(JsonRead *this);
+FN_EXTERN Variant *jsonReadVar(JsonRead *this);
 
 /***********************************************************************************************************************************
 Read Helper Functions
 ***********************************************************************************************************************************/
 // Convert JSON to Variant
-Variant *jsonToVar(const String *json);
+FN_EXTERN Variant *jsonToVar(const String *json);
 
 // Validate JSON
-void jsonValidate(const String *json);
+FN_EXTERN void jsonValidate(const String *json);
 
 /***********************************************************************************************************************************
 Read Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 jsonReadFree(JsonRead *const this)
 {
     objFree(this);
@@ -115,59 +115,59 @@ typedef struct JsonWriteNewParam
 #define jsonWriteNewP(...)                                                                                                          \
     jsonWriteNew((JsonWriteNewParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-JsonWrite *jsonWriteNew(JsonWriteNewParam param);
+FN_EXTERN JsonWrite *jsonWriteNew(JsonWriteNewParam param);
 
 /***********************************************************************************************************************************
 Write Functions
 ***********************************************************************************************************************************/
 // Write array begin/end
-JsonWrite *jsonWriteArrayBegin(JsonWrite *this);
-JsonWrite *jsonWriteArrayEnd(JsonWrite *this);
+FN_EXTERN JsonWrite *jsonWriteArrayBegin(JsonWrite *this);
+FN_EXTERN JsonWrite *jsonWriteArrayEnd(JsonWrite *this);
 
 // Write boolean
-JsonWrite *jsonWriteBool(JsonWrite *this, bool value);
+FN_EXTERN JsonWrite *jsonWriteBool(JsonWrite *this, bool value);
 
 // Write integer
-JsonWrite *jsonWriteInt(JsonWrite *this, int value);
-JsonWrite *jsonWriteInt64(JsonWrite *this, int64_t value);
-JsonWrite *jsonWriteUInt(JsonWrite *this, unsigned int value);
-JsonWrite *jsonWriteUInt64(JsonWrite *this, uint64_t value);
+FN_EXTERN JsonWrite *jsonWriteInt(JsonWrite *this, int value);
+FN_EXTERN JsonWrite *jsonWriteInt64(JsonWrite *this, int64_t value);
+FN_EXTERN JsonWrite *jsonWriteUInt(JsonWrite *this, unsigned int value);
+FN_EXTERN JsonWrite *jsonWriteUInt64(JsonWrite *this, uint64_t value);
 
 // Write JSON
-JsonWrite *jsonWriteJson(JsonWrite *this, const String *value);
+FN_EXTERN JsonWrite *jsonWriteJson(JsonWrite *this, const String *value);
 
 // Write key
-JsonWrite *jsonWriteKey(JsonWrite *this, const String *key);
-JsonWrite *jsonWriteKeyStrId(JsonWrite *this, StringId key);
-JsonWrite *jsonWriteKeyZ(JsonWrite *this, const char *key);
+FN_EXTERN JsonWrite *jsonWriteKey(JsonWrite *this, const String *key);
+FN_EXTERN JsonWrite *jsonWriteKeyStrId(JsonWrite *this, StringId key);
+FN_EXTERN JsonWrite *jsonWriteKeyZ(JsonWrite *this, const char *key);
 
 // Write null
-JsonWrite *jsonWriteNull(JsonWrite *this);
+FN_EXTERN JsonWrite *jsonWriteNull(JsonWrite *this);
 
 // Write object begin/end
-JsonWrite *jsonWriteObjectBegin(JsonWrite *this);
-JsonWrite *jsonWriteObjectEnd(JsonWrite *this);
+FN_EXTERN JsonWrite *jsonWriteObjectBegin(JsonWrite *this);
+FN_EXTERN JsonWrite *jsonWriteObjectEnd(JsonWrite *this);
 
 // Write string
-JsonWrite *jsonWriteStr(JsonWrite *this, const String *value);
-JsonWrite *jsonWriteStrFmt(JsonWrite *this, const char *format, ...) __attribute__((format(printf, 2, 3)));
-JsonWrite *jsonWriteStrId(JsonWrite *this, StringId value);
-JsonWrite *jsonWriteStrLst(JsonWrite *this, const StringList *value);
-JsonWrite *jsonWriteZ(JsonWrite *this, const char *value);
+FN_EXTERN JsonWrite *jsonWriteStr(JsonWrite *this, const String *value);
+FN_EXTERN FN_PRINTF(2, 3) JsonWrite *jsonWriteStrFmt(JsonWrite *this, const char *format, ...);
+FN_EXTERN JsonWrite *jsonWriteStrId(JsonWrite *this, StringId value);
+FN_EXTERN JsonWrite *jsonWriteStrLst(JsonWrite *this, const StringList *value);
+FN_EXTERN JsonWrite *jsonWriteZ(JsonWrite *this, const char *value);
 
 // Write variant
-JsonWrite *jsonWriteVar(JsonWrite *this, const Variant *value);
+FN_EXTERN JsonWrite *jsonWriteVar(JsonWrite *this, const Variant *value);
 
 /***********************************************************************************************************************************
 Write Getters/Setters
 ***********************************************************************************************************************************/
 // Get JSON result
-const String *jsonWriteResult(JsonWrite *this);
+FN_EXTERN const String *jsonWriteResult(JsonWrite *this);
 
 /***********************************************************************************************************************************
 Write Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 jsonWriteFree(JsonWrite *const this)
 {
     objFree(this);
@@ -177,23 +177,27 @@ jsonWriteFree(JsonWrite *const this)
 Write Helper Functions
 ***********************************************************************************************************************************/
 // Convert Variant to JSON
-String *jsonFromVar(const Variant *value);
+FN_EXTERN String *jsonFromVar(const Variant *value);
 
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *jsonReadToLog(const JsonRead *this);
+#ifdef DEBUG
+
+FN_EXTERN void jsonReadToLog(const JsonRead *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_JSON_READ_TYPE                                                                                                \
     JsonRead *
 #define FUNCTION_LOG_JSON_READ_FORMAT(value, buffer, bufferSize)                                                                   \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, jsonReadToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, jsonReadToLog, buffer, bufferSize)
 
-String *jsonWriteToLog(const JsonWrite *this);
+FN_EXTERN void jsonWriteToLog(const JsonWrite *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_JSON_WRITE_TYPE                                                                                               \
     JsonWrite *
 #define FUNCTION_LOG_JSON_WRITE_FORMAT(value, buffer, bufferSize)                                                                  \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, jsonWriteToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, jsonWriteToLog, buffer, bufferSize)
+
+#endif // DEBUG
 
 #endif
