@@ -29,7 +29,7 @@ typedef struct KeyValuePair
 } KeyValuePair;
 
 /**********************************************************************************************************************************/
-KeyValue *
+FN_EXTERN KeyValue *
 kvNew(void)
 {
     FUNCTION_TEST_VOID();
@@ -56,7 +56,7 @@ kvNew(void)
 }
 
 /**********************************************************************************************************************************/
-KeyValue *
+FN_EXTERN KeyValue *
 kvDup(const KeyValue *const source)
 {
     FUNCTION_TEST_BEGIN();
@@ -85,7 +85,7 @@ kvDup(const KeyValue *const source)
 }
 
 /**********************************************************************************************************************************/
-unsigned int
+FN_EXTERN unsigned int
 kvGetIdx(const KeyValue *this, const Variant *key)
 {
     FUNCTION_TEST_BEGIN();
@@ -131,6 +131,8 @@ kvPutInternal(KeyValue *this, const Variant *key, Variant *value)
     ASSERT(this != NULL);
     ASSERT(key != NULL);
 
+    FUNCTION_AUDIT_HELPER();
+
     // Find the key
     unsigned int listIdx = kvGetIdx(this, key);
 
@@ -163,7 +165,7 @@ kvPutInternal(KeyValue *this, const Variant *key, Variant *value)
 }
 
 /**********************************************************************************************************************************/
-KeyValue *
+FN_EXTERN KeyValue *
 kvPut(KeyValue *this, const Variant *key, const Variant *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -185,7 +187,7 @@ kvPut(KeyValue *this, const Variant *key, const Variant *value)
 }
 
 /**********************************************************************************************************************************/
-KeyValue *
+FN_EXTERN KeyValue *
 kvAdd(KeyValue *this, const Variant *key, const Variant *value)
 {
     FUNCTION_TEST_BEGIN();
@@ -231,7 +233,7 @@ kvAdd(KeyValue *this, const Variant *key, const Variant *value)
 }
 
 /**********************************************************************************************************************************/
-KeyValue *
+FN_EXTERN KeyValue *
 kvPutKv(KeyValue *this, const Variant *key)
 {
     FUNCTION_TEST_BEGIN();
@@ -255,7 +257,7 @@ kvPutKv(KeyValue *this, const Variant *key)
 }
 
 /**********************************************************************************************************************************/
-const Variant *
+FN_EXTERN const Variant *
 kvGet(const KeyValue *this, const Variant *key)
 {
     FUNCTION_TEST_BEGIN();
@@ -278,7 +280,7 @@ kvGet(const KeyValue *this, const Variant *key)
 }
 
 /**********************************************************************************************************************************/
-const Variant *
+FN_EXTERN const Variant *
 kvGetDefault(const KeyValue *const this, const Variant *const key, const Variant *const defaultValue)
 {
     FUNCTION_TEST_BEGIN();
@@ -301,7 +303,7 @@ kvGetDefault(const KeyValue *const this, const Variant *const key, const Variant
 }
 
 /**********************************************************************************************************************************/
-VariantList *
+FN_EXTERN VariantList *
 kvGetList(const KeyValue *const this, const Variant *const key)
 {
     FUNCTION_TEST_BEGIN();
@@ -331,3 +333,38 @@ kvGetList(const KeyValue *const this, const Variant *const key)
 
     FUNCTION_TEST_RETURN(VARIANT_LIST, result);
 }
+
+/**********************************************************************************************************************************/
+FN_EXTERN KeyValue *
+kvRemove(KeyValue *this, const Variant *key)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(KEY_VALUE, this);
+        FUNCTION_TEST_PARAM(VARIANT, key);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(key != NULL);
+
+    // Find the key
+    unsigned int listIdx = kvGetIdx(this, key);
+
+    // If the key was found, remove it
+    if (listIdx != KEY_NOT_FOUND)
+    {
+        // Free the key/value being removed and remove from the list
+        KeyValuePair *const pair = (KeyValuePair *)lstGet(this->list, listIdx);
+
+        varFree(pair->key);
+        varFree(pair->value);
+        lstRemoveIdx(this->list, listIdx);
+
+        // Remove from the key list (index must be the same as the key/value list)
+        ASSERT(varEq(key, varLstGet(this->pub.keyList, listIdx)));
+
+        varFree(varLstGet(this->pub.keyList, listIdx));
+        lstRemoveIdx((List *)this->pub.keyList, listIdx);
+    }
+
+    FUNCTION_TEST_RETURN(KEY_VALUE, this);
+}
