@@ -35,7 +35,7 @@ Integer types (packTypeMapData[type].valueMultiBit) when an unsigned value is <=
             1 0 0 1 - the low-order bit is 1 so the "ID delta low order bit" is set.
     04 = since the low order bit of the internal ID delta was already set in bit 0 of the tag byte, then the remain bits are shifted
         right by one and represented in this second byte as 4. To get the ID delta for 04, shift the 4 back to the left one and then
-        add back the "ID delta low order bit" to give a binary representation of  1 0 0 1 = 9. Add back the 1 which is never
+        add back the "ID delta low order bit" to give a binary representation of 1 0 0 1 = 9. Add back the 1 which is never
         recorded and the ID gap is 10.
 
 Integer types (packTypeMapData[type].valueMultiBit) when an unsigned value is > 1 or a signed value is < -1 or > 0:
@@ -81,7 +81,7 @@ Array and object types:
 0-2 - ID delta low order bits
   Note: arrays and objects are merely containers for the other pack types.
 
-  Example: 1801  (container begin)
+  Example: 1801 (container begin)
     1 = array type
     8 = "more ID delta indicator bit" - there exists a gap (i.e. NULLs are not stored so there is a gap between the stored IDs)
     01 = since there are three "ID delta low order bits", the 01 will be shifted left by 3 with zeros, resulting in 8. Add back
@@ -104,11 +104,6 @@ Array and object types:
 #include "common/type/convert.h"
 #include "common/type/pack.h"
 
-/***********************************************************************************************************************************
-Constants
-***********************************************************************************************************************************/
-#define PACK_UINT64_SIZE_MAX                                        10
-
 /***********************************************************************************************************************************
 Map PackType types to the types that will be written into the pack. This hides the details of the type IDs from the user and allows
 the IDs used in the pack to differ from the IDs the user sees.
@@ -121,7 +116,9 @@ typedef enum
     pckTypeMapI32 = 3,                                              // Maps to pckTypeI32
     pckTypeMapI64 = 4,                                              // Maps to pckTypeI64
     pckTypeMapObj = 5,                                              // Maps to pckTypeObj
-    pckTypeMapPtr = 6,                                              // Maps to pckTypePtr
+
+    // The empty position 6 can be used for a new type that will be encoded entirely in the tag
+
     pckTypeMapStr = 7,                                              // Maps to pckTypeStr
     pckTypeMapU32 = 8,                                              // Maps to pckTypeU32
     pckTypeMapU64 = 9,                                              // Maps to pckTypeU64
@@ -167,10 +164,8 @@ static const PackTypeMapData packTypeMapData[] =
     {
         .type = pckTypeObj,
     },
-    {
-        .type = pckTypePtr,
-        .valueMultiBit = true,
-    },
+    // Placeholders for unused type that can be encoded entirely in the tag
+    {0},
     {
         .type = pckTypeStr,
         .valueSingleBit = true,
@@ -215,8 +210,6 @@ static const PackTypeMapData packTypeMapData[] =
     },
 };
 
-#define PACK_TYPE_MAP_SIZE                                          (sizeof(packTypeMapData) / sizeof(PackTypeMapData))
-
 /***********************************************************************************************************************************
 Object types
 ***********************************************************************************************************************************/
@@ -343,7 +336,7 @@ pckReadNewInternal(void)
 
     PackRead *this = NULL;
 
-    OBJ_NEW_BEGIN(PackRead)
+    OBJ_NEW_BEGIN(PackRead, .childQty = MEM_CONTEXT_QTY_MAX)
     {
         this = OBJ_NEW_ALLOC();
 
@@ -356,10 +349,10 @@ pckReadNewInternal(void)
     }
     OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
-PackRead *
+FN_EXTERN PackRead *
 pckReadNewIo(IoRead *read)
 {
     FUNCTION_TEST_BEGIN();
@@ -370,18 +363,18 @@ pckReadNewIo(IoRead *read)
 
     PackRead *this = pckReadNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->read = read;
         this->buffer = bufNew(ioBufferSize());
         this->bufferPtr = bufPtr(this->buffer);
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
-PackRead *
+FN_EXTERN PackRead *
 pckReadNew(const Pack *const pack)
 {
     FUNCTION_TEST_BEGIN();
@@ -389,12 +382,12 @@ pckReadNew(const Pack *const pack)
     FUNCTION_TEST_END();
 
     if (pack == NULL)
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK_READ, NULL);
 
-    FUNCTION_TEST_RETURN(pckReadNewC(bufPtrConst((const Buffer *)pack), bufUsed((const Buffer *)pack)));
+    FUNCTION_TEST_RETURN(PACK_READ, pckReadNewC(bufPtrConst((const Buffer *)pack), bufUsed((const Buffer *)pack)));
 }
 
-PackRead *
+FN_EXTERN PackRead *
 pckReadNewC(const unsigned char *const buffer, size_t size)
 {
     FUNCTION_TEST_BEGIN();
@@ -408,7 +401,7 @@ pckReadNewC(const unsigned char *const buffer, size_t size)
     this->bufferPtr = buffer;
     this->bufferUsed = size;
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
 /***********************************************************************************************************************************
@@ -451,10 +444,10 @@ pckReadBuffer(PackRead *this, size_t size)
         if (remaining < 1)
             THROW(FormatError, "unexpected EOF");
 
-        FUNCTION_TEST_RETURN(remaining < size ? remaining : size);
+        FUNCTION_TEST_RETURN(SIZE, remaining < size ? remaining : size);
     }
 
-    FUNCTION_TEST_RETURN(size);
+    FUNCTION_TEST_RETURN(SIZE, size);
 }
 
 /***********************************************************************************************************************************
@@ -491,33 +484,14 @@ pckReadU64Internal(PackRead *this)
 
     ASSERT(this != NULL);
 
-    uint64_t result = 0;
-    uint8_t byte;
-
-    // Convert bytes from varint-128 encoding to a uint64
-    for (unsigned int bufferIdx = 0; bufferIdx < PACK_UINT64_SIZE_MAX; bufferIdx++)
+    if (this->read != NULL)
     {
-        // Get the next encoded byte
-        pckReadBuffer(this, 1);
-        byte = this->bufferPtr[this->bufferPos];
-
-        // Shift the lower order 7 encoded bits into the uint64 in reverse order
-        result |= (uint64_t)(byte & 0x7f) << (7 * bufferIdx);
-
-        // Increment buffer position to indicate that the byte has been processed
-        this->bufferPos++;
-
-        // Done if the high order bit is not set to indicate more data
-        if (byte < 0x80)
-            break;
+        // Internal buffer should be empty
+        ASSERT(this->bufferUsed == this->bufferPos);
+        FUNCTION_TEST_RETURN(UINT64, ioReadVarIntU64(this->read));
     }
 
-    // By this point all bytes should have been read so error if this is not the case. This could be due to a coding error or
-    // corrupton in the data stream.
-    if (byte >= 0x80)
-        THROW(FormatError, "unterminated base-128 integer");
-
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, cvtUInt64FromVarInt128(this->bufferPtr, &this->bufferPos, this->bufferUsed));
 }
 
 /***********************************************************************************************************************************
@@ -554,7 +528,7 @@ pckReadTagNext(PackRead *this)
             this->tagNextTypeMap = (unsigned int)pckReadU64Internal(this) + 0xF;
 
         CHECK(
-            FormatError, this->tagNextTypeMap < PACK_TYPE_MAP_SIZE && packTypeMapData[this->tagNextTypeMap].type != 0,
+            FormatError, this->tagNextTypeMap < LENGTH_OF(packTypeMapData) && packTypeMapData[this->tagNextTypeMap].type != 0,
             "invalid tag type");
 
         // If the value can contain multiple bits (e.g. integer)
@@ -630,7 +604,7 @@ pckReadTagNext(PackRead *this)
         result = true;
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(BOOL, result);
 }
 
 /***********************************************************************************************************************************
@@ -705,11 +679,11 @@ pckReadTag(PackRead *this, unsigned int *id, PackTypeMap typeMap, bool peek)
     }
     while (1);
 
-    FUNCTION_TEST_RETURN(this->tagNextValue);
+    FUNCTION_TEST_RETURN(UINT64, this->tagNextValue);
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 pckReadNext(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -719,11 +693,11 @@ pckReadNext(PackRead *this)
     ASSERT(this != NULL);
     ASSERT(this->tagNextId == 0);
 
-    FUNCTION_TEST_RETURN(pckReadTagNext(this));
+    FUNCTION_TEST_RETURN(BOOL, pckReadTagNext(this));
 }
 
 /**********************************************************************************************************************************/
-unsigned int
+FN_EXTERN unsigned int
 pckReadId(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -732,11 +706,11 @@ pckReadId(PackRead *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->tagNextId);
+    FUNCTION_TEST_RETURN(UINT, this->tagNextId);
 }
 
 /**********************************************************************************************************************************/
-size_t
+FN_EXTERN size_t
 pckReadSize(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -746,11 +720,11 @@ pckReadSize(PackRead *this)
     ASSERT(this != NULL);
     ASSERT(packTypeMapData[this->tagNextTypeMap].size);
 
-    FUNCTION_TEST_RETURN(this->tagNextSize);
+    FUNCTION_TEST_RETURN(SIZE, this->tagNextSize);
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 pckReadConsume(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -769,7 +743,7 @@ pckReadConsume(PackRead *this)
 }
 
 /**********************************************************************************************************************************/
-const unsigned char *
+FN_EXTERN const unsigned char *
 pckReadBufPtr(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -780,7 +754,7 @@ pckReadBufPtr(PackRead *this)
     ASSERT(packTypeMapData[this->tagNextTypeMap].size);
     ASSERT(this->buffer == NULL);
 
-    FUNCTION_TEST_RETURN(this->bufferPtr + this->bufferPos);
+    FUNCTION_TEST_RETURN_CONST_P(UCHARDATA, this->bufferPtr + this->bufferPos);
 }
 
 /**********************************************************************************************************************************/
@@ -804,14 +778,14 @@ pckReadNullInternal(PackRead *this, unsigned int *id)
     if (*id < this->tagNextId)
     {
         this->tagStack.top->idLast = *id;
-        FUNCTION_TEST_RETURN(true);
+        FUNCTION_TEST_RETURN(BOOL, true);
     }
 
     // The field is not NULL
-    FUNCTION_TEST_RETURN(false);
+    FUNCTION_TEST_RETURN(BOOL, false);
 }
 
-bool
+FN_EXTERN bool
 pckReadNull(PackRead *this, PackIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -821,11 +795,11 @@ pckReadNull(PackRead *this, PackIdParam param)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(pckReadNullInternal(this, &param.id));
+    FUNCTION_TEST_RETURN(BOOL, pckReadNullInternal(this, &param.id));
 }
 
 /**********************************************************************************************************************************/
-PackType
+FN_EXTERN PackType
 pckReadType(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -834,11 +808,11 @@ pckReadType(PackRead *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(packTypeMapData[this->tagNextTypeMap].type);
+    FUNCTION_TEST_RETURN(STRING_ID, packTypeMapData[this->tagNextTypeMap].type);
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 pckReadArrayBegin(PackRead *this, PackIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -857,7 +831,7 @@ pckReadArrayBegin(PackRead *this, PackIdParam param)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-void
+FN_EXTERN void
 pckReadArrayEnd(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -883,7 +857,7 @@ pckReadArrayEnd(PackRead *this)
 }
 
 /**********************************************************************************************************************************/
-Buffer *
+FN_EXTERN Buffer *
 pckReadBin(PackRead *this, PckReadBinParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -894,7 +868,7 @@ pckReadBin(PackRead *this, PckReadBinParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(BUFFER, NULL);
 
     Buffer *result = NULL;
 
@@ -916,11 +890,11 @@ pckReadBin(PackRead *this, PckReadBinParam param)
     else
         result = bufNew(0);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(BUFFER, result);
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 pckReadBool(PackRead *this, PckReadBoolParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -932,13 +906,13 @@ pckReadBool(PackRead *this, PckReadBoolParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(BOOL, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapBool, false));
+    FUNCTION_TEST_RETURN(BOOL, pckReadTag(this, &param.id, pckTypeMapBool, false));
 }
 
 /**********************************************************************************************************************************/
-int32_t
+FN_EXTERN int32_t
 pckReadI32(PackRead *this, PckReadI32Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -950,13 +924,13 @@ pckReadI32(PackRead *this, PckReadI32Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(INT, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(cvtInt32FromZigZag((uint32_t)pckReadTag(this, &param.id, pckTypeMapI32, false)));
+    FUNCTION_TEST_RETURN(INT, cvtInt32FromZigZag((uint32_t)pckReadTag(this, &param.id, pckTypeMapI32, false)));
 }
 
 /**********************************************************************************************************************************/
-int64_t
+FN_EXTERN int64_t
 pckReadI64(PackRead *this, PckReadI64Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -968,13 +942,13 @@ pckReadI64(PackRead *this, PckReadI64Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(INT64, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapI64, false)));
+    FUNCTION_TEST_RETURN(INT64, cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapI64, false)));
 }
 
 /**********************************************************************************************************************************/
-mode_t
+FN_EXTERN mode_t
 pckReadMode(PackRead *this, PckReadModeParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -986,13 +960,13 @@ pckReadMode(PackRead *this, PckReadModeParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(MODE, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((mode_t)pckReadTag(this, &param.id, pckTypeMapMode, false));
+    FUNCTION_TEST_RETURN(MODE, (mode_t)pckReadTag(this, &param.id, pckTypeMapMode, false));
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 pckReadObjBegin(PackRead *this, PackIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1011,7 +985,7 @@ pckReadObjBegin(PackRead *this, PackIdParam param)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-void
+FN_EXTERN void
 pckReadObjEnd(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1037,7 +1011,7 @@ pckReadObjEnd(PackRead *this)
 }
 
 /**********************************************************************************************************************************/
-PackRead *
+FN_EXTERN PackRead *
 pckReadPackRead(PackRead *this, PckReadPackParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1051,10 +1025,10 @@ pckReadPackRead(PackRead *this, PckReadPackParam param)
     if (result != NULL)
         pckMove(pack, objMemContext(result));
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK_READ, result);
 }
 
-PackRead *
+FN_EXTERN PackRead *
 pckReadPackReadConst(PackRead *this, PckReadPackParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1063,7 +1037,7 @@ pckReadPackReadConst(PackRead *this, PckReadPackParam param)
     FUNCTION_TEST_END();
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK_READ, NULL);
 
     // Read the tag
     pckReadTag(this, &param.id, pckTypeMapPack, false);
@@ -1072,10 +1046,10 @@ pckReadPackReadConst(PackRead *this, PckReadPackParam param)
 
     pckReadConsumeBuffer(this);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK_READ, result);
 }
 
-Pack *
+FN_EXTERN Pack *
 pckReadPack(PackRead *const this, PckReadPackParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1086,13 +1060,13 @@ pckReadPack(PackRead *const this, PckReadPackParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK, NULL);
 
     // Read the tag
     pckReadTag(this, &param.id, pckTypeMapPack, false);
 
     // Get the pack size
-    Buffer *result = bufNew(this->tagNextSize);
+    Buffer *const result = OBJ_NAME(bufNew(this->tagNextSize), Pack::Buffer);
 
     // Read the pack out in chunks
     while (bufUsed(result) < bufSize(result))
@@ -1102,28 +1076,11 @@ pckReadPack(PackRead *const this, PckReadPackParam param)
         this->bufferPos += size;
     }
 
-    FUNCTION_TEST_RETURN((Pack *)result);
+    FUNCTION_TEST_RETURN(PACK, (Pack *)result);
 }
 
 /**********************************************************************************************************************************/
-void *
-pckReadPtr(PackRead *this, PckReadPtrParam param)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(PACK_READ, this);
-        FUNCTION_TEST_PARAM(UINT, param.id);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
-
-    FUNCTION_TEST_RETURN((void *)(uintptr_t)pckReadTag(this, &param.id, pckTypeMapPtr, false));
-}
-
-/**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 pckReadStr(PackRead *this, PckReadStrParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1135,7 +1092,7 @@ pckReadStr(PackRead *this, PckReadStrParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(strDup(param.defaultValue));
+        FUNCTION_TEST_RETURN(STRING, strDup(param.defaultValue));
 
     String *result = NULL;
 
@@ -1159,11 +1116,11 @@ pckReadStr(PackRead *this, PckReadStrParam param)
     else
         result = strNew();
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STRING, result);
 }
 
 /**********************************************************************************************************************************/
-StringId
+FN_EXTERN StringId
 pckReadStrId(PackRead *this, PckReadStrIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1175,13 +1132,13 @@ pckReadStrId(PackRead *this, PckReadStrIdParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(STRING_ID, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapStrId, false));
+    FUNCTION_TEST_RETURN(STRING_ID, pckReadTag(this, &param.id, pckTypeMapStrId, false));
 }
 
 /**********************************************************************************************************************************/
-StringList *
+FN_EXTERN StringList *
 pckReadStrLst(PackRead *const this, PckReadStrLstParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1192,22 +1149,26 @@ pckReadStrLst(PackRead *const this, PckReadStrLstParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(STRING_LIST, NULL);
 
     pckReadArrayBeginP(this, .id = param.id);
 
     StringList *const result = strLstNew();
 
-    while (!pckReadNullP(this))
-        strLstAdd(result, pckReadStrP(this));
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        while (!pckReadNullP(this))
+            strLstAdd(result, pckReadStrP(this));
+    }
+    MEM_CONTEXT_TEMP_END();
 
     pckReadArrayEndP(this);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STRING_LIST, result);
 }
 
 /**********************************************************************************************************************************/
-time_t
+FN_EXTERN time_t
 pckReadTime(PackRead *this, PckReadTimeParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1219,13 +1180,13 @@ pckReadTime(PackRead *this, PckReadTimeParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(TIME, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((time_t)cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapTime, false)));
+    FUNCTION_TEST_RETURN(TIME, (time_t)cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapTime, false)));
 }
 
 /**********************************************************************************************************************************/
-uint32_t
+FN_EXTERN uint32_t
 pckReadU32(PackRead *this, PckReadU32Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1237,13 +1198,13 @@ pckReadU32(PackRead *this, PckReadU32Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(UINT32, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((uint32_t)pckReadTag(this, &param.id, pckTypeMapU32, false));
+    FUNCTION_TEST_RETURN(UINT32, (uint32_t)pckReadTag(this, &param.id, pckTypeMapU32, false));
 }
 
 /**********************************************************************************************************************************/
-uint64_t
+FN_EXTERN uint64_t
 pckReadU64(PackRead *this, PckReadU64Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1255,13 +1216,13 @@ pckReadU64(PackRead *this, PckReadU64Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(UINT64, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapU64, false));
+    FUNCTION_TEST_RETURN(UINT64, pckReadTag(this, &param.id, pckTypeMapU64, false));
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 pckReadEnd(PackRead *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1281,11 +1242,11 @@ pckReadEnd(PackRead *this)
 }
 
 /**********************************************************************************************************************************/
-String *
-pckReadToLog(const PackRead *this)
+FN_EXTERN void
+pckReadToLog(const PackRead *const this, StringStatic *const debugLog)
 {
-    return strNewFmt(
-        "{depth: %u, idLast: %u, tagNextId: %u, tagNextType: %u, tagNextValue %" PRIu64 "}", this->tagStack.depth,
+    strStcFmt(
+        debugLog, "{depth: %u, idLast: %u, tagNextId: %u, tagNextType: %u, tagNextValue %" PRIu64 "}", this->tagStack.depth,
         this->tagStack.top->idLast, this->tagNextId, this->tagNextTypeMap, this->tagNextValue);
 }
 
@@ -1298,7 +1259,7 @@ pckWriteNewInternal(void)
 
     PackWrite *this = NULL;
 
-    OBJ_NEW_BEGIN(PackWrite)
+    OBJ_NEW_BEGIN(PackWrite, .childQty = MEM_CONTEXT_QTY_MAX)
     {
         this = OBJ_NEW_ALLOC();
 
@@ -1311,10 +1272,10 @@ pckWriteNewInternal(void)
     }
     OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteNew(const PckWriteNewParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1323,16 +1284,16 @@ pckWriteNew(const PckWriteNewParam param)
 
     PackWrite *this = pckWriteNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->buffer = bufNew(param.size == 0 ? PACK_EXTRA_MIN : param.size);
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteNewIo(IoWrite *write)
 {
     FUNCTION_TEST_BEGIN();
@@ -1343,14 +1304,14 @@ pckWriteNewIo(IoWrite *write)
 
     PackWrite *this = pckWriteNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->write = write;
         this->buffer = bufNew(ioBufferSize());
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /***********************************************************************************************************************************
@@ -1409,7 +1370,7 @@ pckWriteBuffer(PackWrite *this, const Buffer *buffer)
 Pack an unsigned 64-bit integer to base-128 varint encoding
 ***********************************************************************************************************************************/
 static void
-pckWriteU64Internal(PackWrite *this, uint64_t value)
+pckWriteU64Internal(PackWrite *const this, const uint64_t value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(PACK_WRITE, this);
@@ -1418,27 +1379,13 @@ pckWriteU64Internal(PackWrite *this, uint64_t value)
 
     ASSERT(this != NULL);
 
-    unsigned char buffer[PACK_UINT64_SIZE_MAX];
+    unsigned char buffer[CVT_VARINT128_BUFFER_SIZE];
     size_t size = 0;
 
-    // Convert uint64 to varint-128 encoding. Keep writing out bytes while the remaining value is greater than 7 bits.
-    while (value >= 0x80)
-    {
-        // Encode the lower order 7 bits, adding the continuation bit to indicate there is more data
-        buffer[size] = (unsigned char)value | 0x80;
-
-        // Shift the value to remove bits that have been encoded
-        value >>= 7;
-
-        // Keep track of size so we know how many bytes to write out
-        size++;
-    }
-
-    // Encode the last 7 bits of value
-    buffer[size] = (unsigned char)value;
+    cvtUInt64ToVarInt128(value, buffer, &size, sizeof(buffer));
 
     // Write encoded bytes to the buffer
-    pckWriteBuffer(this, BUF(buffer, size + 1));
+    pckWriteBuffer(this, BUF(buffer, size));
 
     FUNCTION_TEST_RETURN_VOID();
 }
@@ -1578,15 +1525,15 @@ pckWriteDefaultNull(PackWrite *this, bool defaultWrite, bool defaultEqual)
     if (!defaultWrite && defaultEqual)
     {
         this->tagStack.top->nullTotal++;
-        FUNCTION_TEST_RETURN(true);
+        FUNCTION_TEST_RETURN(BOOL, true);
     }
 
     // Let the caller know that it should write the value
-    FUNCTION_TEST_RETURN(false);
+    FUNCTION_TEST_RETURN(BOOL, false);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteNull(PackWrite *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1595,11 +1542,11 @@ pckWriteNull(PackWrite *this)
 
     this->tagStack.top->nullTotal++;
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteArrayBegin(PackWrite *this, PackIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1615,10 +1562,10 @@ pckWriteArrayBegin(PackWrite *this, PackIdParam param)
     // Add array to the tag stack so IDs can be tracked separately from the parent container
     pckTagStackPush(objMemContext(this), &this->tagStack, pckTypeMapArray);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteArrayEnd(PackWrite *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1636,11 +1583,11 @@ pckWriteArrayEnd(PackWrite *this)
     // Pop array off the stack to revert to ID tracking for the prior container
     pckTagStackPop(&this->tagStack);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteBin(PackWrite *this, const Buffer *value, PckWriteBinParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1666,11 +1613,11 @@ pckWriteBin(PackWrite *this, const Buffer *value, PckWriteBinParam param)
         }
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteBool(PackWrite *this, bool value, PckWriteBoolParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1686,11 +1633,11 @@ pckWriteBool(PackWrite *this, bool value, PckWriteBoolParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapBool, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteI32(PackWrite *this, int32_t value, PckWriteI32Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1706,11 +1653,11 @@ pckWriteI32(PackWrite *this, int32_t value, PckWriteI32Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapI32, param.id, cvtInt32ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteI64(PackWrite *this, int64_t value, PckWriteI64Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1726,11 +1673,11 @@ pckWriteI64(PackWrite *this, int64_t value, PckWriteI64Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapI64, param.id, cvtInt64ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteMode(PackWrite *this, mode_t value, PckWriteModeParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1746,11 +1693,11 @@ pckWriteMode(PackWrite *this, mode_t value, PckWriteModeParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapMode, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteObjBegin(PackWrite *this, PackIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1766,10 +1713,10 @@ pckWriteObjBegin(PackWrite *this, PackIdParam param)
     // Add object to the tag stack so IDs can be tracked separately from the parent container
     pckTagStackPush(objMemContext(this), &this->tagStack, pckTypeMapObj);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteObjEnd(PackWrite *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1787,11 +1734,11 @@ pckWriteObjEnd(PackWrite *this)
     // Pop object off the stack to revert to ID tracking for the prior container
     pckTagStackPop(&this->tagStack);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWritePack(PackWrite *const this, const Pack *const value, const PckWritePackParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1811,30 +1758,11 @@ pckWritePack(PackWrite *const this, const Pack *const value, const PckWritePackP
         pckWriteBuffer(this, (Buffer *)value);
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
-pckWritePtr(PackWrite *this, const void *value, PckWritePtrParam param)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(PACK_WRITE, this);
-        FUNCTION_TEST_PARAM_P(VOID, value);
-        FUNCTION_TEST_PARAM(UINT, param.id);
-        FUNCTION_TEST_PARAM(BOOL, param.defaultWrite);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    if (!pckWriteDefaultNull(this, param.defaultWrite, value == NULL))
-        pckWriteTag(this, pckTypeMapPtr, param.id, (uintptr_t)value);
-
-    FUNCTION_TEST_RETURN(this);
-}
-
-/**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteStr(PackWrite *this, const String *value, PckWriteStrParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1860,11 +1788,11 @@ pckWriteStr(PackWrite *this, const String *value, PckWriteStrParam param)
         }
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteStrId(PackWrite *this, uint64_t value, PckWriteStrIdParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1880,11 +1808,11 @@ pckWriteStrId(PackWrite *this, uint64_t value, PckWriteStrIdParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapStrId, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteStrLst(PackWrite *const this, const StringList *const value, const PckWriteStrLstParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1907,11 +1835,11 @@ pckWriteStrLst(PackWrite *const this, const StringList *const value, const PckWr
         pckWriteArrayEndP(this);
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteTime(PackWrite *this, time_t value, PckWriteTimeParam param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1927,11 +1855,11 @@ pckWriteTime(PackWrite *this, time_t value, PckWriteTimeParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapTime, param.id, cvtInt64ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteU32(PackWrite *this, uint32_t value, PckWriteU32Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1947,11 +1875,11 @@ pckWriteU32(PackWrite *this, uint32_t value, PckWriteU32Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapU32, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteU64(PackWrite *this, uint64_t value, PckWriteU64Param param)
 {
     FUNCTION_TEST_BEGIN();
@@ -1967,11 +1895,11 @@ pckWriteU64(PackWrite *this, uint64_t value, PckWriteU64Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapU64, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-PackWrite *
+FN_EXTERN PackWrite *
 pckWriteEnd(PackWrite *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -1994,11 +1922,11 @@ pckWriteEnd(PackWrite *this)
     else
         bufResize(this->buffer, bufUsed(this->buffer));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
-Pack *
+FN_EXTERN Pack *
 pckWriteResult(PackWrite *const this)
 {
     FUNCTION_TEST_BEGIN();
@@ -2011,15 +1939,16 @@ pckWriteResult(PackWrite *const this)
     {
         ASSERT(this->tagStack.top == NULL);
 
-        result = (Pack *)this->buffer;
+        result = (Pack *)OBJ_NAME(this->buffer, Pack::Buffer);
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK, result);
 }
 
 /**********************************************************************************************************************************/
-String *
-pckWriteToLog(const PackWrite *this)
+FN_EXTERN void
+pckWriteToLog(const PackWrite *const this, StringStatic *const debugLog)
 {
-    return strNewFmt("{depth: %u, idLast: %u}", this->tagStack.depth, this->tagStack.top == NULL ? 0 : this->tagStack.top->idLast);
+    strStcFmt(
+        debugLog, "{depth: %u, idLast: %u}", this->tagStack.depth, this->tagStack.top == NULL ? 0 : this->tagStack.top->idLast);
 }
