@@ -48,54 +48,51 @@ Command Functions
 Access the current command and command parameters.
 ***********************************************************************************************************************************/
 // Current command
-ConfigCommand cfgCommand(void);
+FN_EXTERN ConfigCommand cfgCommand(void);
 
 // Current command role (async, local, remote)
-ConfigCommandRole cfgCommandRole(void);
+FN_EXTERN ConfigCommandRole cfgCommandRole(void);
 
 // Get command name
-const char *cfgCommandName(void);
+FN_EXTERN const char *cfgCommandName(void);
 
 // Get command:role name
-String *cfgCommandRoleName(void);
+FN_EXTERN String *cfgCommandRoleName(void);
 
 // Does this command require an immediate lock?
-bool cfgLockRequired(void);
+FN_EXTERN bool cfgLockRequired(void);
 
 // Does the command require a remote lock?
-bool cfgLockRemoteRequired(void);
+FN_EXTERN bool cfgLockRemoteRequired(void);
 
 // Lock type required for this command
-LockType cfgLockType(void);
+FN_EXTERN LockType cfgLockType(void);
 
 // Does this command log to a file?
-bool cfgLogFile(void);
+FN_EXTERN bool cfgLogFile(void);
 
 // Default log level -- used for log messages that are common to all commands
-LogLevel cfgLogLevelDefault(void);
+FN_EXTERN LogLevel cfgLogLevelDefault(void);
 
 // Command parameters, if any
-const StringList *cfgCommandParam(void);
+FN_EXTERN const StringList *cfgCommandParam(void);
 
 /***********************************************************************************************************************************
 Option Group Functions
 ***********************************************************************************************************************************/
 // Format group name for display to the user. Useful for messages that do not show an option name but must use an group name that
 // the user will recognize.
-const char *cfgOptionGroupName(ConfigOptionGroup groupId, unsigned int groupIdx);
+FN_EXTERN const char *cfgOptionGroupName(ConfigOptionGroup groupId, unsigned int groupIdx);
 
 // Get the default index for this group, i.e. the index that will be used if a non-indexed function like cfgOptionTest() is called.
-unsigned int cfgOptionGroupIdxDefault(ConfigOptionGroup groupId);
+FN_EXTERN unsigned int cfgOptionGroupIdxDefault(ConfigOptionGroup groupId);
 
 // Convert the group index to a key, i.e. the key that was used in the original configuration file, command-line, etc.
-unsigned int cfgOptionGroupIdxToKey(ConfigOptionGroup groupId, unsigned int groupIdx);
+FN_EXTERN unsigned int cfgOptionGroupIdxToKey(ConfigOptionGroup groupId, unsigned int groupIdx);
 
 // Total indexes, 0 if the group is not valid. Will be the total configured indexes, no matter which raw indexes were used during
 // configuration. e.g., if pg1-path and pg8-path are configured then this function will return 2.
-unsigned int cfgOptionGroupIdxTotal(ConfigOptionGroup groupId);
-
-// Are any options in the group valid for the command?
-bool cfgOptionGroupValid(ConfigOptionGroup groupId);
+FN_EXTERN unsigned int cfgOptionGroupIdxTotal(ConfigOptionGroup groupId);
 
 /***********************************************************************************************************************************
 Option Functions
@@ -104,100 +101,100 @@ Access option values, indexes, and determine if an option is valid for the curre
 accepts an index, which currently work with non-indexed options (with optionIdx 0) but they may not always do so.
 ***********************************************************************************************************************************/
 // Get default index for a group option
-unsigned int cfgOptionIdxDefault(ConfigOption optionId);
+FN_EXTERN unsigned int cfgOptionIdxDefault(ConfigOption optionId);
 
 // Get boolean config option
-bool cfgOptionIdxBool(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN bool cfgOptionIdxBool(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline bool
+FN_INLINE_ALWAYS bool
 cfgOptionBool(const ConfigOption optionId)
 {
     return cfgOptionIdxBool(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get int config option
-int cfgOptionIdxInt(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN int cfgOptionIdxInt(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline int
+FN_INLINE_ALWAYS int
 cfgOptionInt(const ConfigOption optionId)
 {
     return cfgOptionIdxInt(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get int64 config option
-int64_t cfgOptionIdxInt64(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN int64_t cfgOptionIdxInt64(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline int64_t
+FN_INLINE_ALWAYS int64_t
 cfgOptionInt64(const ConfigOption optionId)
 {
     return cfgOptionIdxInt64(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get kv config option
-const KeyValue *cfgOptionIdxKv(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const KeyValue *cfgOptionIdxKv(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline const KeyValue *
+FN_INLINE_ALWAYS const KeyValue *
 cfgOptionKv(const ConfigOption optionId)
 {
     return cfgOptionIdxKv(optionId, cfgOptionIdxDefault(optionId));
 }
 
-const KeyValue *cfgOptionIdxKvNull(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const KeyValue *cfgOptionIdxKvNull(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline const KeyValue *
+FN_INLINE_ALWAYS const KeyValue *
 cfgOptionKvNull(const ConfigOption optionId)
 {
     return cfgOptionIdxKvNull(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get list config option
-const VariantList *cfgOptionIdxLst(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const VariantList *cfgOptionIdxLst(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline const VariantList *
+FN_INLINE_ALWAYS const VariantList *
 cfgOptionLst(const ConfigOption optionId)
 {
     return cfgOptionIdxLst(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get String config option
-const String *cfgOptionIdxStr(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const String *cfgOptionIdxStr(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 cfgOptionStr(const ConfigOption optionId)
 {
     return cfgOptionIdxStr(optionId, cfgOptionIdxDefault(optionId));
 }
 
-const String *cfgOptionIdxStrNull(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const String *cfgOptionIdxStrNull(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 cfgOptionStrNull(const ConfigOption optionId)
 {
     return cfgOptionIdxStrNull(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get StringId config option
-StringId cfgOptionIdxStrId(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN StringId cfgOptionIdxStrId(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline StringId
+FN_INLINE_ALWAYS StringId
 cfgOptionStrId(const ConfigOption optionId)
 {
     return cfgOptionIdxStrId(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get uint config option
-unsigned int cfgOptionIdxUInt(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN unsigned int cfgOptionIdxUInt(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline unsigned int
+FN_INLINE_ALWAYS unsigned int
 cfgOptionUInt(const ConfigOption optionId)
 {
     return cfgOptionIdxUInt(optionId, cfgOptionIdxDefault(optionId));
 }
 
 // Get uint64 config option
-uint64_t cfgOptionIdxUInt64(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN uint64_t cfgOptionIdxUInt64(ConfigOption optionId, unsigned int optionIdx);
 
-__attribute__((always_inline)) static inline uint64_t
+FN_INLINE_ALWAYS uint64_t
 cfgOptionUInt64(const ConfigOption optionId)
 {
     return cfgOptionIdxUInt64(optionId, cfgOptionIdxDefault(optionId));
@@ -207,19 +204,19 @@ cfgOptionUInt64(const ConfigOption optionId)
 // command line, config, etc., then that exact value will be displayed. This makes it easier for the user to recognize the value and
 // saves having to format it into something reasonable, especially for time and size option types. Note that cfgOptTypeHash and
 // cfgOptTypeList option types are not supported by these functions, but they are generally not displayed to the user as a whole.
-const String *cfgOptionDisplay(const ConfigOption optionId);
-const String *cfgOptionIdxDisplay(const ConfigOption optionId, const unsigned int optionIdx);
+FN_EXTERN const String *cfgOptionDisplay(const ConfigOption optionId);
+FN_EXTERN const String *cfgOptionIdxDisplay(const ConfigOption optionId, const unsigned int optionIdx);
 
 // Option name by id
-const char *cfgOptionName(ConfigOption optionId);
-const char *cfgOptionIdxName(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN const char *cfgOptionName(ConfigOption optionId);
+FN_EXTERN const char *cfgOptionIdxName(ConfigOption optionId, unsigned int optionIdx);
 
 // Is the option valid for this command?
-bool cfgOptionValid(ConfigOption optionId);
+FN_EXTERN bool cfgOptionValid(ConfigOption optionId);
 
 // Is the option valid for the command and also has a value?
-bool cfgOptionTest(ConfigOption optionId);
-bool cfgOptionIdxTest(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN bool cfgOptionTest(ConfigOption optionId);
+FN_EXTERN bool cfgOptionIdxTest(ConfigOption optionId, unsigned int optionIdx);
 
 /***********************************************************************************************************************************
 Option Source Enum
@@ -241,31 +238,29 @@ Used primarily by modules that need to manipulate the configuration.  These modu
 config/load.c.
 ***********************************************************************************************************************************/
 // Was help requested?
-bool cfgCommandHelp(void);
+FN_EXTERN bool cfgCommandHelp(void);
 
-void cfgCommandSet(ConfigCommand commandId, ConfigCommandRole commandRoleId);
+FN_EXTERN void cfgCommandSet(ConfigCommand commandId, ConfigCommandRole commandRoleId);
 
 // pgBackRest exe
-const String *cfgExe(void);
+FN_EXTERN const String *cfgExe(void);
 
 // Set option default. Option defaults are generally not set in advance because the vast majority of them are never used.  It is
 // more efficient to generate them when they are requested. Some defaults are (e.g. the exe path) are set at runtime.
-void cfgOptionDefaultSet(ConfigOption optionId, const Variant *defaultValue);
+FN_EXTERN void cfgOptionDefaultSet(ConfigOption optionId, const Variant *defaultValue);
 
 // Was the option negated?
-bool cfgOptionNegate(ConfigOption optionId);
-bool cfgOptionIdxNegate(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN bool cfgOptionIdxNegate(ConfigOption optionId, unsigned int optionIdx);
 
 // Was the option reset?
-bool cfgOptionReset(ConfigOption optionId);
-bool cfgOptionIdxReset(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN bool cfgOptionIdxReset(ConfigOption optionId, unsigned int optionIdx);
 
 // Set config option
-void cfgOptionSet(ConfigOption optionId, ConfigSource source, const Variant *value);
-void cfgOptionIdxSet(ConfigOption optionId, unsigned int optionIdx, ConfigSource source, const Variant *value);
+FN_EXTERN void cfgOptionSet(ConfigOption optionId, ConfigSource source, const Variant *value);
+FN_EXTERN void cfgOptionIdxSet(ConfigOption optionId, unsigned int optionIdx, ConfigSource source, const Variant *value);
 
 // How was the option set (default, param, config)?
-ConfigSource cfgOptionSource(ConfigOption optionId);
-ConfigSource cfgOptionIdxSource(ConfigOption optionId, unsigned int optionIdx);
+FN_EXTERN ConfigSource cfgOptionSource(ConfigOption optionId);
+FN_EXTERN ConfigSource cfgOptionIdxSource(ConfigOption optionId, unsigned int optionIdx);
 
 #endif
