@@ -10,19 +10,19 @@ Configuration Load
 #include "command/command.h"
 #include "common/compress/helper.intern.h"
 #include "common/crypto/common.h"
-#include "common/memContext.h"
 #include "common/debug.h"
 #include "common/io/io.h"
 #include "common/io/socket/common.h"
 #include "common/lock.h"
 #include "common/log.h"
+#include "common/memContext.h"
 #include "config/config.intern.h"
 #include "config/load.h"
 #include "config/parse.h"
 #include "info/infoBackup.h"
 #include "storage/cifs/storage.h"
-#include "storage/posix/storage.h"
 #include "storage/helper.h"
+#include "storage/posix/storage.h"
 
 /***********************************************************************************************************************************
 Load log settings
@@ -149,7 +149,7 @@ cfgLoadUpdateOption(void)
             THROW_FMT(
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
-                    " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
+                " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
                 strZ(cfgOptionDisplay(cfgOptProtocolTimeout)), strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),
                 strZ(cfgOptionDisplay(cfgOptDbTimeout)));
         }
@@ -219,11 +219,11 @@ cfgLoadUpdateOption(void)
                 {
                     case backupTypeFull:
                     {
-                        if (cfgOptionIdxStrId(cfgOptRepoRetentionFullType, optionIdx) ==
-                                CFGOPTVAL_REPO_RETENTION_FULL_TYPE_COUNT &&
+                        if (cfgOptionIdxStrId(cfgOptRepoRetentionFullType, optionIdx) == CFGOPTVAL_REPO_RETENTION_FULL_TYPE_COUNT &&
                             cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx))
                         {
-                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            cfgOptionIdxSet(
+                                cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
                                 VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionFull, optionIdx)));
                         }
 
@@ -235,7 +235,8 @@ cfgLoadUpdateOption(void)
                         // if repo-retention-diff is set then user must have set it
                         if (cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
                         {
-                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            cfgOptionIdxSet(
+                                cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
                                 VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionDiff, optionIdx)));
                         }
                         else
@@ -282,10 +283,10 @@ cfgLoadUpdateOption(void)
         {
             THROW_FMT(
                 OptionInvalidValueError,
-                "'%s' is not valid for option '%s'"
-                    "\nHINT: RFC-2818 forbids dots in wildcard matches."
-                    "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
-                    "\nHINT: remove dots from the bucket name.",
+                "'%s' is not valid for option '%s'\n"
+                "HINT: RFC-2818 forbids dots in wildcard matches.\n"
+                "HINT: TLS/SSL verification cannot proceed with this bucket name.\n"
+                "HINT: remove dots from the bucket name.",
                 strZ(cfgOptionIdxDisplay(cfgOptRepoS3Bucket, repoIdx)), cfgOptionIdxName(cfgOptRepoS3Bucket, repoIdx));
         }
     }
@@ -396,7 +397,7 @@ cfgLoadLogFileName(const ConfigCommandRole commandRole)
     String *const result = strCatFmt(
         strNew(),
         "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
-        cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName());
+        cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)) : "all", cfgCommandName());
 
     // ??? Append async for local/remote archive async commands. It would be good to find a more generic way to do this in case the
     // async role is added to more commands.
