@@ -11,7 +11,7 @@ Azure Storage Helper
 #include "storage/azure/helper.h"
 
 /**********************************************************************************************************************************/
-Storage *
+FN_EXTERN Storage *
 storageAzureHelper(const unsigned int repoIdx, const bool write, StoragePathExpressionCallback pathExpressionCallback)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -57,7 +57,7 @@ storageAzureHelper(const unsigned int repoIdx, const bool write, StoragePathExpr
         {
             TRY_BEGIN()
             {
-                bufNewDecode(encodeBase64, key);
+                bufNewDecode(encodingBase64, key);
             }
             CATCH(FormatError)
             {
@@ -79,8 +79,8 @@ storageAzureHelper(const unsigned int repoIdx, const bool write, StoragePathExpr
             result = storageAzureNew(
                 cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, pathExpressionCallback,
                 cfgOptionIdxStr(cfgOptRepoAzureContainer, repoIdx), cfgOptionIdxStr(cfgOptRepoAzureAccount, repoIdx), keyType, key,
-                STORAGE_AZURE_BLOCKSIZE_MIN, endpoint, uriStyle, port, ioTimeoutMs(), cfgOptionIdxBool(cfgOptRepoStorageVerifyTls,
-                repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx),
+                (size_t)cfgOptionIdxUInt64(cfgOptRepoStorageUploadChunkSize, repoIdx), endpoint, uriStyle, port, ioTimeoutMs(),
+                cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx),
                 cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
         }
         MEM_CONTEXT_PRIOR_END();
