@@ -53,7 +53,7 @@ Macros for function logging
 #define FUNCTION_LOG_STORAGE_WRITE_AZURE_TYPE                                                                                      \
     StorageWriteAzure *
 #define FUNCTION_LOG_STORAGE_WRITE_AZURE_FORMAT(value, buffer, bufferSize)                                                         \
-    objToLog(value, "StorageWriteAzure", buffer, bufferSize)
+    objNameToLog(value, "StorageWriteAzure", buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Open the file
@@ -178,8 +178,10 @@ storageWriteAzure(THIS_VOID, const Buffer *buffer)
     do
     {
         // Copy as many bytes as possible into the block buffer
-        size_t bytesNext = bufRemains(this->blockBuffer) > bufUsed(buffer) - bytesTotal ?
-            bufUsed(buffer) - bytesTotal : bufRemains(this->blockBuffer);
+        const size_t bytesNext =
+            bufRemains(this->blockBuffer) > bufUsed(buffer) - bytesTotal ?
+                bufUsed(buffer) - bytesTotal : bufRemains(this->blockBuffer);
+
         bufCatSub(this->blockBuffer, buffer, bytesTotal, bytesNext);
         bytesTotal += bytesNext;
 
@@ -259,8 +261,8 @@ storageWriteAzureClose(THIS_VOID)
 }
 
 /**********************************************************************************************************************************/
-StorageWrite *
-storageWriteAzureNew(StorageAzure *storage, const String *name, uint64_t fileId, size_t blockSize)
+FN_EXTERN StorageWrite *
+storageWriteAzureNew(StorageAzure *const storage, const String *const name, const uint64_t fileId, const size_t blockSize)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_AZURE, storage);
@@ -272,13 +274,13 @@ storageWriteAzureNew(StorageAzure *storage, const String *name, uint64_t fileId,
     ASSERT(storage != NULL);
     ASSERT(name != NULL);
 
-    StorageWrite *this = NULL;
+    StorageWriteAzure *this = NULL;
 
-    OBJ_NEW_BEGIN(StorageWriteAzure, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
+    OBJ_NEW_BEGIN(StorageWriteAzure, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        StorageWriteAzure *driver = OBJ_NEW_ALLOC();
+        this = OBJ_NEW_ALLOC();
 
-        *driver = (StorageWriteAzure)
+        *this = (StorageWriteAzure)
         {
             .storage = storage,
             .fileId = fileId,
@@ -292,6 +294,7 @@ storageWriteAzureNew(StorageAzure *storage, const String *name, uint64_t fileId,
                 .createPath = true,
                 .syncFile = true,
                 .syncPath = true,
+                .truncate = true,
 
                 .ioInterface = (IoWriteInterface)
                 {
@@ -301,10 +304,8 @@ storageWriteAzureNew(StorageAzure *storage, const String *name, uint64_t fileId,
                 },
             },
         };
-
-        this = storageWriteNew(driver, &driver->interface);
     }
     OBJ_NEW_END();
 
-    FUNCTION_LOG_RETURN(STORAGE_WRITE, this);
+    FUNCTION_LOG_RETURN(STORAGE_WRITE, storageWriteNew(this, &this->interface));
 }
