@@ -130,13 +130,13 @@ storageReadGcsNew(
     ASSERT(storage != NULL);
     ASSERT(name != NULL);
 
-    StorageRead *this = NULL;
+    StorageReadGcs *this = NULL;
 
     OBJ_NEW_BEGIN(StorageReadGcs, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
-        StorageReadGcs *const driver = OBJ_NAME(OBJ_NEW_ALLOC(), StorageRead::StorageReadGcs);
+        this = OBJ_NEW_ALLOC();
 
-        *driver = (StorageReadGcs)
+        *this = (StorageReadGcs)
         {
             .storage = storage,
 
@@ -156,10 +156,8 @@ storageReadGcsNew(
                 },
             },
         };
-
-        this = storageReadNew(driver, &driver->interface);
     }
     OBJ_NEW_END();
 
-    FUNCTION_LOG_RETURN(STORAGE_READ, this);
+    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadNew(this, &this->interface));
 }
