@@ -11,9 +11,9 @@ Storage Helper
 #include "common/regExp.h"
 #include "config/config.h"
 #include "protocol/helper.h"
+#include "storage/helper.h"
 #include "storage/posix/storage.h"
 #include "storage/remote/storage.h"
-#include "storage/helper.h"
 
 /***********************************************************************************************************************************
 Storage path constants
@@ -71,7 +71,7 @@ storageHelperContextInit(void)
     {
         MEM_CONTEXT_BEGIN(memContextTop())
         {
-            MEM_CONTEXT_NEW_BEGIN("StorageHelper")
+            MEM_CONTEXT_NEW_BEGIN(StorageHelper, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
             {
                 storageHelper.memContext = MEM_CONTEXT_NEW();
             }
@@ -84,7 +84,8 @@ storageHelperContextInit(void)
 }
 
 /**********************************************************************************************************************************/
-void storageHelperInit(const StorageHelper *const helperList)
+FN_EXTERN void
+storageHelperInit(const StorageHelper *const helperList)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, helperList);
@@ -96,7 +97,7 @@ void storageHelperInit(const StorageHelper *const helperList)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageHelperDryRunInit(bool dryRun)
 {
     FUNCTION_TEST_VOID();
@@ -133,7 +134,7 @@ storageHelperStanzaInit(const bool stanzaRequired)
 }
 
 /**********************************************************************************************************************************/
-const Storage *
+FN_EXTERN const Storage *
 storageLocal(void)
 {
     FUNCTION_TEST_VOID();
@@ -144,15 +145,15 @@ storageLocal(void)
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.storageLocal =  storagePosixNewP(FSLASH_STR);
+            storageHelper.storageLocal = storagePosixNewP(FSLASH_STR);
         }
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageLocal);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageLocal);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storageLocalWrite(void)
 {
     FUNCTION_TEST_VOID();
@@ -168,7 +169,7 @@ storageLocalWrite(void)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageLocalWrite);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageLocalWrite);
 }
 
 /***********************************************************************************************************************************
@@ -197,11 +198,11 @@ storagePgGet(unsigned int pgIdx, bool write)
         result = storagePosixNewP(cfgOptionIdxStr(cfgOptPgPath, pgIdx), .write = write);
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STORAGE, result);
 }
 
 /**********************************************************************************************************************************/
-const Storage *
+FN_EXTERN const Storage *
 storagePgIdx(unsigned int pgIdx)
 {
     FUNCTION_TEST_BEGIN();
@@ -222,17 +223,17 @@ storagePgIdx(unsigned int pgIdx)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storagePg[pgIdx]);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storagePg[pgIdx]);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storagePg(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RETURN(storagePgIdx(cfgOptionGroupIdxDefault(cfgOptGrpPg)));
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storagePgIdx(cfgOptionGroupIdxDefault(cfgOptGrpPg)));
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storagePgIdxWrite(unsigned int pgIdx)
 {
     FUNCTION_TEST_BEGIN();
@@ -257,14 +258,14 @@ storagePgIdxWrite(unsigned int pgIdx)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storagePgWrite[pgIdx]);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storagePgWrite[pgIdx]);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storagePgWrite(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RETURN(storagePgIdxWrite(cfgOptionGroupIdxDefault(cfgOptGrpPg)));
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storagePgIdxWrite(cfgOptionGroupIdxDefault(cfgOptGrpPg)));
 }
 
 /***********************************************************************************************************************************
@@ -291,7 +292,7 @@ storageHelperRepoInit(void)
 Construct a repo path from an expression and path
 ***********************************************************************************************************************************/
 static String *
-storageRepoPathExpression(const String *expression, const String *path)
+storageRepoPathExpression(const String *const expression, const String *const path)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, expression);
@@ -300,35 +301,37 @@ storageRepoPathExpression(const String *expression, const String *path)
 
     ASSERT(expression != NULL);
 
-    String *result = NULL;
+    String *const result = strNew();
 
     if (strEq(expression, STORAGE_REPO_ARCHIVE_STR))
     {
         // Construct the base path
         if (storageHelper.stanza != NULL)
-            result = strCatFmt(strNew(), STORAGE_PATH_ARCHIVE "/%s", strZ(storageHelper.stanza));
+            strCatFmt(result, STORAGE_PATH_ARCHIVE "/%s", strZ(storageHelper.stanza));
         else
-            result = strCatZ(strNew(), STORAGE_PATH_ARCHIVE);
+            strCat(result, STORAGE_PATH_ARCHIVE_STR);
 
         // If a subpath should be appended, determine if it is WAL path, else just append the subpath
         if (path != NULL)
         {
-            StringList *pathSplit = strLstNewSplitZ(path, "/");
-            String *file = strLstSize(pathSplit) == 2 ? strLstGet(pathSplit, 1) : NULL;
+            StringList *const pathSplit = strLstNewSplitZ(path, "/");
+            const String *const file = strLstSize(pathSplit) == 2 ? strLstGet(pathSplit, 1) : NULL;
 
             if (file != NULL && regExpMatch(storageHelper.walRegExp, file))
-                strCatFmt(result, "/%s/%s/%s", strZ(strLstGet(pathSplit, 0)), strZ(strSubN(file, 0, 16)), strZ(file));
+                strCatFmt(result, "/%s/%.16s/%s", strZ(strLstGet(pathSplit, 0)), strZ(file), strZ(file));
             else
                 strCatFmt(result, "/%s", strZ(path));
+
+            strLstFree(pathSplit);
         }
     }
     else if (strEq(expression, STORAGE_REPO_BACKUP_STR))
     {
         // Construct the base path
         if (storageHelper.stanza != NULL)
-            result = strCatFmt(strNew(), STORAGE_PATH_BACKUP "/%s", strZ(storageHelper.stanza));
+            strCatFmt(result, STORAGE_PATH_BACKUP "/%s", strZ(storageHelper.stanza));
         else
-            result = strCatZ(strNew(), STORAGE_PATH_BACKUP);
+            strCatZ(result, STORAGE_PATH_BACKUP);
 
         // Append subpath if provided
         if (path != NULL)
@@ -337,7 +340,9 @@ storageRepoPathExpression(const String *expression, const String *path)
     else
         THROW_FMT(AssertError, "invalid expression '%s'", strZ(expression));
 
-    FUNCTION_TEST_RETURN(result);
+    ASSERT(result != 0);
+
+    FUNCTION_TEST_RETURN(STRING, result);
 }
 
 /***********************************************************************************************************************************
@@ -388,11 +393,11 @@ storageRepoGet(unsigned int repoIdx, bool write)
         }
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STORAGE, result);
 }
 
 /**********************************************************************************************************************************/
-const Storage *
+FN_EXTERN const Storage *
 storageRepoIdx(unsigned int repoIdx)
 {
     FUNCTION_TEST_BEGIN();
@@ -421,17 +426,17 @@ storageRepoIdx(unsigned int repoIdx)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageRepo[repoIdx]);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageRepo[repoIdx]);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storageRepo(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RETURN(storageRepoIdx(cfgOptionGroupIdxDefault(cfgOptGrpRepo)));
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageRepoIdx(cfgOptionGroupIdxDefault(cfgOptGrpRepo)));
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storageRepoIdxWrite(unsigned int repoIdx)
 {
     FUNCTION_TEST_BEGIN();
@@ -464,14 +469,14 @@ storageRepoIdxWrite(unsigned int repoIdx)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageRepoWrite[repoIdx]);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageRepoWrite[repoIdx]);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storageRepoWrite(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RETURN(storageRepoIdxWrite(cfgOptionGroupIdxDefault(cfgOptGrpRepo)));
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageRepoIdxWrite(cfgOptionGroupIdxDefault(cfgOptGrpRepo)));
 }
 
 /***********************************************************************************************************************************
@@ -514,11 +519,11 @@ storageSpoolPathExpression(const String *expression, const String *path)
     else
         THROW_FMT(AssertError, "invalid expression '%s'", strZ(expression));
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STRING, result);
 }
 
 /**********************************************************************************************************************************/
-const Storage *
+FN_EXTERN const Storage *
 storageSpool(void)
 {
     FUNCTION_TEST_VOID();
@@ -536,10 +541,10 @@ storageSpool(void)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageSpool);
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageSpool);
 }
 
-const Storage *
+FN_EXTERN const Storage *
 storageSpoolWrite(void)
 {
     FUNCTION_TEST_VOID();
@@ -561,19 +566,5 @@ storageSpoolWrite(void)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RETURN(storageHelper.storageSpoolWrite);
-}
-
-/**********************************************************************************************************************************/
-void
-storageHelperFree(void)
-{
-    FUNCTION_TEST_VOID();
-
-    if (storageHelper.memContext != NULL)
-        memContextFree(storageHelper.memContext);
-
-    storageHelper = (struct StorageHelperLocal){.memContext = NULL, .helperList = storageHelper.helperList};
-
-    FUNCTION_TEST_RETURN_VOID();
+    FUNCTION_TEST_RETURN_CONST(STORAGE, storageHelper.storageSpoolWrite);
 }
