@@ -3,21 +3,16 @@ Remote Storage Protocol Handler
 ***********************************************************************************************************************************/
 #include "build.auto.h"
 
-#include "command/backup/pageChecksum.h"
 #include "common/compress/helper.h"
-#include "common/crypto/cipherBlock.h"
-#include "common/crypto/hash.h"
 #include "common/debug.h"
-#include "common/io/filter/sink.h"
-#include "common/io/filter/size.h"
 #include "common/io/io.h"
 #include "common/log.h"
 #include "common/regExp.h"
 #include "common/type/pack.h"
 #include "config/config.h"
 #include "protocol/helper.h"
-#include "storage/remote/protocol.h"
 #include "storage/helper.h"
+#include "storage/remote/protocol.h"
 #include "storage/storage.intern.h"
 
 /***********************************************************************************************************************************
@@ -27,8 +22,31 @@ static struct
 {
     MemContext *memContext;                                         // Mem context
     void *driver;                                                   // Storage driver used for requests
+
+    const StorageRemoteFilterHandler *filterHandler;                // Filter handler list
+    unsigned int filterHandlerSize;                                 // Filter handler list size
 } storageRemoteProtocolLocal;
 
+/***********************************************************************************************************************************
+Set filter handlers
+***********************************************************************************************************************************/
+FN_EXTERN void
+storageRemoteFilterHandlerSet(const StorageRemoteFilterHandler *filterHandler, unsigned int filterHandlerSize)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, filterHandler);
+        FUNCTION_TEST_PARAM(UINT, filterHandlerSize);
+    FUNCTION_TEST_END();
+
+    ASSERT(filterHandler != NULL);
+    ASSERT(filterHandlerSize > 0);
+
+    storageRemoteProtocolLocal.filterHandler = filterHandler;
+    storageRemoteProtocolLocal.filterHandlerSize = filterHandlerSize;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
 /***********************************************************************************************************************************
 Set filter group based on passed filters
 ***********************************************************************************************************************************/
@@ -52,37 +70,51 @@ storageRemoteFilterGroup(IoFilterGroup *const filterGroup, const Pack *const fil
             const StringId filterKey = pckReadStrIdP(filterList);
             const Pack *const filterParam = pckReadPackP(filterList);
 
+            // If a compression filter
             IoFilter *filter = compressFilterPack(filterKey, filterParam);
 
             if (filter != NULL)
+            {
                 ioFilterGroupAdd(filterGroup, filter);
+            }
+            // Else a filter handler
             else
             {
-                switch (filterKey)
+                ASSERT(storageRemoteProtocolLocal.filterHandler != NULL);
+
+                // Search for a filter handler
+                unsigned int filterIdx = 0;
+
+                for (; filterIdx < storageRemoteProtocolLocal.filterHandlerSize; filterIdx++)
                 {
-                    case CIPHER_BLOCK_FILTER_TYPE:
-                        ioFilterGroupAdd(filterGroup, cipherBlockNewPack(filterParam));
-                        break;
+                    // If a match create the filter
+                    if (storageRemoteProtocolLocal.filterHandler[filterIdx].type == filterKey)
+                    {
+                        // Create a filter with parameters
+                        if (storageRemoteProtocolLocal.filterHandler[filterIdx].handlerParam != NULL)
+                        {
+                            ASSERT(filterParam != NULL);
 
-                    case CRYPTO_HASH_FILTER_TYPE:
-                        ioFilterGroupAdd(filterGroup, cryptoHashNewPack(filterParam));
-                        break;
+                            ioFilterGroupAdd(
+                                filterGroup, storageRemoteProtocolLocal.filterHandler[filterIdx].handlerParam(filterParam));
+                        }
+                        // Else create a filter without parameters
+                        else
+                        {
+                            ASSERT(storageRemoteProtocolLocal.filterHandler[filterIdx].handlerNoParam != NULL);
+                            ASSERT(filterParam == NULL);
 
-                    case PAGE_CHECKSUM_FILTER_TYPE:
-                        ioFilterGroupAdd(filterGroup, pageChecksumNewPack(filterParam));
-                        break;
+                            ioFilterGroupAdd(filterGroup, storageRemoteProtocolLocal.filterHandler[filterIdx].handlerNoParam());
+                        }
 
-                    case SINK_FILTER_TYPE:
-                        ioFilterGroupAdd(filterGroup, ioSinkNew());
+                        // Break on filter match
                         break;
-
-                    case SIZE_FILTER_TYPE:
-                        ioFilterGroupAdd(filterGroup, ioSizeNew());
-                        break;
-
-                    default:
-                        THROW_FMT(AssertError, "unable to add filter '%s'", strZ(strIdToStr(filterKey)));
+                    }
                 }
+
+                // Error when the filter was not found
+                if (filterIdx == storageRemoteProtocolLocal.filterHandlerSize)
+                    THROW_FMT(AssertError, "unable to add filter '%s'", strZ(strIdToStr(filterKey)));
             }
         }
     }
@@ -92,7 +124,7 @@ storageRemoteFilterGroup(IoFilterGroup *const filterGroup, const Pack *const fil
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemoteFeatureProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -100,6 +132,8 @@ storageRemoteFeatureProtocol(PackRead *const param, ProtocolServer *const server
         FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
     FUNCTION_LOG_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(param == NULL);
     ASSERT(server != NULL);
 
@@ -140,7 +174,6 @@ storageRemoteFeatureProtocol(PackRead *const param, ProtocolServer *const server
 /**********************************************************************************************************************************/
 typedef struct StorageRemoteInfoProcotolWriteData
 {
-    MemContext *memContext;                                         // Mem context used to store values from last call
     time_t timeModifiedLast;                                        // timeModified from last call
     mode_t modeLast;                                                // mode from last call
     uid_t userIdLast;                                               // userId from last call
@@ -163,6 +196,8 @@ storageRemoteInfoProtocolPut(
         FUNCTION_TEST_PARAM(STORAGE_INFO, info);
     FUNCTION_TEST_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(data != NULL);
     ASSERT(write != NULL);
     ASSERT(info != NULL);
@@ -208,42 +243,28 @@ storageRemoteInfoProtocolPut(
             pckWriteStrP(write, info->linkDestination);
     }
 
-    // Store defaults to use for the next call. If memContext is NULL this function is only being called one time so there is no
-    // point in storing defaults.
-    if (data->memContext != NULL)
+    // Store defaults to use for the next call
+    data->timeModifiedLast = info->timeModified;
+    data->modeLast = info->mode;
+    data->userIdLast = info->userId;
+    data->groupIdLast = info->groupId;
+
+    if (info->user != NULL && !strEq(info->user, data->user))                                                       // {vm_covered}
     {
-        data->timeModifiedLast = info->timeModified;
-        data->modeLast = info->mode;
-        data->userIdLast = info->userId;
-        data->groupIdLast = info->groupId;
+        strFree(data->user);
+        data->user = strDup(info->user);
+    }
 
-        if (info->user != NULL && !strEq(info->user, data->user))                                                   // {vm_covered}
-        {
-            strFree(data->user);
-
-            MEM_CONTEXT_BEGIN(data->memContext)
-            {
-                data->user = strDup(info->user);
-            }
-            MEM_CONTEXT_END();
-        }
-
-        if (info->group != NULL && !strEq(info->group, data->group))                                                // {vm_covered}
-        {
-            strFree(data->group);
-
-            MEM_CONTEXT_BEGIN(data->memContext)
-            {
-                data->group = strDup(info->group);
-            }
-            MEM_CONTEXT_END();
-        }
+    if (info->group != NULL && !strEq(info->group, data->group))                                                    // {vm_covered}
+    {
+        strFree(data->group);
+        data->group = strDup(info->group);
     }
 
     FUNCTION_TEST_RETURN_VOID();
 }
 
-void
+FN_EXTERN void
 storageRemoteInfoProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -280,7 +301,34 @@ storageRemoteInfoProtocol(PackRead *const param, ProtocolServer *const server)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
+storageRemoteLinkCreateProtocol(PackRead *const param, ProtocolServer *const server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(PACK_READ, param);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(param != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        const String *const target = pckReadStrP(param);
+        const String *const linkPath = pckReadStrP(param);
+        const StorageLinkType linkType = (StorageLinkType)pckReadU32P(param);
+
+        storageInterfaceLinkCreateP(storageRemoteProtocolLocal.driver, target, linkPath, .linkType = linkType);
+        protocolServerDataEndPut(server);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN void
 storageRemoteListProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -296,7 +344,7 @@ storageRemoteListProtocol(PackRead *const param, ProtocolServer *const server)
     {
         const String *const path = pckReadStrP(param);
         const StorageInfoLevel level = (StorageInfoLevel)pckReadU32P(param);
-        StorageRemoteInfoProtocolWriteData writeData = {.memContext = memContextCurrent()};
+        StorageRemoteInfoProtocolWriteData writeData = {0};
         StorageList *const list = storageInterfaceListP(storageRemoteProtocolLocal.driver, path, level);
 
         // Put list
@@ -327,7 +375,7 @@ storageRemoteListProtocol(PackRead *const param, ProtocolServer *const server)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemoteOpenReadProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -397,7 +445,7 @@ storageRemoteOpenReadProtocol(PackRead *const param, ProtocolServer *const serve
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemoteOpenWriteProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -428,7 +476,7 @@ storageRemoteOpenWriteProtocol(PackRead *const param, ProtocolServer *const serv
             storageInterfaceNewWriteP(
                 storageRemoteProtocolLocal.driver, file, .modeFile = modeFile, .modePath = modePath, .user = user, .group = group,
                 .timeModified = timeModified, .createPath = createPath, .syncFile = syncFile, .syncPath = syncPath,
-                .atomic = atomic));
+                .atomic = atomic, .truncate = true));
 
         // Set filter group based on passed filters
         storageRemoteFilterGroup(ioWriteFilterGroup(fileWrite), filter);
@@ -484,7 +532,7 @@ storageRemoteOpenWriteProtocol(PackRead *const param, ProtocolServer *const serv
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemotePathCreateProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -512,7 +560,7 @@ storageRemotePathCreateProtocol(PackRead *const param, ProtocolServer *const ser
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemotePathRemoveProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -540,7 +588,7 @@ storageRemotePathRemoveProtocol(PackRead *const param, ProtocolServer *const ser
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemotePathSyncProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -565,7 +613,7 @@ storageRemotePathSyncProtocol(PackRead *const param, ProtocolServer *const serve
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 storageRemoteRemoveProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
