@@ -10,7 +10,6 @@ Remote Storage
 #include "common/type/pack.h"
 #include "storage/remote/protocol.h"
 #include "storage/remote/read.h"
-#include "storage/remote/storage.intern.h"
 #include "storage/remote/write.h"
 
 /***********************************************************************************************************************************
@@ -45,6 +44,8 @@ storageRemoteInfoGet(StorageRemoteInfoData *const data, PackRead *const read, St
         FUNCTION_TEST_PARAM(STORAGE_INFO, info);
     FUNCTION_TEST_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(data != NULL);
     ASSERT(read != NULL);
     ASSERT(info != NULL);
@@ -127,6 +128,8 @@ storageRemoteInfo(THIS_VOID, const String *file, StorageInfoLevel level, Storage
         FUNCTION_LOG_PARAM(BOOL, param.followLink);
     FUNCTION_LOG_END();
 
+    FUNCTION_AUDIT_STRUCT();
+
     ASSERT(this != NULL);
 
     StorageInfo result = {.level = level};
@@ -167,6 +170,40 @@ storageRemoteInfo(THIS_VOID, const String *file, StorageInfoLevel level, Storage
     FUNCTION_LOG_RETURN(STORAGE_INFO, result);
 }
 
+/**********************************************************************************************************************************/
+static void
+storageRemoteLinkCreate(
+    THIS_VOID, const String *const target, const String *const linkPath, const StorageInterfaceLinkCreateParam param)
+{
+    THIS(StorageRemote);
+
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
+        FUNCTION_LOG_PARAM(STRING, target);
+        FUNCTION_LOG_PARAM(STRING, linkPath);
+        FUNCTION_LOG_PARAM(ENUM, param.linkType);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+    ASSERT(target != NULL);
+    ASSERT(linkPath != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        ProtocolCommand *const command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_LINK_CREATE);
+        PackWrite *const commandParam = protocolCommandParam(command);
+
+        pckWriteStrP(commandParam, target);
+        pckWriteStrP(commandParam, linkPath);
+        pckWriteU32P(commandParam, param.linkType);
+
+        protocolClientExecute(this->client, command, false);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
 /**********************************************************************************************************************************/
 static StorageList *
 storageRemoteList(THIS_VOID, const String *const path, const StorageInfoLevel level, const StorageInterfaceListParam param)
@@ -281,6 +318,7 @@ storageRemoteNewWrite(
 
     ASSERT(this != NULL);
     ASSERT(file != NULL);
+    ASSERT(param.truncate);
 
     FUNCTION_LOG_RETURN(
         STORAGE_WRITE,
@@ -427,12 +465,13 @@ static const StorageInterface storageInterfaceRemote =
     .pathRemove = storageRemotePathRemove,
     .pathSync = storageRemotePathSync,
     .remove = storageRemoteRemove,
+    .linkCreate = storageRemoteLinkCreate,
 };
 
-Storage *
+FN_EXTERN Storage *
 storageRemoteNew(
-    mode_t modeFile, mode_t modePath, bool write, StoragePathExpressionCallback pathExpressionFunction, ProtocolClient *client,
-    unsigned int compressLevel)
+    const mode_t modeFile, const mode_t modePath, const bool write, StoragePathExpressionCallback pathExpressionFunction,
+    ProtocolClient *const client, const unsigned int compressLevel)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(MODE, modeFile);
@@ -447,26 +486,25 @@ storageRemoteNew(
     ASSERT(modePath != 0);
     ASSERT(client != NULL);
 
-    Storage *this = NULL;
+    StorageRemote *this = NULL;
+    const String *path = NULL;
 
     OBJ_NEW_BEGIN(StorageRemote, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
-        StorageRemote *driver = OBJ_NEW_ALLOC();
+        this = OBJ_NEW_ALLOC();
 
-        *driver = (StorageRemote)
+        *this = (StorageRemote)
         {
             .client = client,
             .compressLevel = compressLevel,
             .interface = storageInterfaceRemote,
         };
 
-        const String *path = NULL;
-
         // Get storage features from the remote
         MEM_CONTEXT_TEMP_BEGIN()
         {
             // Execute command and get result
-            PackRead *result = protocolClientExecute(driver->client, protocolCommandNew(PROTOCOL_COMMAND_STORAGE_FEATURE), true);
+            PackRead *result = protocolClientExecute(this->client, protocolCommandNew(PROTOCOL_COMMAND_STORAGE_FEATURE), true);
 
             // Get path in parent context
             MEM_CONTEXT_PRIOR_BEGIN()
@@ -475,13 +513,12 @@ storageRemoteNew(
             }
             MEM_CONTEXT_PRIOR_END();
 
-            driver->interface.feature = pckReadU64P(result);
+            this->interface.feature = pckReadU64P(result);
         }
         MEM_CONTEXT_TEMP_END();
-
-        this = storageNew(STORAGE_REMOTE_TYPE, path, modeFile, modePath, write, pathExpressionFunction, driver, driver->interface);
     }
     OBJ_NEW_END();
 
-    FUNCTION_LOG_RETURN(STORAGE, this);
+    FUNCTION_LOG_RETURN(
+        STORAGE, storageNew(STORAGE_REMOTE_TYPE, path, modeFile, modePath, write, pathExpressionFunction, this, this->interface));
 }
