@@ -15,7 +15,7 @@ Storage type
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-Storage *storageRemoteNew(
+FN_EXTERN Storage *storageRemoteNew(
     mode_t modeFile, mode_t modePath, bool write, StoragePathExpressionCallback pathExpressionFunction, ProtocolClient *client,
     unsigned int compressLevel);
 
