@@ -30,18 +30,14 @@ typedef enum
     storageS3UriStylePath = STRID5("path", 0x450300),
 } StorageS3UriStyle;
 
-/***********************************************************************************************************************************
-Defaults
-***********************************************************************************************************************************/
-#define STORAGE_S3_PARTSIZE_MIN                                     ((size_t)5 * 1024 * 1024)
-
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-Storage *storageS3New(
+FN_EXTERN Storage *storageS3New(
     const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
     const String *endPoint, StorageS3UriStyle uriStyle, const String *region, StorageS3KeyType keyType, const String *accessKey,
-    const String *secretAccessKey, const String *securityToken, const String *credRole, const String *webIdToken, size_t partSize,
-    const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath);
+    const String *secretAccessKey, const String *securityToken, const String *kmsKeyId, const String *credRole,
+    const String *webIdToken, size_t partSize, const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer,
+    const String *caFile, const String *caPath);
 
 #endif
