@@ -575,6 +575,8 @@ sub backupCompare
     my $oActualManifest = new pgBackRestTest::Env::Manifest(
         $self->repoBackupPath("${strBackup}/" . FILE_MANIFEST), {strCipherPass => $self->cipherPassManifest()});
 
+    ${$oExpectedManifest}{&MANIFEST_SECTION_BACKUP}{'backup-reference'} =
+        $oActualManifest->get(MANIFEST_SECTION_BACKUP, 'backup-reference');
     ${$oExpectedManifest}{&MANIFEST_SECTION_BACKUP}{&MANIFEST_KEY_TIMESTAMP_START} =
         $oActualManifest->get(MANIFEST_SECTION_BACKUP, &MANIFEST_KEY_TIMESTAMP_START);
     ${$oExpectedManifest}{&MANIFEST_SECTION_BACKUP}{&MANIFEST_KEY_TIMESTAMP_STOP} =
@@ -601,6 +603,9 @@ sub backupCompare
 
     foreach my $strFileKey ($oActualManifest->keys(MANIFEST_SECTION_TARGET_FILE))
     {
+        # Remove repo checksum
+        $oActualManifest->remove(&MANIFEST_SECTION_TARGET_FILE, $strFileKey, 'rck');
+
         # Determine repo size if compression or encryption is enabled
         my $strCompressType = $oExpectedManifest->{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_COMPRESS_TYPE};
 
@@ -1085,6 +1090,7 @@ sub configCreate
 
     # General options
     # ------------------------------------------------------------------------------------------------------------------------------
+    $oParamHash{&CFGDEF_SECTION_GLOBAL}{'beta'} = 'y';
     $oParamHash{&CFGDEF_SECTION_GLOBAL}{'job-retry'} = 0;
 
     $oParamHash{&CFGDEF_SECTION_GLOBAL}{'log-level-console'} = lc(DETAIL);
@@ -1103,6 +1109,11 @@ sub configCreate
         $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-bundle-limit'} = '64KiB';
     }
 
+    if ($oParam->{bBlockIncr})
+    {
+        $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-block'} = 'y';
+    }
+
     $oParamHash{&CFGDEF_SECTION_GLOBAL}{'log-path'} = $self->logPath();
     $oParamHash{&CFGDEF_SECTION_GLOBAL}{'lock-path'} = $self->lockPath();
 
@@ -1943,6 +1954,16 @@ sub restoreCompare
 
     foreach my $strName ($oActualManifest->keys(MANIFEST_SECTION_TARGET_FILE))
     {
+        # Remove repo checksum
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{'rck'});
+
+        # When bundling zero-length files will not have a reference
+        if ($oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-bundle'} &&
+            $oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{&MANIFEST_SUBKEY_SIZE} == 0)
+        {
+            $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE);
+        }
+
         # If synthetic match checksum errors since they can't be verified here
         if ($self->synthetic)
         {
@@ -1991,13 +2012,19 @@ sub restoreCompare
                 ${$oExpectedManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strName}{size});
         }
 
-        # Remove repo-size, bno, bni from the manifest
+        # Remove repo-size, bn*, bi* from the manifest
         $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE);
         delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{&MANIFEST_SUBKEY_REPO_SIZE});
         $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, "bni");
         delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{"bni"});
         $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, "bno");
         delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{"bno"});
+        $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, "bi");
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{"bi"});
+        $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, "bic");
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{"bic"});
+        $oActualManifest->remove(MANIFEST_SECTION_TARGET_FILE, $strName, "bim");
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_TARGET_FILE}{$strName}{"bim"});
 
         if ($oActualManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) != 0)
         {
@@ -2115,6 +2142,9 @@ sub restoreCompare
         $oActualManifest->set(
             MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LABEL, undef,
             $oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{&MANIFEST_KEY_LABEL});
+        $oActualManifest->set(
+            MANIFEST_SECTION_BACKUP, 'backup-reference', undef,
+            $oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-reference'});
         $oActualManifest->set(
             MANIFEST_SECTION_BACKUP, MANIFEST_KEY_TIMESTAMP_COPY_START, undef,
             $oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{&MANIFEST_KEY_TIMESTAMP_COPY_START});
@@ -2135,6 +2165,17 @@ sub restoreCompare
                 $oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-bundle'});
         }
 
+        if (defined($oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-bundle-raw'}))
+        {
+            $oActualManifest->set(
+                MANIFEST_SECTION_BACKUP, 'backup-bundle-raw', undef,
+                $oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-bundle-raw'});
+        }
+
+        # Delete block incr headers since old Perl manifest code will not generate them
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-block-incr'});
+        delete($oExpectedManifestRef->{&MANIFEST_SECTION_BACKUP}{'backup-block-incr-size'});
+
         $oActualManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LSN_START, undef,
                               ${$oExpectedManifestRef}{&MANIFEST_SECTION_BACKUP}{&MANIFEST_KEY_LSN_START});
         $oActualManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LSN_STOP, undef,
