@@ -57,7 +57,6 @@ sub new
             strImage => containerRepo() . ':' . testRunGet()->vm() . "-test",
             bTls => $oParam->{bTls},
             strBackupDestination => $$oParam{strBackupDestination},
-            oLogTest => $$oParam{oLogTest},
             bSynthetic => true,
             bStandby => $$oParam{bStandby},
             bRepoLocal => $oParam->{bRepoLocal},
@@ -99,8 +98,7 @@ sub dbFileCreate
     # Get tablespace path if this is a tablespace
     my $strPgPath;
 
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90 &&
-        index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
+    if (index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -185,9 +183,8 @@ sub manifestDbPathGet
     # Determine the manifest key
     my $strDbPath = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_PATH};
 
-    # If target is a tablespace and pg version >= 9.0
-    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}) &&
-        $$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
+    # If target is a tablespace
+    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}))
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -232,8 +229,6 @@ sub manifestFileCreate
         sprintf('%04o', S_IMODE($oStat->mode));
     ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_TIMESTAMP} = $oStat->mtime;
     ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_SIZE} = $oStat->size;
-    ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_PRIMARY} =
-        defined($bPrimary) ? ($bPrimary ? JSON::PP::true : JSON::PP::false) : JSON::PP::false;
     delete(${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_REFERENCE});
 
     my $bChecksumPage = defined($strChecksumPageError) ? false : (isChecksumPage($strManifestKey) ? true : undef);
@@ -299,9 +294,8 @@ sub manifestKeyGet
     # Determine the manifest key
     my $strManifestKey = $strTarget;
 
-    # If target is a tablespace and pg version >= 9.0
-    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}) &&
-        $$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
+    # If target is a tablespace
+    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}))
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -370,8 +364,6 @@ sub manifestLinkCreate
         ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_SIZE} = $oStat->size;
         ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_TIMESTAMP} = $oStat->mtime;
         (${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_CHECKSUM}) = storageTest()->hashSize($strDestinationFile);
-        ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_PRIMARY} =
-            defined($bPrimary) ? ($bPrimary ? JSON::PP::true : JSON::PP::false) : JSON::PP::false;
 
         ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strManifestKey}{&MANIFEST_SUBKEY_FILE} =
             basename(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strManifestKey}{&MANIFEST_SUBKEY_PATH});
@@ -566,15 +558,11 @@ sub manifestTablespaceCreate
     # Create the tablespace path if it does not exist
     my $strTablespacePath = $strLinkPath;
     my $strPathTarget = $strTarget;
+    my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
+    my $strTablespaceId = 'PG_' . ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} . "_${iCatalog}";
 
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
-    {
-        my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
-        my $strTablespaceId = 'PG_' . ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} . "_${iCatalog}";
-
-        $strTablespacePath .= "/${strTablespaceId}";
-        $strPathTarget .= "/${strTablespaceId}";
-    }
+    $strTablespacePath .= "/${strTablespaceId}";
+    $strPathTarget .= "/${strTablespaceId}";
 
     if (!-e $strTablespacePath)
     {
@@ -666,8 +654,7 @@ sub dbPathCreate
     my $strFinalPath = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_PATH};
 
     # Get tablespace path if this is a tablespace
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90 &&
-        index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
+    if (index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
