@@ -52,7 +52,6 @@ sub setup
 {
     my $self = shift;
     my $bSynthetic = shift;
-    my $oLogTest = shift;
     my $oConfigParam = shift;
 
     # Start object server first since it takes the longest
@@ -87,7 +86,7 @@ sub setup
         $strBackupDestination = defined($$oConfigParam{strBackupDestination}) ? $$oConfigParam{strBackupDestination} : HOST_BACKUP;
 
         $oHostBackup = new pgBackRestTest::Env::Host::HostBackupTest(
-            {strBackupDestination => $strBackupDestination, bSynthetic => $bSynthetic, oLogTest => $oLogTest,
+            {strBackupDestination => $strBackupDestination, bSynthetic => $bSynthetic,
                 bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
         $oHostGroup->hostAdd($oHostBackup);
     }
@@ -103,14 +102,14 @@ sub setup
     if ($bSynthetic)
     {
         $oHostDbPrimary = new pgBackRestTest::Env::Host::HostDbSyntheticTest(
-            {strBackupDestination => $strBackupDestination, oLogTest => $oLogTest,
+            {strBackupDestination => $strBackupDestination,
                 bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
     }
     else
     {
         $oHostDbPrimary = new pgBackRestTest::Env::Host::HostDbTest(
-            {strBackupDestination => $strBackupDestination, oLogTest => $oLogTest, bRepoLocal =>
-                $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
+            {strBackupDestination => $strBackupDestination, bRepoLocal => $oConfigParam->{strStorage} eq POSIX,
+                bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
     }
 
     $oHostGroup->hostAdd($oHostDbPrimary);
@@ -121,8 +120,8 @@ sub setup
     if (defined($$oConfigParam{bStandby}) && $$oConfigParam{bStandby})
     {
         $oHostDbStandby = new pgBackRestTest::Env::Host::HostDbTest(
-            {strBackupDestination => $strBackupDestination, bStandby => true, oLogTest => $oLogTest,
-                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bTls => $oConfigParam->{bTls}});
+            {strBackupDestination => $strBackupDestination, bStandby => true, bRepoLocal => $oConfigParam->{strStorage} eq POSIX,
+                bTls => $oConfigParam->{bTls}});
 
         $oHostGroup->hostAdd($oHostDbStandby);
     }
@@ -146,7 +145,9 @@ sub setup
         bHardlink => $bHostBackup ? undef : $$oConfigParam{bHardLink},
         bArchiveAsync => $$oConfigParam{bArchiveAsync},
         strStorage => $oConfigParam->{strStorage},
-        iRepoTotal => $oConfigParam->{iRepoTotal}});
+        iRepoTotal => $oConfigParam->{iRepoTotal},
+        bBundle => $oConfigParam->{bBundle},
+        bBlockIncr => $oConfigParam->{bBlockIncr}});
 
     # Create backup config if backup host exists
     if (defined($oHostBackup))
@@ -156,7 +157,9 @@ sub setup
             strCompressType => $$oConfigParam{strCompressType},
             bHardlink => $$oConfigParam{bHardLink},
             strStorage => $oConfigParam->{strStorage},
-            iRepoTotal => $oConfigParam->{iRepoTotal}});
+            iRepoTotal => $oConfigParam->{iRepoTotal},
+            bBundle => $oConfigParam->{bBundle},
+            bBlockIncr => $oConfigParam->{bBlockIncr}});
     }
     # If backup host is not defined set it to db-primary
     else
@@ -184,7 +187,9 @@ sub setup
             bHardlink => $bHostBackup ? undef : $$oConfigParam{bHardLink},
             bArchiveAsync => $$oConfigParam{bArchiveAsync},
             strStorage => $oConfigParam->{strStorage},
-            iRepoTotal => $oConfigParam->{iRepoTotal}});
+            iRepoTotal => $oConfigParam->{iRepoTotal},
+            bBundle => $oConfigParam->{bBundle},
+            bBlockIncr => $oConfigParam->{bBlockIncr}});
     }
 
     # Create object storage
@@ -239,11 +244,6 @@ sub dbCatalogVersion
 
     my $hCatalogVersion =
     {
-        &PG_VERSION_83 => 200711281,
-        &PG_VERSION_84 => 200904091,
-        &PG_VERSION_90 => 201008051,
-        &PG_VERSION_91 => 201105231,
-        &PG_VERSION_92 => 201204301,
         &PG_VERSION_93 => 201306121,
         &PG_VERSION_94 => 201409291,
         &PG_VERSION_95 => 201510051,
@@ -253,6 +253,7 @@ sub dbCatalogVersion
         &PG_VERSION_12 => 201909212,
         &PG_VERSION_13 => 202007201,
         &PG_VERSION_14 => 202105121,
+        &PG_VERSION_15 => 202209061,
     };
 
     if (!defined($hCatalogVersion->{$strPgVersion}))
@@ -284,11 +285,6 @@ sub dbControlVersion
 
     my $hControlVersion =
     {
-        &PG_VERSION_83 => 833,
-        &PG_VERSION_84 => 843,
-        &PG_VERSION_90 => 903,
-        &PG_VERSION_91 => 903,
-        &PG_VERSION_92 => 922,
         &PG_VERSION_93 => 937,
         &PG_VERSION_94 => 942,
         &PG_VERSION_95 => 942,
@@ -298,6 +294,7 @@ sub dbControlVersion
         &PG_VERSION_12 => 1201,
         &PG_VERSION_13 => 1300,
         &PG_VERSION_14 => 1300,
+        &PG_VERSION_15 => 1300,
     };
 
     if (!defined($hControlVersion->{$strPgVersion}))
@@ -336,11 +333,6 @@ sub controlGenerateContent
     {
         32 =>
         {
-            '8.3' =>  96 - length($tControlContent),
-            '8.4' => 104 - length($tControlContent),
-            '9.0' => 140 - length($tControlContent),
-            '9.1' => 140 - length($tControlContent),
-            '9.2' => 156 - length($tControlContent),
             '9.3' => 180 - length($tControlContent),
             '9.4' => 188 - length($tControlContent),
             '9.5' => 200 - length($tControlContent),
@@ -353,11 +345,6 @@ sub controlGenerateContent
 
         64 =>
         {
-            '8.3' => 112 - length($tControlContent),
-            '8.4' => 112 - length($tControlContent),
-            '9.0' => 152 - length($tControlContent),
-            '9.1' => 152 - length($tControlContent),
-            '9.2' => 168 - length($tControlContent),
             '9.3' => 192 - length($tControlContent),
             '9.4' => 200 - length($tControlContent),
             '9.5' => 216 - length($tControlContent),
@@ -446,11 +433,6 @@ sub walGenerateContent
     # Get WAL magic for the PG version
     my $hWalMagic =
     {
-        &PG_VERSION_83 => hex('0xD062'),
-        &PG_VERSION_84 => hex('0xD063'),
-        &PG_VERSION_90 => hex('0xD064'),
-        &PG_VERSION_91 => hex('0xD066'),
-        &PG_VERSION_92 => hex('0xD071'),
         &PG_VERSION_93 => hex('0xD075'),
         &PG_VERSION_94 => hex('0xD07E'),
         &PG_VERSION_95 => hex('0xD087'),
