@@ -41,12 +41,12 @@ sub run
 
     foreach my $rhRun
     (
-        {vm => VM2, remote => false, storage => AZURE, encrypt =>  true, compress => BZ2},
-        {vm => VM2, remote =>  true, storage => POSIX, encrypt => false, compress =>  GZ},
-        {vm => VM3, remote => false, storage =>   GCS, encrypt => false, compress => ZST},
-        {vm => VM3, remote =>  true, storage => AZURE, encrypt =>  true, compress => LZ4},
-        {vm => VM4, remote => false, storage =>    S3, encrypt => false, compress =>  GZ},
-        {vm => VM4, remote =>  true, storage =>   GCS, encrypt =>  true, compress => ZST},
+        {vm => VM2, remote => false, tls => false, storage => AZURE, encrypt =>  true, compress => BZ2},
+        {vm => VM2, remote =>  true, tls =>  true, storage => POSIX, encrypt => false, compress =>  GZ},
+        {vm => VM3, remote => false, tls => false, storage =>   GCS, encrypt => false, compress => ZST},
+        {vm => VM3, remote =>  true, tls =>  true, storage => AZURE, encrypt =>  true, compress => LZ4},
+        {vm => VM4, remote => false, tls => false, storage =>    S3, encrypt => false, compress =>  GZ},
+        {vm => VM4, remote =>  true, tls => false, storage =>   GCS, encrypt =>  true, compress => ZST},
     )
     {
         # Only run tests for this vm
@@ -54,17 +54,19 @@ sub run
 
         # Increment the run, log, and decide whether this unit test should be run
         my $bRemote = $rhRun->{remote};
+        my $bTls = $rhRun->{tls};
         my $strStorage = $rhRun->{storage};
         my $bEncrypt = $rhRun->{encrypt};
         my $strCompressType = $rhRun->{compress};
 
         # Increment the run, log, and decide whether this unit test should be run
-        if (!$self->begin("remote ${bRemote}, storage ${strStorage}, enc ${bEncrypt}, cmp ${strCompressType}")) {next}
+        if (!$self->begin("remote ${bRemote}, tls ${bTls}, storage ${strStorage}, enc ${bEncrypt}, cmp ${strCompressType}")) {next}
 
         # Create hosts, file object, and config
         my ($oHostDbPrimary, $oHostDbStandby, $oHostBackup) = $self->setup(
-            true, $self->expect(), {bHostBackup => $bRemote, strStorage => $strStorage, bRepoEncrypt => $bEncrypt,
-            strCompressType => $strCompressType});
+            true,
+            {bHostBackup => $bRemote, bTls => $bTls, strStorage => $strStorage, bRepoEncrypt => $bEncrypt,
+                strCompressType => $strCompressType});
 
         # Archive and backup info file names
         my $strArchiveInfoFile = $oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE);
@@ -127,7 +129,7 @@ sub run
 
         my $strCommand = $oHostDbPrimary->backrestExe() . ' --config=' . $oHostDbPrimary->backrestConfig() .
             ' --stanza=db archive-push';
-        $oHostDbPrimary->executeSimple($strCommand . " ${strSourceFile}", {oLogTest => $self->expect()});
+        $oHostDbPrimary->executeSimple($strCommand . " ${strSourceFile}");
 
         # With data existing in the archive dir, move the info files and confirm failure
         forceStorageMove(storageRepo(), $strArchiveInfoFile, $strArchiveInfoOldFile, {bRecurse => false});
@@ -147,7 +149,7 @@ sub run
         #--------------------------------------------------------------------------------------------------------------------------
         $strArchiveFile = $self->walSegment(1, 1, 2);
         $strSourceFile = $self->walGenerate($strWalPath, PG_VERSION_93, 1, $strArchiveFile);
-        $oHostDbPrimary->executeSimple($strCommand . " ${strSourceFile}", {oLogTest => $self->expect()});
+        $oHostDbPrimary->executeSimple($strCommand . " ${strSourceFile}");
 
         # Fail on archive push due to mismatch of DB since stanza not upgraded
         #--------------------------------------------------------------------------------------------------------------------------
@@ -163,7 +165,7 @@ sub run
 
         # Perform a successful stanza upgrade noting additional history lines in info files for new version of the database
         #--------------------------------------------------------------------------------------------------------------------------
-        #  Save a pre-upgrade copy of archive info for testing db-id mismatch
+        # Save a pre-upgrade copy of archive info for testing db-id mismatch
         forceStorageMove(storageRepo(), $strArchiveInfoCopyFile, $strArchiveInfoCopyOldFile, {bRecurse => false});
 
         $oHostBackup->stanzaUpgrade('successful upgrade creates additional history', {strOptionalParam => '--no-online'});
@@ -176,8 +178,7 @@ sub run
         # Attempt to get the last archive log that was pushed to this repo
         $oHostDbPrimary->executeSimple(
             $oHostDbPrimary->backrestExe() . ' --config=' . $oHostDbPrimary->backrestConfig() .
-                " --stanza=db archive-get ${strArchiveFile} " . $oHostDbPrimary->dbBasePath() . '/pg_xlog/RECOVERYXLOG',
-            {oLogTest => $self->expect()});
+                " --stanza=db archive-get ${strArchiveFile} " . $oHostDbPrimary->dbBasePath() . '/pg_xlog/RECOVERYXLOG');
 
         # Copy the new pg_control back so the tests can continue with the upgraded stanza
         $self->controlGenerate($oHostDbPrimary->dbBasePath(), PG_VERSION_94);
@@ -212,7 +213,7 @@ sub run
         forceStorageRemove(storageRepo(), $strArchiveInfoCopyFile, {bRecurse => false});
         forceStorageMove(storageRepo(), $strArchiveInfoCopyOldFile, $strArchiveInfoFile, {bRecurse => false});
 
-        #  Confirm versions
+        # Confirm versions
         my $oArchiveInfo = new pgBackRestTest::Env::ArchiveInfo($oHostBackup->repoArchivePath());
         my $oBackupInfo = new pgBackRestTest::Env::BackupInfo($oHostBackup->repoBackupPath());
         $self->testResult(sub {$oArchiveInfo->test(INFO_ARCHIVE_SECTION_DB, INFO_ARCHIVE_KEY_DB_VERSION, undef,
