@@ -7,13 +7,14 @@ Perform a test.
 #define TEST_COMMAND_TEST_TEST_H
 
 #include "common/logLevel.h"
-#include "common/type/string.h"
+#include "common/type/stringList.h"
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 void cmdTest(
     const String *pathRepo, const String *pathTest, const String *const vm, unsigned int vmId, const String *moduleName,
-    unsigned int test, uint64_t scale, LogLevel logLevel, bool logTime, const String *timeZone);
+    unsigned int test, uint64_t scale, LogLevel logLevel, bool logTime, const String *timeZone, bool coverage, bool profile,
+    bool optimize, bool backTrace);
 
 #endif
