@@ -73,14 +73,24 @@ harnessPqScriptStrictSet(bool strict)
 Run pq script
 ***********************************************************************************************************************************/
 static HarnessPq *
-harnessPqScriptRun(const char *function, const VariantList *param, HarnessPq *parent)
+harnessPqScriptRun(const char *const function, const VariantList *const param, const HarnessPq *const parent)
 {
     // If an error has already been thrown then throw the same error again
     if (harnessPqScriptFail)
         THROW(AssertError, harnessPqScriptError);
 
     // Convert params to json for comparison and reporting
-    String *paramStr = param ? jsonFromVar(varNewVarLst(param)) : strNew();
+    String *paramStr = NULL;
+
+    if (param)
+    {
+        Variant *const varList = varNewVarLst(param);
+
+        paramStr = jsonFromVar(varList);
+        varFree(varList);
+    }
+    else
+        paramStr = strNew();
 
     // Ensure script has not ended
     if (harnessPqScriptDone)
@@ -151,13 +161,16 @@ harnessPqScriptRun(const char *function, const VariantList *param, HarnessPq *pa
     if (harnessPqScript[harnessPqScriptIdx].function == NULL)
         harnessPqScriptDone = true;
 
+    strFree(paramStr);
+
     return result;
 }
 
 /***********************************************************************************************************************************
 Shim for PQconnectdb()
 ***********************************************************************************************************************************/
-PGconn *PQconnectdb(const char *conninfo)
+PGconn *
+PQconnectdb(const char *conninfo)
 {
     return (PGconn *)harnessPqScriptRun(HRNPQ_CONNECTDB, varLstAdd(varLstNew(), varNewStrZ(conninfo)), NULL);
 }
@@ -165,7 +178,8 @@ PGconn *PQconnectdb(const char *conninfo)
 /***********************************************************************************************************************************
 Shim for PQstatus()
 ***********************************************************************************************************************************/
-ConnStatusType PQstatus(const PGconn *conn)
+ConnStatusType
+PQstatus(const PGconn *conn)
 {
     return (ConnStatusType)harnessPqScriptRun(HRNPQ_STATUS, NULL, (HarnessPq *)conn)->resultInt;
 }
@@ -173,7 +187,8 @@ ConnStatusType PQstatus(const PGconn *conn)
 /***********************************************************************************************************************************
 Shim for PQerrorMessage()
 ***********************************************************************************************************************************/
-char *PQerrorMessage(const PGconn *conn)
+char *
+PQerrorMessage(const PGconn *conn)
 {
     return (char *)harnessPqScriptRun(HRNPQ_ERRORMESSAGE, NULL, (HarnessPq *)conn)->resultZ;
 }
@@ -347,7 +362,8 @@ PQclear(PGresult *res)
 /***********************************************************************************************************************************
 Shim for PQfinish()
 ***********************************************************************************************************************************/
-void PQfinish(PGconn *conn)
+void
+PQfinish(PGconn *conn)
 {
     if (harnessPqStrict && !harnessPqScriptFail)
         harnessPqScriptRun(HRNPQ_FINISH, NULL, (HarnessPq *)conn);
