@@ -11,7 +11,7 @@ Test Help Command
 #include "common/harnessStorage.h"
 
 /***********************************************************************************************************************************
-Configuration load with just enough funcionality to test help
+Configuration load with just enough functionality to test help
 ***********************************************************************************************************************************/
 static void
 testCfgLoad(const StringList *const argList)
@@ -45,13 +45,14 @@ testRun(void)
     const char *helpVersion = PROJECT_NAME " " PROJECT_VERSION;
 
     // General help text is used in more than one test
-    const char *generalHelp = strZ(strNewFmt(
+    const char *generalHelp = zNewFmt(
         "%s - General help\n"
         "\n"
         "Usage:\n"
         "    pgbackrest [options] [command]\n"
         "\n"
         "Commands:\n"
+        "    annotate        Add or modify backup annotation.\n"
         "    archive-get     Get a WAL segment from the archive.\n"
         "    archive-push    Push a WAL segment to the archive.\n"
         "    backup          Backup a database cluster.\n"
@@ -69,10 +70,11 @@ testRun(void)
         "    stanza-upgrade  Upgrade a stanza.\n"
         "    start           Allow pgBackRest processes to run.\n"
         "    stop            Stop pgBackRest processes from running.\n"
+        "    verify          Verify contents of the repository.\n"
         "    version         Get version.\n"
         "\n"
         "Use 'pgbackrest help [command]' for more information.\n",
-        helpVersion));
+        helpVersion);
 
     // *****************************************************************************************************************************
     if (testBegin("helpRenderSplitSize()"))
@@ -96,17 +98,24 @@ testRun(void)
     if (testBegin("helpRenderText()"))
     {
         TEST_RESULT_STR_Z(
-            helpRenderText(STRDEF("this is a short sentence"), false, 0, false, 80), "this is a short sentence", "one line");
+            helpRenderText(STRDEF("this is a short sentence"), false, false, 0, false, 80), "this is a short sentence", "one line");
 
         TEST_RESULT_STR_Z(
-            helpRenderText(STRDEF("this is a short sentence"), false, 4, false, 14),
+            helpRenderText(STRDEF("this is a short sentence"), false, false, 4, false, 14),
             "this is a\n"
             "    short\n"
             "    sentence",
             "three lines, no indent first");
 
         TEST_RESULT_STR_Z(
-            helpRenderText(STRDEF("This is a short paragraph.\n\nHere is another one."), true, 2, true, 16),
+            helpRenderText(STRDEF("this is a short sentence"), true, true, 4, true, 132),
+            "    this is a short sentence\n"
+            "\n"
+            "    FOR BETA TESTING ONLY. DO NOT USE IN PRODUCTION.",
+            "beta feature");
+
+        TEST_RESULT_STR_Z(
+            helpRenderText(STRDEF("This is a short paragraph.\n\nHere is another one."), true, false, 2, true, 16),
             "  This is a\n"
             "  short\n"
             "  paragraph.\n"
@@ -143,14 +152,14 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("version command");
 
-        const char *commandHelp = strZ(strNewFmt(
+        const char *commandHelp = zNewFmt(
             "%s%s",
             helpVersion,
             " - 'version' command help\n"
             "\n"
             "Get version.\n"
             "\n"
-            "Displays installed pgBackRest version.\n"));
+            "Displays installed pgBackRest version.\n");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -163,7 +172,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("restore command");
 
-        commandHelp = strZ(strNewFmt(
+        commandHelp = zNewFmt(
             "%s%s%s",
             helpVersion,
             " - 'restore' command help\n"
@@ -177,140 +186,150 @@ testRun(void)
             "specific repository, the --repo option can be passed (e.g. --repo=1). The --set\n"
             "option can be passed if a backup other than the latest is desired.\n"
             "\n"
-            "When PITR of --type=time is specified, then the target time must be specified\n"
-            "with the --target option. If a backup is not specified via the --set option,\n"
-            "then the configured repositories will be checked, in order, for a backup that\n"
-            "contains the requested time. If no backup can be found, the latest backup from\n"
-            "the first repository containing backups will be used. For other types of PITR,\n"
-            "e.g. xid, the --set option must be provided if the target is prior to the\n"
-            "latest backup. See Point-in-Time Recovery for more details and examples.\n"
+            "When PITR of --type=time or --type=lsn is specified, then the target time or\n"
+            "target lsn must be specified with the --target option. If a backup is not\n"
+            "specified via the --set option, then the configured repositories will be\n"
+            "checked, in order, for a backup that contains the requested time or lsn. If no\n"
+            "matching backup is found, the latest backup from the first repository\n"
+            "containing backups will be used for --type=time while no backup will be\n"
+            "selected for --type=lsn. For other types of PITR, e.g. xid, the --set option\n"
+            "must be provided if the target is prior to the latest backup. See Point-in-Time\n"
+            "Recovery for more details and examples.\n"
+            "\n"
+            "Replication slots are not included per recommendation of PostgreSQL. See\n"
+            "Backing Up The Data Directory in the PostgreSQL documentation for more\n"
+            "information.\n"
             "\n"
             "Command Options:\n"
             "\n"
-            "  --archive-mode                   preserve or disable archiving on restored\n"
-            "                                   cluster [default=preserve]\n"
-            "  --db-exclude                     restore excluding the specified databases\n"
-            "  --db-include                     restore only specified databases\n"
-            "                                   [current=db1, db2]\n"
-            "  --force                          force a restore [default=n]\n"
-            "  --link-all                       restore all symlinks [default=n]\n"
-            "  --link-map                       modify the destination of a symlink\n"
-            "                                   [current=/link1=/dest1, /link2=/dest2]\n"
-            "  --recovery-option                set an option in recovery.conf\n"
-            "  --set                            backup set to restore [default=latest]\n"
-            "  --tablespace-map                 restore a tablespace into the specified\n"
-            "                                   directory\n"
-            "  --tablespace-map-all             restore all tablespaces into the specified\n"
-            "                                   directory\n"
-            "  --target                         recovery target\n"
-            "  --target-action                  action to take when recovery target is\n"
-            "                                   reached [default=pause]\n"
-            "  --target-exclusive               stop just before the recovery target is\n"
-            "                                   reached [default=n]\n"
-            "  --target-timeline                recover along a timeline\n"
-            "  --type                           recovery type [default=default]\n"
+            "  --archive-mode                    preserve or disable archiving on restored\n"
+            "                                    cluster [default=preserve]\n"
+            "  --db-exclude                      restore excluding the specified databases\n"
+            "  --db-include                      restore only specified databases\n"
+            "                                    [current=db1, db2]\n"
+            "  --force                           force a restore [default=n]\n"
+            "  --link-all                        restore all symlinks [default=n]\n"
+            "  --link-map                        modify the destination of a symlink\n"
+            "                                    [current=/link1=/dest1, /link2=/dest2]\n"
+            "  --recovery-option                 set an option in recovery.conf\n"
+            "  --set                             backup set to restore [default=latest]\n"
+            "  --tablespace-map                  restore a tablespace into the specified\n"
+            "                                    directory\n"
+            "  --tablespace-map-all              restore all tablespaces into the specified\n"
+            "                                    directory\n"
+            "  --target                          recovery target\n"
+            "  --target-action                   action to take when recovery target is\n"
+            "                                    reached [default=pause]\n"
+            "  --target-exclusive                stop just before the recovery target is\n"
+            "                                    reached [default=n]\n"
+            "  --target-timeline                 recover along a timeline\n"
+            "  --type                            recovery type [default=default]\n"
             "\n"
             "General Options:\n"
             "\n"
-            "  --buffer-size                    buffer size for I/O operations\n"
-            "                                   [current=32768, default=1MiB]\n"
-            "  --cmd                            pgBackRest command\n"
-            "                                   [default=/path/to/pgbackrest]\n"
-            "  --cmd-ssh                        SSH client command [default=ssh]\n"
-            "  --compress-level-network         network compression level [default=3]\n"
-            "  --config                         pgBackRest configuration file\n"
-            "                                   [default=/etc/pgbackrest/pgbackrest.conf]\n"
-            "  --config-include-path            path to additional pgBackRest configuration\n"
-            "                                   files [default=/etc/pgbackrest/conf.d]\n"
-            "  --config-path                    base path of pgBackRest configuration files\n"
-            "                                   [default=/etc/pgbackrest]\n"
-            "  --delta                          restore or backup using checksums [default=n]\n"
-            "  --io-timeout                     I/O timeout [default=60]\n"
-            "  --lock-path                      path where lock files are stored\n"
-            "                                   [default=/tmp/pgbackrest]\n"
-            "  --neutral-umask                  use a neutral umask [default=y]\n"
-            "  --process-max                    max processes to use for compress/transfer\n"
-            "                                   [default=1]\n"
-            "  --protocol-timeout               protocol timeout [default=1830]\n"
-            "  --sck-keep-alive                 keep-alive enable [default=y]\n"
-            "  --stanza                         defines the stanza\n"
-            "  --tcp-keep-alive-count           keep-alive count\n"
-            "  --tcp-keep-alive-idle            keep-alive idle time\n"
-            "  --tcp-keep-alive-interval        keep-alive interval time\n"
+            "  --buffer-size                     buffer size for I/O operations\n"
+            "                                    [current=32768, default=1MiB]\n"
+            "  --cmd                             pgBackRest command\n"
+            "                                    [default=/path/to/pgbackrest]\n"
+            "  --cmd-ssh                         SSH client command [default=ssh]\n"
+            "  --compress-level-network          network compression level [default=3]\n"
+            "  --config                          pgBackRest configuration file\n"
+            "                                    [default=/etc/pgbackrest/pgbackrest.conf]\n"
+            "  --config-include-path             path to additional pgBackRest configuration\n"
+            "                                    files [default=/etc/pgbackrest/conf.d]\n"
+            "  --config-path                     base path of pgBackRest configuration files\n"
+            "                                    [default=/etc/pgbackrest]\n"
+            "  --delta                           restore or backup using checksums\n"
+            "                                    [default=n]\n"
+            "  --io-timeout                      I/O timeout [default=60]\n"
+            "  --lock-path                       path where lock files are stored\n"
+            "                                    [default=/tmp/pgbackrest]\n"
+            "  --neutral-umask                   use a neutral umask [default=y]\n"
+            "  --process-max                     max processes to use for compress/transfer\n"
+            "                                    [default=1]\n"
+            "  --protocol-timeout                protocol timeout [default=1830]\n"
+            "  --sck-keep-alive                  keep-alive enable [default=y]\n"
+            "  --stanza                          defines the stanza\n"
+            "  --tcp-keep-alive-count            keep-alive count\n"
+            "  --tcp-keep-alive-idle             keep-alive idle time\n"
+            "  --tcp-keep-alive-interval         keep-alive interval time\n"
             "\n"
             "Log Options:\n"
             "\n"
-            "  --log-level-console              level for console logging [default=warn]\n"
-            "  --log-level-file                 level for file logging [default=info]\n"
-            "  --log-level-stderr               level for stderr logging [default=warn]\n"
-            "  --log-path                       path where log files are stored\n"
-            "                                   [default=/var/log/pgbackrest]\n"
-            "  --log-subprocess                 enable logging in subprocesses [default=n]\n"
-            "  --log-timestamp                  enable timestamp in logging [default=y]\n"
+            "  --log-level-console               level for console logging [default=warn]\n"
+            "  --log-level-file                  level for file logging [default=info]\n"
+            "  --log-level-stderr                level for stderr logging [default=warn]\n"
+            "  --log-path                        path where log files are stored\n"
+            "                                    [default=/var/log/pgbackrest]\n"
+            "  --log-subprocess                  enable logging in subprocesses [default=n]\n"
+            "  --log-timestamp                   enable timestamp in logging [default=y]\n"
             "\n",
             "Repository Options:\n"
             "\n"
-            "  --repo                           set repository\n"
-            "  --repo-azure-account             azure repository account\n"
-            "  --repo-azure-container           azure repository container\n"
-            "  --repo-azure-endpoint            azure repository endpoint\n"
-            "                                   [default=blob.core.windows.net]\n"
-            "  --repo-azure-key                 azure repository key\n"
-            "  --repo-azure-key-type            azure repository key type [default=shared]\n"
-            "  --repo-azure-uri-style           azure URI Style [default=host]\n"
-            "  --repo-cipher-pass               repository cipher passphrase\n"
-            "                                   [current=<redacted>]\n"
-            "  --repo-cipher-type               cipher used to encrypt the repository\n"
-            "                                   [current=aes-256-cbc, default=none]\n"
-            "  --repo-gcs-bucket                GCS repository bucket\n"
-            "  --repo-gcs-endpoint              GCS repository endpoint\n"
-            "                                   [default=storage.googleapis.com]\n"
-            "  --repo-gcs-key                   GCS repository key\n"
-            "  --repo-gcs-key-type              GCS repository key type [default=service]\n"
-            "  --repo-host                      repository host when operating remotely via\n"
-            "                                   SSH [current=backup.example.net]\n"
-            "  --repo-host-ca-file              repository host certificate authority file\n"
-            "  --repo-host-ca-path              repository host certificate authority path\n"
-            "  --repo-host-cert-file            repository host certificate file\n"
-            "  --repo-host-cmd                  repository host pgBackRest command\n"
-            "                                   [default=/path/to/pgbackrest]\n"
-            "  --repo-host-config               pgBackRest repository host configuration\n"
-            "                                   file\n"
-            "                                   [default=/etc/pgbackrest/pgbackrest.conf]\n"
-            "  --repo-host-config-include-path  pgBackRest repository host configuration\n"
-            "                                   include path [default=/etc/pgbackrest/conf.d]\n"
-            "  --repo-host-config-path          pgBackRest repository host configuration\n"
-            "                                   path [default=/etc/pgbackrest]\n"
-            "  --repo-host-key-file             repository host key file\n"
-            "  --repo-host-port                 repository host port when repo-host is set\n"
-            "  --repo-host-type                 repository host protocol type [default=ssh]\n"
-            "  --repo-host-user                 repository host user when repo-host is set\n"
-            "                                   [default=pgbackrest]\n"
-            "  --repo-path                      path where backups and archive are stored\n"
-            "                                   [default=/var/lib/pgbackrest]\n"
-            "  --repo-s3-bucket                 S3 repository bucket\n"
-            "  --repo-s3-endpoint               S3 repository endpoint\n"
-            "  --repo-s3-key                    S3 repository access key\n"
-            "  --repo-s3-key-secret             S3 repository secret access key\n"
-            "  --repo-s3-key-type               S3 repository key type [default=shared]\n"
-            "  --repo-s3-region                 S3 repository region\n"
-            "  --repo-s3-role                   S3 repository role\n"
-            "  --repo-s3-token                  S3 repository security token\n"
-            "  --repo-s3-uri-style              S3 URI Style [default=host]\n"
-            "  --repo-storage-ca-file           repository storage CA file\n"
-            "  --repo-storage-ca-path           repository storage CA path\n"
-            "  --repo-storage-host              repository storage host\n"
-            "  --repo-storage-port              repository storage port [default=443]\n"
-            "  --repo-storage-verify-tls        repository storage certificate verify\n"
-            "                                   [default=y]\n"
-            "  --repo-type                      type of storage used for the repository\n"
-            "                                   [default=posix]\n"
+            "  --repo                            set repository\n"
+            "  --repo-azure-account              azure repository account\n"
+            "  --repo-azure-container            azure repository container\n"
+            "  --repo-azure-endpoint             azure repository endpoint\n"
+            "                                    [default=blob.core.windows.net]\n"
+            "  --repo-azure-key                  azure repository key\n"
+            "  --repo-azure-key-type             azure repository key type [default=shared]\n"
+            "  --repo-azure-uri-style            azure URI Style [default=host]\n"
+            "  --repo-cipher-pass                repository cipher passphrase\n"
+            "                                    [current=<redacted>]\n"
+            "  --repo-cipher-type                cipher used to encrypt the repository\n"
+            "                                    [current=aes-256-cbc, default=none]\n"
+            "  --repo-gcs-bucket                 GCS repository bucket\n"
+            "  --repo-gcs-endpoint               GCS repository endpoint\n"
+            "                                    [default=storage.googleapis.com]\n"
+            "  --repo-gcs-key                    GCS repository key\n"
+            "  --repo-gcs-key-type               GCS repository key type [default=service]\n"
+            "  --repo-host                       repository host when operating remotely\n"
+            "                                    [current=backup.example.net]\n"
+            "  --repo-host-ca-file               repository host certificate authority file\n"
+            "  --repo-host-ca-path               repository host certificate authority path\n"
+            "  --repo-host-cert-file             repository host certificate file\n"
+            "  --repo-host-cmd                   repository host pgBackRest command\n"
+            "                                    [default=/path/to/pgbackrest]\n"
+            "  --repo-host-config                pgBackRest repository host configuration\n"
+            "                                    file\n"
+            "                                    [default=/etc/pgbackrest/pgbackrest.conf]\n"
+            "  --repo-host-config-include-path   pgBackRest repository host configuration\n"
+            "                                    include path\n"
+            "                                    [default=/etc/pgbackrest/conf.d]\n"
+            "  --repo-host-config-path           pgBackRest repository host configuration\n"
+            "                                    path [default=/etc/pgbackrest]\n"
+            "  --repo-host-key-file              repository host key file\n"
+            "  --repo-host-port                  repository host port when repo-host is set\n"
+            "  --repo-host-type                  repository host protocol type [default=ssh]\n"
+            "  --repo-host-user                  repository host user when repo-host is set\n"
+            "                                    [default=pgbackrest]\n"
+            "  --repo-path                       path where backups and archive are stored\n"
+            "                                    [default=/var/lib/pgbackrest]\n"
+            "  --repo-s3-bucket                  S3 repository bucket\n"
+            "  --repo-s3-endpoint                S3 repository endpoint\n"
+            "  --repo-s3-key                     S3 repository access key\n"
+            "  --repo-s3-key-secret              S3 repository secret access key\n"
+            "  --repo-s3-key-type                S3 repository key type [default=shared]\n"
+            "  --repo-s3-kms-key-id              S3 repository KMS key\n"
+            "  --repo-s3-region                  S3 repository region\n"
+            "  --repo-s3-role                    S3 repository role\n"
+            "  --repo-s3-token                   S3 repository security token\n"
+            "  --repo-s3-uri-style               S3 URI Style [default=host]\n"
+            "  --repo-storage-ca-file            repository storage CA file\n"
+            "  --repo-storage-ca-path            repository storage CA path\n"
+            "  --repo-storage-host               repository storage host\n"
+            "  --repo-storage-port               repository storage port [default=443]\n"
+            "  --repo-storage-upload-chunk-size  repository storage upload chunk size\n"
+            "  --repo-storage-verify-tls         repository storage certificate verify\n"
+            "                                    [default=y]\n"
+            "  --repo-type                       type of storage used for the repository\n"
+            "                                    [default=posix]\n"
             "\n"
             "Stanza Options:\n"
             "\n"
-            "  --pg-path                        postgreSQL data directory\n"
+            "  --pg-path                         postgreSQL data directory\n"
             "\n"
-            "Use 'pgbackrest help restore [option]' for more information.\n"));
+            "Use 'pgbackrest help restore [option]' for more information.\n");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -359,7 +378,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("default and current option value");
 
-        const char *optionHelp = strZ(strNewFmt(
+        const char *optionHelp = zNewFmt(
             "%s - 'archive-push' command - 'buffer-size' option help\n"
             "\n"
             "Buffer size for I/O operations.\n"
@@ -368,14 +387,9 @@ testRun(void)
             "of buffers used depends on options and each operation may use additional\n"
             "memory, e.g. gz compression may use an additional 256KiB of memory.\n"
             "\n"
-            "Size can be entered in bytes (default) or KiB, MiB, GiB, TiB, or PiB where the\n"
-            "multiplier is a power of 1024. For example, the case-insensitive value 5GiB (or\n"
-            "5GB, 5g) can be used instead of 5368709120. Fractional values such as 2.5GiB\n"
-            "are not allowed, use 2560MiB instead.\n"
-            "\n"
             "Allowed values are 16KiB, 32KiB, 64KiB, 128KiB, 256KiB, 512KiB, 1MiB, 2MiB,\n"
             "4MiB, 8MiB, and 16MiB.\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -406,10 +420,10 @@ testRun(void)
         #define HELP_OPTION_DEPRECATED_NAMES                                                                                       \
             "deprecated names: repo-azure-host, repo-s3-host\n"
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             HELP_OPTION
             HELP_OPTION_DEPRECATED_NAMES,
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -419,12 +433,12 @@ testRun(void)
         TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, repo1-s3-host option");
         TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             HELP_OPTION
             "current: s3-host\n"
             "\n"
             HELP_OPTION_DEPRECATED_NAMES,
-            helpVersion));
+            helpVersion);
 
         // Set a current value for deprecated option name
         hrnCfgArgRawZ(argList, cfgOptRepoType, "s3");
@@ -435,7 +449,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("cipher pass redacted");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'archive-push' command - 'repo-cipher-pass' option help\n"
             "\n"
             "Repository cipher passphrase.\n"
@@ -443,7 +457,7 @@ testRun(void)
             "Passphrase used to encrypt/decrypt files of the repository.\n"
             "\n"
             "current: <redacted>\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -459,7 +473,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("deprecated and new option name produce same results");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'backup' command - 'repo-hardlink' option help\n"
             "\n"
             "Hardlink files between backups in the repository.\n"
@@ -472,7 +486,7 @@ testRun(void)
             "default: n\n"
             "\n"
             "deprecated name: hardlink\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -493,7 +507,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("check admonition");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'backup' command - 'repo-retention-archive' option help\n"
             "\n"
             "Number of backups worth of continuous WAL to retain.\n"
@@ -516,7 +530,7 @@ testRun(void)
             "expired WAL and is therefore not recommended.\n"
             "\n"
             "deprecated name: retention-archive\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
