@@ -12,9 +12,9 @@ ERROR_DECLARE(TestParent1Error);
 ERROR_DECLARE(TestParent2Error);
 ERROR_DECLARE(TestChildError);
 
-ERROR_DEFINE(101, TestParent1Error, TestParent1Error);
-ERROR_DEFINE(102, TestParent2Error, TestParent1Error);
-ERROR_DEFINE(200, TestChildError, TestParent2Error);
+ERROR_DEFINE(101, TestParent1Error, false, TestParent1Error);
+ERROR_DEFINE(102, TestParent2Error, false, TestParent1Error);
+ERROR_DEFINE(200, TestChildError, false, TestParent2Error);
 
 /***********************************************************************************************************************************
 testTryRecurse - test to blow up try stack
@@ -33,7 +33,7 @@ testTryRecurse(void)
 
         testTryRecurse();
     }
-    CATCH(MemoryError)
+    CATCH(UnhandledError)
     {
         testTryRecurseCatch = true;                                 // {uncoverable - catch should never be executed}
     }
@@ -48,10 +48,12 @@ testTryRecurse(void)
 Test error handler
 ***********************************************************************************************************************************/
 static unsigned int testErrorHandlerTryDepth;
+static bool testErrorHandlerFatal;
 
 static void
-testErrorHandler(unsigned int tryDepth)
+testErrorHandler(unsigned int tryDepth, bool fatal)
 {
+    testErrorHandlerFatal = fatal;
     testErrorHandlerTryDepth = tryDepth;
 }
 
@@ -134,7 +136,7 @@ testRun(void)
         TEST_TITLE("set error handler");
 
         static const ErrorHandlerFunction testErrorHandlerList[] = {testErrorHandler};
-        errorHandlerSet(testErrorHandlerList, sizeof(testErrorHandlerList) / sizeof(ErrorHandlerFunction));
+        errorHandlerSet(testErrorHandlerList, LENGTH_OF(testErrorHandlerList));
 
         assert(errorContext.handlerList[0] == testErrorHandler);
         assert(errorContext.handlerTotal == 1);
@@ -157,22 +159,39 @@ testRun(void)
                     TRY_BEGIN()
                     {
                         assert(errorTryDepth() == 4);
-                        tryDone = true;
 
-                        char bigMessage[sizeof(messageBuffer) + 128];
-                        memset(bigMessage, 'A', sizeof(bigMessage));
+                        TRY_BEGIN()
+                        {
+                            assert(errorTryDepth() == 5);
+                            tryDone = true;
+                        }
+                        FINALLY()
+                        {
+                            assert(errorContext.tryList[5].state == errorStateTry);
 
-                        THROW(AssertError, bigMessage);
+                            char bigMessage[sizeof(messageBuffer) + 128];
+                            memset(bigMessage, 'A', sizeof(bigMessage));
+
+                            THROW(AssertError, bigMessage);
+                        }
+                        TRY_END();
+                    }
+                    CATCH_ANY()
+                    {
+                        // Catch should not be executed since this error is fatal
+                        assert(false);
                     }
                     TRY_END();
                 }
-                CATCH(AssertError)
+                CATCH_FATAL()
                 {
                     assert(testErrorHandlerTryDepth == 3);
+                    assert(testErrorHandlerFatal);
 
-                    // Finally below should run even though this error has been rethrown
-                    RETHROW();
+                    // Change to FormatError so error can be caught by normal catches
+                    THROW(FormatError, errorMessage());
                 }
+                // Should run even though an error has been thrown in the catch
                 FINALLY()
                 {
                     finallyDone = true;
@@ -182,18 +201,20 @@ testRun(void)
             CATCH_ANY()
             {
                 assert(testErrorHandlerTryDepth == 2);
+                assert(!testErrorHandlerFatal);
 
                 RETHROW();
             }
             TRY_END();
         }
-        CATCH(MemoryError)
+        CATCH(UnhandledError)
         {
             assert(false);                                              // {uncoverable - catch should never be executed}
         }
         CATCH(RuntimeError)
         {
             assert(testErrorHandlerTryDepth == 1);
+            assert(!testErrorHandlerFatal);
             assert(errorTryDepth() == 1);
             assert(errorContext.tryList[1].state == errorStateEnd);
             assert(strlen(errorMessage()) == sizeof(messageBuffer) - 1);
@@ -223,17 +244,13 @@ testRun(void)
             tryDone = true;
             testTryRecurse();
         }
-        CATCH(AssertError)
+        CATCH_FATAL()
         {
             assert(errorCode() == AssertError.code);
             assert(strcmp(errorFileName(), TEST_PGB_PATH "/test/src/module/common/errorTest.c") == 0);
             assert(strcmp(errorFunctionName(), "testTryRecurse") == 0);
             assert(errorFileLine() == 29);
-            assert(
-                strcmp(
-                    errorStackTrace(),
-                    TEST_PGB_PATH "/test/src/module/common/errorTest.c:testTryRecurse:29:(test build required for parameters)")
-                == 0);
+            assert(errorStackTrace() != NULL);
             assert(strcmp(errorMessage(), "too many nested try blocks") == 0);
             assert(strcmp(errorName(), AssertError.name) == 0);
             assert(errorType() == &AssertError);
@@ -268,7 +285,7 @@ testRun(void)
         {
             THROW_CODE(25, "message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             assert(errorCode() == 25);
             assert(strcmp(errorMessage(), "message") == 0);
@@ -311,7 +328,7 @@ testRun(void)
             errno = E2BIG;
             THROW_ON_SYS_ERROR(true, AssertError, "message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -325,7 +342,7 @@ testRun(void)
             errno = 0;
             THROW_ON_SYS_ERROR_FMT(true, AssertError, "message %d", 77);
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -339,7 +356,7 @@ testRun(void)
             errno = E2BIG;
             THROW_ON_SYS_ERROR_FMT(true, AssertError, "message %d", 77);
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -353,7 +370,7 @@ testRun(void)
             errno = 0;
             THROW_SYS_ERROR(AssertError, "message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -367,7 +384,7 @@ testRun(void)
             errno = EIO;
             THROW_SYS_ERROR_FMT(AssertError, "message %d", 1);
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -381,7 +398,7 @@ testRun(void)
             errno = 0;
             THROW_SYS_ERROR_FMT(AssertError, "message %d", 1);
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             printf("%s\n", errorMessage());
             assert(errorCode() == AssertError.code);
@@ -398,6 +415,9 @@ testRun(void)
         {
             HRN_FORK_CHILD_BEGIN(.expectedExitStatus = UnhandledError.code)
             {
+                // Redirect stderr to stdout (we do not care about the output here since coverage will tell us we hit the code)
+                stderr = stdout;
+
                 THROW(TestChildError, "does not get caught!");
             }
             HRN_FORK_CHILD_END();
