@@ -11,15 +11,15 @@ stress testing as needed.
 #include "common/harnessFork.h"
 #include "common/harnessStorage.h"
 
-#include "common/crypto/hash.h"
 #include "common/compress/gz/compress.h"
 #include "common/compress/lz4/compress.h"
-#include "common/io/filter/filter.h"
-#include "common/io/filter/sink.h"
+#include "common/crypto/hash.h"
 #include "common/io/bufferRead.h"
 #include "common/io/bufferWrite.h"
 #include "common/io/fdRead.h"
 #include "common/io/fdWrite.h"
+#include "common/io/filter/filter.h"
+#include "common/io/filter/sink.h"
 #include "common/io/io.h"
 #include "common/type/object.h"
 #include "protocol/client.h"
@@ -28,53 +28,34 @@ stress testing as needed.
 #include "storage/remote/protocol.h"
 
 /***********************************************************************************************************************************
-Dummy callback functions
-***********************************************************************************************************************************/
-static void
-storageTestDummyInfoListCallback(void *data, const StorageInfo *info)
-{
-    (void)info;
-
-    // Do some work in the mem context to blow up the total time if this is not efficient, i.e. if the current mem context is not
-    // being freed regularly
-    memResize(memNew(16), 32);
-
-    // Increment callback total
-    (*(uint64_t *)data)++;
-}
-
-/***********************************************************************************************************************************
-Driver to test storageInfoList
+Driver to test storageNewItrP()
 ***********************************************************************************************************************************/
 typedef struct
 {
     STORAGE_COMMON_MEMBER;
     uint64_t fileTotal;
-} StorageTestPerfInfoList;
+} StorageTestPerfList;
 
-static bool
-storageTestPerfInfoList(
-    THIS_VOID, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
-    StorageInterfaceInfoListParam param)
+static StorageList *
+storageTestPerfList(THIS_VOID, const String *path, StorageInfoLevel level, StorageInterfaceListParam param)
 {
-    THIS(StorageTestPerfInfoList);
-    (void)path; (void)level; (void)param;
+    THIS(StorageTestPerfList);
 
-    MEM_CONTEXT_TEMP_BEGIN()
+    (void)path;
+    (void)level;
+    (void)param;
+
+    StorageList *result = NULL;
+
+    if (this->fileTotal != 0)
     {
-        MEM_CONTEXT_TEMP_RESET_BEGIN()
-        {
-            for (uint64_t fileIdx = 0; fileIdx < this->fileTotal; fileIdx++)
-            {
-                callback(callbackData, &(StorageInfo){.exists = true, .name = STRDEF("name")});
-                MEM_CONTEXT_TEMP_RESET(1000);
-            }
-        }
-        MEM_CONTEXT_TEMP_END();
-    }
-    MEM_CONTEXT_TEMP_END();
+        result = storageLstNew(storageInfoLevelExists);
 
-    return this->fileTotal != 0;
+        for (uint64_t fileIdx = 0; fileIdx < this->fileTotal; fileIdx++)
+            storageLstAdd(result, &(StorageInfo){.exists = true, .name = STRDEF("name")});
+    }
+
+    return result;
 }
 
 /***********************************************************************************************************************************
@@ -118,7 +99,7 @@ testIoRateNew(uint64_t bytesPerSec)
 {
     IoFilter *this = NULL;
 
-    OBJ_NEW_BEGIN(TestIoRate)
+    OBJ_NEW_BEGIN(TestIoRate, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
         TestIoRate *driver = OBJ_NEW_ALLOC();
 
@@ -144,7 +125,7 @@ testRun(void)
     FUNCTION_HARNESS_VOID();
 
     // *****************************************************************************************************************************
-    if (testBegin("storageInfoList()"))
+    if (testBegin("storageNewItrP()"))
     {
         TEST_TITLE_FMT("list %d million files", TEST_SCALE);
 
@@ -163,16 +144,24 @@ testRun(void)
                 hrnCfgArgRawStrId(argList, cfgOptRemoteType, protocolStorageTypeRepo);
                 HRN_CFG_LOAD(cfgCmdArchivePush, argList, .role = cfgCmdRoleRemote);
 
-                // Create a driver to test remote performance of storageInfoList() and inject it into storageRepo()
-                StorageTestPerfInfoList driver =
+                // Create a driver to test remote performance of storageNewItrP() and inject it into storageRepo()
+                StorageTestPerfList *driver = NULL;
+
+                OBJ_NEW_BEGIN(StorageTestPerfList, .childQty = MEM_CONTEXT_QTY_MAX)
                 {
-                    .interface = storageInterfaceTestDummy,
-                    .fileTotal = fileTotal,
-                };
+                    driver = OBJ_NEW_ALLOC();
 
-                driver.interface.infoList = storageTestPerfInfoList;
+                    *driver = (StorageTestPerfList)
+                    {
+                        .interface = storageInterfaceTestDummy,
+                        .fileTotal = fileTotal,
+                    };
+                }
+                OBJ_NEW_END();
 
-                Storage *storageTest = storageNew(strIdFromZ("test"), STRDEF("/"), 0, 0, false, NULL, &driver, driver.interface);
+                driver->interface.list = storageTestPerfList;
+
+                Storage *storageTest = storageNew(strIdFromZ("test"), STRDEF("/"), 0, 0, false, NULL, driver, driver->interface);
                 storageHelper.storageRepoWrite = memNew(sizeof(Storage *));
                 storageHelper.storageRepoWrite[0] = storageTest;
 
@@ -183,7 +172,7 @@ testRun(void)
                     STRDEF("storage test server"), STRDEF("test"), HRN_FORK_CHILD_READ(), HRN_FORK_CHILD_WRITE());
 
                 static const ProtocolServerHandler commandHandler[] = {PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST};
-                protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler));
+                protocolServerProcess(server, NULL, commandHandler, LENGTH_OF(commandHandler));
             }
             HRN_FORK_CHILD_END();
 
@@ -200,13 +189,18 @@ testRun(void)
                 TimeMSec timeBegin = timeMSec();
 
                 // Storage info list
-                uint64_t fileCallbackTotal = 0;
+                uint64_t fileTotal = 0;
+                StorageIterator *storageItr = NULL;
 
-                TEST_RESULT_VOID(
-                    storageInfoListP(storageRemote, NULL, storageTestDummyInfoListCallback, &fileCallbackTotal),
-                    "list remote files");
+                TEST_ASSIGN(storageItr, storageNewItrP(storageRemote, NULL), "list remote files");
 
-                TEST_RESULT_UINT(fileCallbackTotal, fileTotal, "check callback total");
+                while (storageItrMore(storageItr))
+                {
+                    storageItrNext(storageItr);
+                    fileTotal++;
+                }
+
+                TEST_RESULT_UINT(fileTotal, fileTotal, "check callback total");
 
                 TEST_LOG_FMT("list transferred in %ums", (unsigned int)(timeMSec() - timeBegin));
 
@@ -271,15 +265,7 @@ testRun(void)
                                                                                                                                    \
             uint64_t benchMarkBegin = timeMSec();                                                                                  \
                                                                                                                                    \
-            Buffer *buffer = bufNew(ioBufferSize());                                                                               \
-                                                                                                                                   \
-            do                                                                                                                     \
-            {                                                                                                                      \
-                ioRead(read, buffer);                                                                                              \
-                ioWrite(write, buffer);                                                                                            \
-                bufUsedZero(buffer);                                                                                               \
-            }                                                                                                                      \
-            while (!ioReadEof(read));                                                                                              \
+            ioCopyP(read, write);                                                                                                  \
                                                                                                                                    \
             ioReadClose(read);                                                                                                     \
             ioWriteClose(write);                                                                                                   \
@@ -315,7 +301,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 BENCHMARK_BEGIN();
-                BENCHMARK_FILTER_ADD(cryptoHashNew(HASH_TYPE_MD5_STR));
+                BENCHMARK_FILTER_ADD(cryptoHashNew(hashTypeMd5));
                 BENCHMARK_END(md5Total);
             }
             MEM_CONTEXT_TEMP_END();
@@ -326,7 +312,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 BENCHMARK_BEGIN();
-                BENCHMARK_FILTER_ADD(cryptoHashNew(HASH_TYPE_SHA1_STR));
+                BENCHMARK_FILTER_ADD(cryptoHashNew(hashTypeSha1));
                 BENCHMARK_END(sha1Total);
             }
             MEM_CONTEXT_TEMP_END();
@@ -337,7 +323,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 BENCHMARK_BEGIN();
-                BENCHMARK_FILTER_ADD(cryptoHashNew(HASH_TYPE_SHA256_STR));
+                BENCHMARK_FILTER_ADD(cryptoHashNew(hashTypeSha256));
                 BENCHMARK_END(sha256Total);
             }
             MEM_CONTEXT_TEMP_END();
@@ -348,7 +334,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 BENCHMARK_BEGIN();
-                BENCHMARK_FILTER_ADD(gzCompressNew(6));
+                BENCHMARK_FILTER_ADD(gzCompressNew(6, false));
                 BENCHMARK_END(gzip6Total);
             }
             MEM_CONTEXT_TEMP_END();
@@ -360,7 +346,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 BENCHMARK_BEGIN();
-                BENCHMARK_FILTER_ADD(lz4CompressNew(1));
+                BENCHMARK_FILTER_ADD(lz4CompressNew(1, false));
                 BENCHMARK_END(lz41Total);
             }
             MEM_CONTEXT_TEMP_END();
