@@ -57,7 +57,9 @@ STRING_STATIC(TEST_MANIFEST_PATH_USER_STR,                          "test");
 static StorageInfo
 storageTestManifestNewBuildInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param)
 {
-    (void)thisVoid; (void)level; (void)param;
+    (void)thisVoid;
+    (void)level;
+    (void)param;
 
     StorageInfo result =
     {
@@ -85,7 +87,10 @@ static StorageList *
 storageTestManifestNewBuildList(THIS_VOID, const String *path, StorageInfoLevel level, StorageInterfaceListParam param)
 {
     THIS(StorageTestManifestNewBuild);
-    (void)path; (void)level; (void)param;
+
+    (void)path;
+    (void)level;
+    (void)param;
 
     StorageList *const result = storageLstNew(storageInfoLevelDetail);
 
@@ -244,17 +249,25 @@ testRun(void)
         ASSERT(TEST_SCALE <= 1000000);
 
         // Create a storage driver to test manifest build with an arbitrary number of files
-        StorageTestManifestNewBuild driver =
-        {
-            .interface = storageInterfaceTestDummy,
-            .fileTotal = 100000 * (unsigned int)TEST_SCALE,
-        };
+        StorageTestManifestNewBuild *driver = NULL;
 
-        driver.interface.info = storageTestManifestNewBuildInfo;
-        driver.interface.list = storageTestManifestNewBuildList;
+        OBJ_NEW_BEGIN(StorageTestManifestNewBuild, .childQty = MEM_CONTEXT_QTY_MAX)
+        {
+            driver = OBJ_NEW_ALLOC();
+
+            *driver = (StorageTestManifestNewBuild)
+            {
+                .interface = storageInterfaceTestDummy,
+                .fileTotal = 100000 * (unsigned int)TEST_SCALE,
+            };
+        }
+        OBJ_NEW_END();
+
+        driver->interface.info = storageTestManifestNewBuildInfo;
+        driver->interface.list = storageTestManifestNewBuildList;
 
         const Storage *const storagePg = storageNew(
-            strIdFromZ("test"), STRDEF("/pg"), 0, 0, false, NULL, &driver, driver.interface);
+            strIdFromZ("test"), STRDEF("/pg"), 0, 0, false, NULL, driver, driver->interface);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("build manifest");
@@ -267,7 +280,7 @@ testRun(void)
         MEM_CONTEXT_BEGIN(testContext)
         {
             TEST_ASSIGN(
-                manifest, manifestNewBuild(storagePg, PG_VERSION_15, 999999999, false, false, false, false, 0, NULL, NULL),
+                manifest, manifestNewBuild(storagePg, PG_VERSION_15, 999999999, 0, false, false, false, false, NULL, NULL, NULL),
                 "build files");
         }
         MEM_CONTEXT_END();
@@ -275,7 +288,7 @@ testRun(void)
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
         // TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
 
-        TEST_RESULT_UINT(manifestFileTotal(manifest), driver.fileTotal, "   check file total");
+        TEST_RESULT_UINT(manifestFileTotal(manifest), driver->fileTotal, "   check file total");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("save manifest");
@@ -305,7 +318,7 @@ testRun(void)
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
         // TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
 
-        TEST_RESULT_UINT(manifestFileTotal(manifest), driver.fileTotal, "   check file total");
+        TEST_RESULT_UINT(manifestFileTotal(manifest), driver->fileTotal, "   check file total");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("find all files");
