@@ -25,7 +25,7 @@ testRun(void)
         TEST_RESULT_INT(pgVersionFromStr(STRDEF("10")), PG_VERSION_10, "valid pg version 10");
         TEST_RESULT_INT(pgVersionFromStr(STRDEF("9.6")), 90600, "valid pg version 9.6");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_STR_Z(pgVersionToStr(PG_VERSION_11), "11", "infoPgVersionToString 11");
         TEST_RESULT_STR_Z(pgVersionToStr(PG_VERSION_96), "9.6", "infoPgVersionToString 9.6");
         TEST_RESULT_STR_Z(pgVersionToStr(93456), "9.34", "infoPgVersionToString 93456");
@@ -49,7 +49,10 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("pgControlVersion()"))
     {
-        TEST_ERROR(pgControlVersion(70300), AssertError, "invalid PostgreSQL version 70300");
+        TEST_ERROR(
+            pgControlVersion(70300), VersionNotSupportedError,
+            "invalid PostgreSQL version 70300\n"
+            "HINT: is this version of PostgreSQL supported?");
         TEST_RESULT_UINT(pgControlVersion(PG_VERSION_93), 937, "9.3 control version");
         TEST_RESULT_UINT(pgControlVersion(PG_VERSION_11), 1100, "11 control version");
     }
@@ -58,60 +61,78 @@ testRun(void)
     if (testBegin("pgControlFromBuffer() and pgControlFromFile()"))
     {
         // Sanity test to ensure PG_VERSION_MAX has been updated
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_UINT(pgInterface[0].version, PG_VERSION_MAX, "check max version");
 
-        //--------------------------------------------------------------------------------------------------------------------------
-        // Create a bogus control file
-        Buffer *result = bufNew(HRN_PG_CONTROL_SIZE);
-        memset(bufPtr(result), 0, bufSize(result));
-        bufUsedSet(result, bufSize(result));
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("unknown control version");
 
-        *(PgControlCommon *)bufPtr(result) = (PgControlCommon)
-        {
-            .controlVersion = 501,
-            .catalogVersion = 19780101,
-        };
+        HRN_PG_CONTROL_OVERRIDE_PUT(storageTest, PG_VERSION_15, 1501, .catalogVersion = 202211111);
 
         TEST_ERROR(
-            pgControlFromBuffer(result), VersionNotSupportedError,
-            "unexpected control version = 501 and catalog version = 19780101\nHINT: is this version of PostgreSQL supported?");
+            pgControlFromFile(storageTest, NULL), VersionNotSupportedError,
+            "unexpected control version = 1501 and catalog version = 202211111\n"
+            "HINT: is this version of PostgreSQL supported?");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         HRN_PG_CONTROL_PUT(
             storageTest, PG_VERSION_11, .systemId = 0xFACEFACE, .checkpoint = 0xEEFFEEFFAABBAABB, .timeline = 47,
             .walSegmentSize = 1024 * 1024);
 
         PgControl info = {0};
-        TEST_ASSIGN(info, pgControlFromFile(storageTest), "get control info v11");
+        TEST_ASSIGN(info, pgControlFromFile(storageTest, NULL), "get control info v11");
         TEST_RESULT_UINT(info.systemId, 0xFACEFACE, "   check system id");
         TEST_RESULT_UINT(info.version, PG_VERSION_11, "   check version");
         TEST_RESULT_UINT(info.catalogVersion, 201809051, "   check catalog version");
         TEST_RESULT_UINT(info.checkpoint, 0xEEFFEEFFAABBAABB, "check checkpoint");
         TEST_RESULT_UINT(info.timeline, 47, "check timeline");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         HRN_PG_CONTROL_PUT(storageTest, PG_VERSION_93, .walSegmentSize = 1024 * 1024);
 
         TEST_ERROR(
-            pgControlFromFile(storageTest), FormatError, "wal segment size is 1048576 but must be 16777216 for PostgreSQL <= 10");
+            pgControlFromFile(storageTest, NULL), FormatError,
+            "wal segment size is 1048576 but must be 16777216 for PostgreSQL <= 10");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         HRN_PG_CONTROL_PUT(storageTest, PG_VERSION_95, .pageSize = 32 * 1024);
 
-        TEST_ERROR(pgControlFromFile(storageTest), FormatError, "page size is 32768 but must be 8192");
+        TEST_ERROR(pgControlFromFile(storageTest, NULL), FormatError, "page size is 32768 but must be 8192");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         HRN_PG_CONTROL_PUT(
             storageTest, PG_VERSION_93, .systemId = 0xEFEFEFEFEF, .catalogVersion = hrnPgCatalogVersion(PG_VERSION_93),
             .checkpoint = 0xAABBAABBEEFFEEFF, .timeline = 88);
 
-        TEST_ASSIGN(info, pgControlFromFile(storageTest), "get control info v90");
+        TEST_ASSIGN(info, pgControlFromFile(storageTest, NULL), "get control info v90");
         TEST_RESULT_UINT(info.systemId, 0xEFEFEFEFEF, "   check system id");
         TEST_RESULT_UINT(info.version, PG_VERSION_93, "   check version");
         TEST_RESULT_UINT(info.catalogVersion, 201306121, "   check catalog version");
         TEST_RESULT_UINT(info.checkpoint, 0xAABBAABBEEFFEEFF, "check checkpoint");
         TEST_RESULT_UINT(info.timeline, 88, "check timeline");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("force control version");
+
+        HRN_PG_CONTROL_OVERRIDE_PUT(
+            storageTest, PG_VERSION_15, 1501, .systemId = 0xEFEFEFEFEF, .catalogVersion = 202211111,
+            .checkpoint = 0xAABBAABBEEFFEEFF, .timeline = 88);
+
+        TEST_ERROR(
+            pgControlFromFile(storageTest, NULL), VersionNotSupportedError,
+            "unexpected control version = 1501 and catalog version = 202211111\n"
+            "HINT: is this version of PostgreSQL supported?");
+        TEST_ERROR(
+            pgControlFromFile(storageTest, STRDEF("99")), VersionNotSupportedError,
+            "invalid PostgreSQL version 990000\n"
+            "HINT: is this version of PostgreSQL supported?");
+
+        TEST_ASSIGN(info, pgControlFromFile(storageTest, STRDEF(PG_VERSION_15_STR)), "get control info v90");
+        TEST_RESULT_UINT(info.systemId, 0xEFEFEFEFEF, "check system id");
+        TEST_RESULT_UINT(info.version, PG_VERSION_15, "check version");
+        TEST_RESULT_UINT(info.catalogVersion, 202211111, "check catalog version");
+        TEST_RESULT_UINT(info.checkpoint, 0xAABBAABBEEFFEEFF, "check checkpoint");
+        TEST_RESULT_UINT(info.timeline, 88, "check timeline");
     }
 
     // *****************************************************************************************************************************
@@ -141,7 +162,7 @@ testRun(void)
             pgLsnRangeToWalSegmentList(
                 2, pgLsnFromStr(STRDEF("A/800")), pgLsnFromStr(STRDEF("B/C0000000")), 1024 * 1024 * 1024),
             "000000020000000A00000000\n000000020000000A00000001\n000000020000000A00000002\n000000020000000A00000003\n"
-                "000000020000000B00000000\n000000020000000B00000001\n000000020000000B00000002\n000000020000000B00000003\n",
+            "000000020000000B00000000\n000000020000000B00000001\n000000020000000B00000002\n000000020000000B00000003\n",
             "get range >= 11/1GB");
         TEST_RESULT_STRLST_Z(
             pgLsnRangeToWalSegmentList(
@@ -184,53 +205,70 @@ testRun(void)
     {
         const String *walFile = STRDEF(TEST_PATH "/0000000F0000000F0000000F");
 
-        // Create a bogus control file, initially not in long format)
-        // --------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("unknown WAL magic");
+
         Buffer *result = bufNew((size_t)16 * 1024 * 1024);
         memset(bufPtr(result), 0, bufSize(result));
         bufUsedSet(result, bufSize(result));
-
-        *(PgWalCommon *)bufPtr(result) = (PgWalCommon){.magic = 777};
-
-        TEST_ERROR(pgWalFromBuffer(result), FormatError, "first page header in WAL file is expected to be in long format");
-
-        // Add the long flag so that the version will now error
-        // --------------------------------------------------------------------------------------------------------------------------
-        ((PgWalCommon *)bufPtr(result))->flag = PG_WAL_LONG_HEADER;
+        HRN_PG_WAL_OVERRIDE_TO_BUFFER(result, PG_VERSION_15, 777);
 
         TEST_ERROR(
-            pgWalFromBuffer(result), VersionNotSupportedError,
+            pgWalFromBuffer(result, NULL), VersionNotSupportedError,
             "unexpected WAL magic 777\n"
-                "HINT: is this version of PostgreSQL supported?");
+            "HINT: is this version of PostgreSQL supported?");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("invalid wal flag");
+
+        ((PgWalCommon *)bufPtr(result))->flag = 0;
+
+        TEST_ERROR(pgWalFromBuffer(result, NULL), FormatError, "first page header in WAL file is expected to be in long format");
+
+        // -------------------------------------------------------------------------------------------------------------------------
         memset(bufPtr(result), 0, bufSize(result));
-        hrnPgWalToBuffer(
-            (PgWal){.version = PG_VERSION_11, .systemId = 0xECAFECAF, .size = PG_WAL_SEGMENT_SIZE_DEFAULT * 2}, result);
+        HRN_PG_WAL_TO_BUFFER(result, PG_VERSION_11, .systemId = 0xECAFECAF, .size = PG_WAL_SEGMENT_SIZE_DEFAULT * 2);
         storagePutP(storageNewWriteP(storageTest, walFile), result);
 
         PgWal info = {0};
-        TEST_ASSIGN(info, pgWalFromFile(walFile, storageTest), "get wal info v11");
+        TEST_ASSIGN(info, pgWalFromFile(walFile, storageTest, NULL), "get wal info v11");
         TEST_RESULT_UINT(info.systemId, 0xECAFECAF, "   check system id");
         TEST_RESULT_UINT(info.version, PG_VERSION_11, "   check version");
         TEST_RESULT_UINT(info.size, PG_WAL_SEGMENT_SIZE_DEFAULT * 2, "   check size");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         memset(bufPtr(result), 0, bufSize(result));
-        hrnPgWalToBuffer(
-            (PgWal){.version = PG_VERSION_96, .systemId = 0xEAEAEAEA, .size = PG_WAL_SEGMENT_SIZE_DEFAULT * 2}, result);
+        HRN_PG_WAL_TO_BUFFER(result, PG_VERSION_96, .systemId = 0xEAEAEAEA, .size = PG_WAL_SEGMENT_SIZE_DEFAULT * 2);
 
-        TEST_ERROR(pgWalFromBuffer(result), FormatError, "wal segment size is 33554432 but must be 16777216 for PostgreSQL <= 10");
+        TEST_ERROR(
+            pgWalFromBuffer(result, NULL), FormatError, "wal segment size is 33554432 but must be 16777216 for PostgreSQL <= 10");
 
-        //--------------------------------------------------------------------------------------------------------------------------
+        // -------------------------------------------------------------------------------------------------------------------------
         memset(bufPtr(result), 0, bufSize(result));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_93, .systemId = 0xEAEAEAEA, .size = PG_WAL_SEGMENT_SIZE_DEFAULT}, result);
+        HRN_PG_WAL_TO_BUFFER(result, PG_VERSION_93, .systemId = 0xEAEAEAEA, .size = PG_WAL_SEGMENT_SIZE_DEFAULT);
         storagePutP(storageNewWriteP(storageTest, walFile), result);
 
-        TEST_ASSIGN(info, pgWalFromFile(walFile, storageTest), "get wal info v9.3");
+        TEST_ASSIGN(info, pgWalFromFile(walFile, storageTest, NULL), "get wal info v9.3");
         TEST_RESULT_UINT(info.systemId, 0xEAEAEAEA, "   check system id");
         TEST_RESULT_UINT(info.version, PG_VERSION_93, "   check version");
         TEST_RESULT_UINT(info.size, PG_WAL_SEGMENT_SIZE_DEFAULT, "   check size");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("force WAL version");
+
+        memset(bufPtr(result), 0, bufSize(result));
+        HRN_PG_WAL_OVERRIDE_TO_BUFFER(result, PG_VERSION_15, 777, .systemId = 0xFAFAFAFA, .size = PG_WAL_SEGMENT_SIZE_DEFAULT);
+        storagePutP(storageNewWriteP(storageTest, walFile), result);
+
+        TEST_ERROR(
+            pgWalFromBuffer(result, NULL), VersionNotSupportedError,
+            "unexpected WAL magic 777\n"
+            "HINT: is this version of PostgreSQL supported?");
+
+        TEST_ASSIGN(info, pgWalFromFile(walFile, storageTest, STRDEF(PG_VERSION_15_STR)), "force wal info v15");
+        TEST_RESULT_UINT(info.systemId, 0xFAFAFAFA, "check system id");
+        TEST_RESULT_UINT(info.version, PG_VERSION_15, "   check version");
+        TEST_RESULT_UINT(info.size, PG_WAL_SEGMENT_SIZE_DEFAULT, "   check size");
     }
 
     // *****************************************************************************************************************************
@@ -242,7 +280,7 @@ testRun(void)
         {
             .version = PG_VERSION_11,
             .systemId = 0xEFEFEFEFEF,
-            .walSegmentSize= 16 * 1024 * 1024,
+            .walSegmentSize = 16 * 1024 * 1024,
             .pageChecksum = true
         };
 
